<?php
/**
 * @file
 * A specific handler for PE.
 *
 * @fixme At first ajax call, when department is changed, the district is not
 * filed correctly.
 * @todo extra validation for dep/prov/dist combinations.
 */

$plugin = array(
  'title' => t('Address form (PE add-on)'),
  'format callback' => 'addressfield_peru_format_address_pe_generate',
  'type' => 'address',
  'weight' => -80,
);

function addressfield_peru_format_address_pe_generate(&$format, $address, $context = array()) {
  //@todo define if we will user #required, #default_value
  if ($address['country'] == 'PE' && $context['mode'] == 'form') {
    // Department tweaks.
    $format['locality_block']['administrative_area']['#wrapper_id'] = $format['#wrapper_id'];
    $format['locality_block']['administrative_area']['#process'][] = 'ajax_process_form';
    $format['locality_block']['administrative_area']['#process'][] = 'addressfield_peru_format_address_pe_administrative_area_process';
    $format['locality_block']['administrative_area']['#element_validate'] = array('addressfield_peru_form_pe_administrative_area_validation');
    $format['locality_block']['administrative_area']['#ajax'] = array(
      'callback' => 'addressfield_standard_widget_refresh',
      'wrapper' => $format['#wrapper_id'],
      'method' => 'replace',
    );

    if (!empty($address['administrative_area'])) {
      $provinces = addressfield_peru_ubigeo_list('provinces', $address['administrative_area']);
      if (!empty($address['sub_administrative_area'])) {
        $districts = addressfield_peru_ubigeo_list('districts', $address['administrative_area'], substr($address['sub_administrative_area'], 2, 2));
      }
      else {
        $districts = array('' => t('--'));
      }
    }
    else {
      $provinces = array('' => t('--'));
      $districts = array('' => t('--'));
    }

    // Province tweaks.
    $format['locality_block']['sub_administrative_area']['#options'] = $provinces;
    $format['locality_block']['sub_administrative_area']['#process'][] = 'ajax_process_form';
    $format['locality_block']['sub_administrative_area']['#process'][] = 'addressfield_peru_format_address_pe_sub_administrative_area_process';
    $format['locality_block']['sub_administrative_area']['#element_validate'] = array('addressfield_peru_form_pe_sub_administrative_area_validation');
    $format['locality_block']['sub_administrative_area']['#ajax'] = array(
      'callback' => 'addressfield_standard_widget_refresh',
      'wrapper' => $format['#wrapper_id'],
      'method' => 'replace',
    );

    // District tweaks.
    $format['locality_block']['locality']['#options'] = $districts;
  }
  else {
    // Cancel the AJAX for forms we don't control.
    if (isset($format['locality_block']['administrative_area'])) {
      $format['locality_block']['administrative_area']['#ajax'] = array();
    }
    if (isset($format['locality_block']['sub_administrative_area'])) {
      $format['locality_block']['sub_administrative_area']['#ajax'] = array();
    }
  }
  if ($address['country'] == 'PE' && $context['mode'] == 'render') {
    // @todo Maybe find another way to know column on theme?
    $format['locality_block']['sub_administrative_area']['#render_type'] = 'addressfield_peru_container';
    $format['locality_block']['sub_administrative_area']['#addressfield_column'] = 'sub_administrative_area';
    $format['locality_block']['locality']['#render_type'] = 'addressfield_peru_container';
    $format['locality_block']['locality']['#addressfield_column'] = 'locality';
    $format['locality_block']['locality']['#weight'] = 1;
    $format['locality_block']['sub_administrative_area']['#weight'] = 2;
    $format['locality_block']['administrative_area']['#weight'] = 3;
  }
}

/**
 * Form process callback for addressfield administrative_area.
 */
function addressfield_peru_format_address_pe_administrative_area_process($element) {
  $element['#limit_validation_errors'] = array($element['#parents']);
  return $element;
}

/**
 * Form validation for addressfield administrative_area.
 */
function addressfield_peru_form_pe_administrative_area_validation($element, &$form_state, &$form) {
  if (empty($element['#value'])) {
    // Nothing to do.
    return;
  }

  // If the department was changed, rebuild the form.
  if ($element['#default_value'] != $element['#value']) {
    $form_state['rebuild'] = TRUE;
  }

  $provinces = addressfield_peru_ubigeo_list('provinces', $element['#value']);

  if (!empty($provinces)) {
    // Get the base #parents for this address element.
    $adddressfield_parents = array_slice($element['#parents'], 0, -1);
    $first_province = key($provinces);
    $department = drupal_array_get_nested_value($form_state['values'], array_merge($adddressfield_parents, array('administrative_area')));

    // Set the new values in the form.
    drupal_array_set_nested_value($form, array_merge($adddressfield_parents, array('locality_block', 'sub_administrative_area', '#default_value')), $first_province, TRUE);
    drupal_array_set_nested_value($form, array_merge($adddressfield_parents, array('locality_block', 'sub_administrative_area', '#value')), $first_province, TRUE);
    drupal_array_set_nested_value($form, array_merge($adddressfield_parents, array('locality_block', 'sub_administrative_area', '#options')), $provinces, TRUE);
    //drupal_array_set_nested_value($form_state['values'], array_merge($adddressfield_parents, array('sub_administrative_area')), $first_province, TRUE);

    $districts = addressfield_peru_ubigeo_list('districts', $department, substr($first_province, 2, 2));
    if (!empty($districts)) {
      $first_district = key($districts);
      drupal_array_set_nested_value($form, array_merge($adddressfield_parents, array('locality_block', 'locality', '#default_value')), $first_district, TRUE);
      drupal_array_set_nested_value($form, array_merge($adddressfield_parents, array('locality_block', 'locality', '#value')), $first_district, TRUE);
      drupal_array_set_nested_value($form, array_merge($adddressfield_parents, array('locality_block', 'locality', '#options')), $districts, TRUE);
    }
  }
}

/**
 * Form process callback for addressfield sub_administrative_area.
 */
function addressfield_peru_format_address_pe_sub_administrative_area_process($element) {
  $element['#limit_validation_errors'] = array($element['#parents']);
  return $element;
}

/**
 * Form validation for addressfield sub_administrative_area.
 */
function addressfield_peru_form_pe_sub_administrative_area_validation($element, &$form_state, &$form) {
  if (empty($element['#value'])) {
    // Nothing to do.
    return;
  }

  // If the province was changed, rebuild the form.
  if ($element['#default_value'] != $element['#value']) {
    $form_state['rebuild'] = TRUE;
  }

  // Get the base #parents for this address form.
  $adddressfield_parents = array_slice($element['#parents'], 0, -1);
  $department = drupal_array_get_nested_value($form_state['values'], array_merge($adddressfield_parents, array('administrative_area')));
  $districts = addressfield_peru_ubigeo_list('districts', $department, substr($element['#value'], 2, 2));

  if (!empty($districts)) {
    $first_district = key($districts);

    // Set the new values in the form.
    drupal_array_set_nested_value($form, array_merge($adddressfield_parents, array('locality_block', 'locality', '#default_value')), $first_district, TRUE);
    drupal_array_set_nested_value($form, array_merge($adddressfield_parents, array('locality_block', 'locality', '#value')), $first_district, TRUE);
    drupal_array_set_nested_value($form, array_merge($adddressfield_parents, array('locality_block', 'locality', '#options')), $districts, TRUE);
    //drupal_array_set_nested_value($form_state['values'], array_merge($adddressfield_parents, array('locality')), $first_district, TRUE);
  }
}

/**
 * Returns a list of ubigeo names keyed by code.
 *
 * Ubigeo information used was retrieved from
 * http://iinei.inei.gob.pe/iinei/siscodes/UbigeoMarco.htm
 * @todo Move to module code?
 *
 * @param string $type
 *   Either 'departments', 'provinces', 'districts' or 'item'.
 * @param string $department_or_code
 *   Denpending on type:
 *   - 'provinces' or 'districts': ISO_3166-2 Peru subdivision (department)
 *     code. i.e. 'AMA'.
 *   - 'item': full ubigeo code. i. e. '010101'.
 * @param string $province
 *   Province ubigeo code. i.e. '01'
 *   Required when $type is 'districts'.
 *
 * @return array
 *   Values depends on the $type:
 *   - 'districts': A list of districts in the department and province passed.
 *   - 'provinces': A list of provinces in the department passed.
 *   - 'departments': A list of departments.
 *   - 'item': The location code.
 *   - 'all': An associative array with the following keys:
 *     - 'department': List of departments.
 *     - 'province': List of provinces.
 *     - 'district': List of districts.
 */
function addressfield_peru_ubigeo_list($type, $department = '', $province = '') {
  // @todo Use real drupal cache.
  $ubigeo_list = &drupal_static(__FUNCTION__);
  static $flat_list;
  if (!isset($ubigeo_list) || !isset($flat_list)) {
    $ubigeo = array(
      '010000' => array('department' => '01', 'province' => '00', 'district' => '00', 'name' => t('Amazonas')),
      '010100' => array('department' => '01', 'province' => '01', 'district' => '00', 'name' => t('Chachapoyas')),
      '010101' => array('department' => '01', 'province' => '01', 'district' => '01', 'name' => t('Chachapoyas')),
      '010102' => array('department' => '01', 'province' => '01', 'district' => '02', 'name' => t('Asuncion')),
      '010103' => array('department' => '01', 'province' => '01', 'district' => '03', 'name' => t('Balsas')),
      '010104' => array('department' => '01', 'province' => '01', 'district' => '04', 'name' => t('Cheto')),
      '010105' => array('department' => '01', 'province' => '01', 'district' => '05', 'name' => t('Chiliquin')),
      '010106' => array('department' => '01', 'province' => '01', 'district' => '06', 'name' => t('Chuquibamba')),
      '010107' => array('department' => '01', 'province' => '01', 'district' => '07', 'name' => t('Granada')),
      '010108' => array('department' => '01', 'province' => '01', 'district' => '08', 'name' => t('Huancas')),
      '010109' => array('department' => '01', 'province' => '01', 'district' => '09', 'name' => t('La jalca')),
      '010110' => array('department' => '01', 'province' => '01', 'district' => '10', 'name' => t('Leimebamba')),
      '010111' => array('department' => '01', 'province' => '01', 'district' => '11', 'name' => t('Levanto')),
      '010112' => array('department' => '01', 'province' => '01', 'district' => '12', 'name' => t('Magdalena')),
      '010113' => array('department' => '01', 'province' => '01', 'district' => '13', 'name' => t('Mariscal castilla')),
      '010114' => array('department' => '01', 'province' => '01', 'district' => '14', 'name' => t('Molinopampa')),
      '010115' => array('department' => '01', 'province' => '01', 'district' => '15', 'name' => t('Montevideo')),
      '010116' => array('department' => '01', 'province' => '01', 'district' => '16', 'name' => t('Olleros')),
      '010117' => array('department' => '01', 'province' => '01', 'district' => '17', 'name' => t('Quinjalca')),
      '010118' => array('department' => '01', 'province' => '01', 'district' => '18', 'name' => t('San francisco de daguas')),
      '010119' => array('department' => '01', 'province' => '01', 'district' => '19', 'name' => t('San isidro de maino')),
      '010120' => array('department' => '01', 'province' => '01', 'district' => '20', 'name' => t('Soloco')),
      '010121' => array('department' => '01', 'province' => '01', 'district' => '21', 'name' => t('Sonche')),
      '010200' => array('department' => '01', 'province' => '02', 'district' => '00', 'name' => t('Bagua')),
      '010201' => array('department' => '01', 'province' => '02', 'district' => '01', 'name' => t('Bagua')),
      '010202' => array('department' => '01', 'province' => '02', 'district' => '02', 'name' => t('Aramango')),
      '010203' => array('department' => '01', 'province' => '02', 'district' => '03', 'name' => t('Copallin')),
      '010204' => array('department' => '01', 'province' => '02', 'district' => '04', 'name' => t('El parco')),
      '010205' => array('department' => '01', 'province' => '02', 'district' => '05', 'name' => t('Imaza')),
      '010206' => array('department' => '01', 'province' => '02', 'district' => '06', 'name' => t('La peca')),
      '010300' => array('department' => '01', 'province' => '03', 'district' => '00', 'name' => t('Bongara')),
      '010301' => array('department' => '01', 'province' => '03', 'district' => '01', 'name' => t('Jumbilla')),
      '010302' => array('department' => '01', 'province' => '03', 'district' => '02', 'name' => t('Chisquilla')),
      '010303' => array('department' => '01', 'province' => '03', 'district' => '03', 'name' => t('Churuja')),
      '010304' => array('department' => '01', 'province' => '03', 'district' => '04', 'name' => t('Corosha')),
      '010305' => array('department' => '01', 'province' => '03', 'district' => '05', 'name' => t('Cuispes')),
      '010306' => array('department' => '01', 'province' => '03', 'district' => '06', 'name' => t('Florida')),
      '010307' => array('department' => '01', 'province' => '03', 'district' => '07', 'name' => t('Jazan')),
      '010308' => array('department' => '01', 'province' => '03', 'district' => '08', 'name' => t('Recta')),
      '010309' => array('department' => '01', 'province' => '03', 'district' => '09', 'name' => t('San carlos')),
      '010310' => array('department' => '01', 'province' => '03', 'district' => '10', 'name' => t('Shipasbamba')),
      '010311' => array('department' => '01', 'province' => '03', 'district' => '11', 'name' => t('Valera')),
      '010312' => array('department' => '01', 'province' => '03', 'district' => '12', 'name' => t('Yambrasbamba')),
      '010400' => array('department' => '01', 'province' => '04', 'district' => '00', 'name' => t('Condorcanqui')),
      '010401' => array('department' => '01', 'province' => '04', 'district' => '01', 'name' => t('Nieva')),
      '010402' => array('department' => '01', 'province' => '04', 'district' => '02', 'name' => t('El cenepa')),
      '010403' => array('department' => '01', 'province' => '04', 'district' => '03', 'name' => t('Rio santiago')),
      '010500' => array('department' => '01', 'province' => '05', 'district' => '00', 'name' => t('Luya')),
      '010501' => array('department' => '01', 'province' => '05', 'district' => '01', 'name' => t('Lamud')),
      '010502' => array('department' => '01', 'province' => '05', 'district' => '02', 'name' => t('Camporredondo')),
      '010503' => array('department' => '01', 'province' => '05', 'district' => '03', 'name' => t('Cocabamba')),
      '010504' => array('department' => '01', 'province' => '05', 'district' => '04', 'name' => t('Colcamar')),
      '010505' => array('department' => '01', 'province' => '05', 'district' => '05', 'name' => t('Conila')),
      '010506' => array('department' => '01', 'province' => '05', 'district' => '06', 'name' => t('Inguilpata')),
      '010507' => array('department' => '01', 'province' => '05', 'district' => '07', 'name' => t('Longuita')),
      '010508' => array('department' => '01', 'province' => '05', 'district' => '08', 'name' => t('Lonya chico')),
      '010509' => array('department' => '01', 'province' => '05', 'district' => '09', 'name' => t('Luya')),
      '010510' => array('department' => '01', 'province' => '05', 'district' => '10', 'name' => t('Luya viejo')),
      '010511' => array('department' => '01', 'province' => '05', 'district' => '11', 'name' => t('Maria')),
      '010512' => array('department' => '01', 'province' => '05', 'district' => '12', 'name' => t('Ocalli')),
      '010513' => array('department' => '01', 'province' => '05', 'district' => '13', 'name' => t('Ocumal')),
      '010514' => array('department' => '01', 'province' => '05', 'district' => '14', 'name' => t('Pisuquia')),
      '010515' => array('department' => '01', 'province' => '05', 'district' => '15', 'name' => t('Providencia')),
      '010516' => array('department' => '01', 'province' => '05', 'district' => '16', 'name' => t('San cristobal')),
      '010517' => array('department' => '01', 'province' => '05', 'district' => '17', 'name' => t('San francisco del yeso')),
      '010518' => array('department' => '01', 'province' => '05', 'district' => '18', 'name' => t('San jeronimo')),
      '010519' => array('department' => '01', 'province' => '05', 'district' => '19', 'name' => t('San juan de lopecancha')),
      '010520' => array('department' => '01', 'province' => '05', 'district' => '20', 'name' => t('Santa catalina')),
      '010521' => array('department' => '01', 'province' => '05', 'district' => '21', 'name' => t('Santo tomas')),
      '010522' => array('department' => '01', 'province' => '05', 'district' => '22', 'name' => t('Tingo')),
      '010523' => array('department' => '01', 'province' => '05', 'district' => '23', 'name' => t('Trita')),
      '010600' => array('department' => '01', 'province' => '06', 'district' => '00', 'name' => t('Rodriguez de mendoza')),
      '010601' => array('department' => '01', 'province' => '06', 'district' => '01', 'name' => t('San nicolas')),
      '010602' => array('department' => '01', 'province' => '06', 'district' => '02', 'name' => t('Chirimoto')),
      '010603' => array('department' => '01', 'province' => '06', 'district' => '03', 'name' => t('Cochamal')),
      '010604' => array('department' => '01', 'province' => '06', 'district' => '04', 'name' => t('Huambo')),
      '010605' => array('department' => '01', 'province' => '06', 'district' => '05', 'name' => t('Limabamba')),
      '010606' => array('department' => '01', 'province' => '06', 'district' => '06', 'name' => t('Longar')),
      '010607' => array('department' => '01', 'province' => '06', 'district' => '07', 'name' => t('Mariscal benavides')),
      '010608' => array('department' => '01', 'province' => '06', 'district' => '08', 'name' => t('Milpuc')),
      '010609' => array('department' => '01', 'province' => '06', 'district' => '09', 'name' => t('Omia')),
      '010610' => array('department' => '01', 'province' => '06', 'district' => '10', 'name' => t('Santa rosa')),
      '010611' => array('department' => '01', 'province' => '06', 'district' => '11', 'name' => t('Totora')),
      '010612' => array('department' => '01', 'province' => '06', 'district' => '12', 'name' => t('Vista alegre')),
      '010700' => array('department' => '01', 'province' => '07', 'district' => '00', 'name' => t('Utcubamba')),
      '010701' => array('department' => '01', 'province' => '07', 'district' => '01', 'name' => t('Bagua grande')),
      '010702' => array('department' => '01', 'province' => '07', 'district' => '02', 'name' => t('Cajaruro')),
      '010703' => array('department' => '01', 'province' => '07', 'district' => '03', 'name' => t('Cumba')),
      '010704' => array('department' => '01', 'province' => '07', 'district' => '04', 'name' => t('El milagro')),
      '010705' => array('department' => '01', 'province' => '07', 'district' => '05', 'name' => t('Jamalca')),
      '010706' => array('department' => '01', 'province' => '07', 'district' => '06', 'name' => t('Lonya grande')),
      '010707' => array('department' => '01', 'province' => '07', 'district' => '07', 'name' => t('Yamon')),
      '020000' => array('department' => '02', 'province' => '00', 'district' => '00', 'name' => t('Ancash')),
      '020100' => array('department' => '02', 'province' => '01', 'district' => '00', 'name' => t('Huaraz')),
      '020101' => array('department' => '02', 'province' => '01', 'district' => '01', 'name' => t('Huaraz')),
      '020102' => array('department' => '02', 'province' => '01', 'district' => '02', 'name' => t('Cochabamba')),
      '020103' => array('department' => '02', 'province' => '01', 'district' => '03', 'name' => t('Colcabamba')),
      '020104' => array('department' => '02', 'province' => '01', 'district' => '04', 'name' => t('Huanchay')),
      '020105' => array('department' => '02', 'province' => '01', 'district' => '05', 'name' => t('Independencia')),
      '020106' => array('department' => '02', 'province' => '01', 'district' => '06', 'name' => t('Jangas')),
      '020107' => array('department' => '02', 'province' => '01', 'district' => '07', 'name' => t('La libertad')),
      '020108' => array('department' => '02', 'province' => '01', 'district' => '08', 'name' => t('Olleros')),
      '020109' => array('department' => '02', 'province' => '01', 'district' => '09', 'name' => t('Pampas')),
      '020110' => array('department' => '02', 'province' => '01', 'district' => '10', 'name' => t('Pariacoto')),
      '020111' => array('department' => '02', 'province' => '01', 'district' => '11', 'name' => t('Pira')),
      '020112' => array('department' => '02', 'province' => '01', 'district' => '12', 'name' => t('Tarica')),
      '020200' => array('department' => '02', 'province' => '02', 'district' => '00', 'name' => t('Aija')),
      '020201' => array('department' => '02', 'province' => '02', 'district' => '01', 'name' => t('Aija')),
      '020202' => array('department' => '02', 'province' => '02', 'district' => '02', 'name' => t('Coris')),
      '020203' => array('department' => '02', 'province' => '02', 'district' => '03', 'name' => t('Huacllan')),
      '020204' => array('department' => '02', 'province' => '02', 'district' => '04', 'name' => t('La merced')),
      '020205' => array('department' => '02', 'province' => '02', 'district' => '05', 'name' => t('Succha')),
      '020300' => array('department' => '02', 'province' => '03', 'district' => '00', 'name' => t('Antonio raymondi')),
      '020301' => array('department' => '02', 'province' => '03', 'district' => '01', 'name' => t('Llamellin')),
      '020302' => array('department' => '02', 'province' => '03', 'district' => '02', 'name' => t('Aczo')),
      '020303' => array('department' => '02', 'province' => '03', 'district' => '03', 'name' => t('Chaccho')),
      '020304' => array('department' => '02', 'province' => '03', 'district' => '04', 'name' => t('Chingas')),
      '020305' => array('department' => '02', 'province' => '03', 'district' => '05', 'name' => t('Mirgas')),
      '020306' => array('department' => '02', 'province' => '03', 'district' => '06', 'name' => t('San juan de rontoy')),
      '020400' => array('department' => '02', 'province' => '04', 'district' => '00', 'name' => t('Asuncion')),
      '020401' => array('department' => '02', 'province' => '04', 'district' => '01', 'name' => t('Chacas')),
      '020402' => array('department' => '02', 'province' => '04', 'district' => '02', 'name' => t('Acochaca')),
      '020500' => array('department' => '02', 'province' => '05', 'district' => '00', 'name' => t('Bolognesi')),
      '020501' => array('department' => '02', 'province' => '05', 'district' => '01', 'name' => t('Chiquian')),
      '020502' => array('department' => '02', 'province' => '05', 'district' => '02', 'name' => t('Abelardo pardo lezameta')),
      '020503' => array('department' => '02', 'province' => '05', 'district' => '03', 'name' => t('Antonio raymondi')),
      '020504' => array('department' => '02', 'province' => '05', 'district' => '04', 'name' => t('Aquia')),
      '020505' => array('department' => '02', 'province' => '05', 'district' => '05', 'name' => t('Cajacay')),
      '020506' => array('department' => '02', 'province' => '05', 'district' => '06', 'name' => t('Canis')),
      '020507' => array('department' => '02', 'province' => '05', 'district' => '07', 'name' => t('Colquioc')),
      '020508' => array('department' => '02', 'province' => '05', 'district' => '08', 'name' => t('Huallanca')),
      '020509' => array('department' => '02', 'province' => '05', 'district' => '09', 'name' => t('Huasta')),
      '020510' => array('department' => '02', 'province' => '05', 'district' => '10', 'name' => t('Huayllacayan')),
      '020511' => array('department' => '02', 'province' => '05', 'district' => '11', 'name' => t('La primavera')),
      '020512' => array('department' => '02', 'province' => '05', 'district' => '12', 'name' => t('Mangas')),
      '020513' => array('department' => '02', 'province' => '05', 'district' => '13', 'name' => t('Pacllon')),
      '020514' => array('department' => '02', 'province' => '05', 'district' => '14', 'name' => t('San miguel de corpanqui')),
      '020515' => array('department' => '02', 'province' => '05', 'district' => '15', 'name' => t('Ticllos')),
      '020600' => array('department' => '02', 'province' => '06', 'district' => '00', 'name' => t('Carhuaz')),
      '020601' => array('department' => '02', 'province' => '06', 'district' => '01', 'name' => t('Carhuaz')),
      '020602' => array('department' => '02', 'province' => '06', 'district' => '02', 'name' => t('Acopampa')),
      '020603' => array('department' => '02', 'province' => '06', 'district' => '03', 'name' => t('Amashca')),
      '020604' => array('department' => '02', 'province' => '06', 'district' => '04', 'name' => t('Anta')),
      '020605' => array('department' => '02', 'province' => '06', 'district' => '05', 'name' => t('Ataquero')),
      '020606' => array('department' => '02', 'province' => '06', 'district' => '06', 'name' => t('Marcara')),
      '020607' => array('department' => '02', 'province' => '06', 'district' => '07', 'name' => t('Pariahuanca')),
      '020608' => array('department' => '02', 'province' => '06', 'district' => '08', 'name' => t('San miguel de aco')),
      '020609' => array('department' => '02', 'province' => '06', 'district' => '09', 'name' => t('Shilla')),
      '020610' => array('department' => '02', 'province' => '06', 'district' => '10', 'name' => t('Tinco')),
      '020611' => array('department' => '02', 'province' => '06', 'district' => '11', 'name' => t('Yungar')),
      '020700' => array('department' => '02', 'province' => '07', 'district' => '00', 'name' => t('Carlos fermin fitzcarrald')),
      '020701' => array('department' => '02', 'province' => '07', 'district' => '01', 'name' => t('San luis')),
      '020702' => array('department' => '02', 'province' => '07', 'district' => '02', 'name' => t('San nicolas')),
      '020703' => array('department' => '02', 'province' => '07', 'district' => '03', 'name' => t('Yauya')),
      '020800' => array('department' => '02', 'province' => '08', 'district' => '00', 'name' => t('Casma')),
      '020801' => array('department' => '02', 'province' => '08', 'district' => '01', 'name' => t('Casma')),
      '020802' => array('department' => '02', 'province' => '08', 'district' => '02', 'name' => t('Buena vista alta')),
      '020803' => array('department' => '02', 'province' => '08', 'district' => '03', 'name' => t('Comandante noel')),
      '020804' => array('department' => '02', 'province' => '08', 'district' => '04', 'name' => t('Yautan')),
      '020900' => array('department' => '02', 'province' => '09', 'district' => '00', 'name' => t('Corongo')),
      '020901' => array('department' => '02', 'province' => '09', 'district' => '01', 'name' => t('Corongo')),
      '020902' => array('department' => '02', 'province' => '09', 'district' => '02', 'name' => t('Aco')),
      '020903' => array('department' => '02', 'province' => '09', 'district' => '03', 'name' => t('Bambas')),
      '020904' => array('department' => '02', 'province' => '09', 'district' => '04', 'name' => t('Cusca')),
      '020905' => array('department' => '02', 'province' => '09', 'district' => '05', 'name' => t('La pampa')),
      '020906' => array('department' => '02', 'province' => '09', 'district' => '06', 'name' => t('Yanac')),
      '020907' => array('department' => '02', 'province' => '09', 'district' => '07', 'name' => t('Yupan')),
      '021000' => array('department' => '02', 'province' => '10', 'district' => '00', 'name' => t('Huari')),
      '021001' => array('department' => '02', 'province' => '10', 'district' => '01', 'name' => t('Huari')),
      '021002' => array('department' => '02', 'province' => '10', 'district' => '02', 'name' => t('Anra')),
      '021003' => array('department' => '02', 'province' => '10', 'district' => '03', 'name' => t('Cajay')),
      '021004' => array('department' => '02', 'province' => '10', 'district' => '04', 'name' => t('Chavin de huantar')),
      '021005' => array('department' => '02', 'province' => '10', 'district' => '05', 'name' => t('Huacachi')),
      '021006' => array('department' => '02', 'province' => '10', 'district' => '06', 'name' => t('Huacchis')),
      '021007' => array('department' => '02', 'province' => '10', 'district' => '07', 'name' => t('Huachis')),
      '021008' => array('department' => '02', 'province' => '10', 'district' => '08', 'name' => t('Huantar')),
      '021009' => array('department' => '02', 'province' => '10', 'district' => '09', 'name' => t('Masin')),
      '021010' => array('department' => '02', 'province' => '10', 'district' => '10', 'name' => t('Paucas')),
      '021011' => array('department' => '02', 'province' => '10', 'district' => '11', 'name' => t('Ponto')),
      '021012' => array('department' => '02', 'province' => '10', 'district' => '12', 'name' => t('Rahuapampa')),
      '021013' => array('department' => '02', 'province' => '10', 'district' => '13', 'name' => t('Rapayan')),
      '021014' => array('department' => '02', 'province' => '10', 'district' => '14', 'name' => t('San marcos')),
      '021015' => array('department' => '02', 'province' => '10', 'district' => '15', 'name' => t('San pedro de chana')),
      '021016' => array('department' => '02', 'province' => '10', 'district' => '16', 'name' => t('Uco')),
      '021100' => array('department' => '02', 'province' => '11', 'district' => '00', 'name' => t('Huarmey')),
      '021101' => array('department' => '02', 'province' => '11', 'district' => '01', 'name' => t('Huarmey')),
      '021102' => array('department' => '02', 'province' => '11', 'district' => '02', 'name' => t('Cochapeti')),
      '021103' => array('department' => '02', 'province' => '11', 'district' => '03', 'name' => t('Culebras')),
      '021104' => array('department' => '02', 'province' => '11', 'district' => '04', 'name' => t('Huayan')),
      '021105' => array('department' => '02', 'province' => '11', 'district' => '05', 'name' => t('Malvas')),
      '021200' => array('department' => '02', 'province' => '12', 'district' => '00', 'name' => t('Huaylas')),
      '021201' => array('department' => '02', 'province' => '12', 'district' => '01', 'name' => t('Caraz')),
      '021202' => array('department' => '02', 'province' => '12', 'district' => '02', 'name' => t('Huallanca')),
      '021203' => array('department' => '02', 'province' => '12', 'district' => '03', 'name' => t('Huata')),
      '021204' => array('department' => '02', 'province' => '12', 'district' => '04', 'name' => t('Huaylas')),
      '021205' => array('department' => '02', 'province' => '12', 'district' => '05', 'name' => t('Mato')),
      '021206' => array('department' => '02', 'province' => '12', 'district' => '06', 'name' => t('Pamparomas')),
      '021207' => array('department' => '02', 'province' => '12', 'district' => '07', 'name' => t('Pueblo libre')),
      '021208' => array('department' => '02', 'province' => '12', 'district' => '08', 'name' => t('Santa cruz')),
      '021209' => array('department' => '02', 'province' => '12', 'district' => '09', 'name' => t('Santo toribio')),
      '021210' => array('department' => '02', 'province' => '12', 'district' => '10', 'name' => t('Yuracmarca')),
      '021300' => array('department' => '02', 'province' => '13', 'district' => '00', 'name' => t('Mariscal luzuriaga')),
      '021301' => array('department' => '02', 'province' => '13', 'district' => '01', 'name' => t('Piscobamba')),
      '021302' => array('department' => '02', 'province' => '13', 'district' => '02', 'name' => t('Casca')),
      '021303' => array('department' => '02', 'province' => '13', 'district' => '03', 'name' => t('Eleazar guzman barron')),
      '021304' => array('department' => '02', 'province' => '13', 'district' => '04', 'name' => t('Fidel olivas escudero')),
      '021305' => array('department' => '02', 'province' => '13', 'district' => '05', 'name' => t('Llama')),
      '021306' => array('department' => '02', 'province' => '13', 'district' => '06', 'name' => t('Llumpa')),
      '021307' => array('department' => '02', 'province' => '13', 'district' => '07', 'name' => t('Lucma')),
      '021308' => array('department' => '02', 'province' => '13', 'district' => '08', 'name' => t('Musga')),
      '021400' => array('department' => '02', 'province' => '14', 'district' => '00', 'name' => t('Ocros')),
      '021401' => array('department' => '02', 'province' => '14', 'district' => '01', 'name' => t('Ocros')),
      '021402' => array('department' => '02', 'province' => '14', 'district' => '02', 'name' => t('Acas')),
      '021403' => array('department' => '02', 'province' => '14', 'district' => '03', 'name' => t('Cajamarquilla')),
      '021404' => array('department' => '02', 'province' => '14', 'district' => '04', 'name' => t('Carhuapampa')),
      '021405' => array('department' => '02', 'province' => '14', 'district' => '05', 'name' => t('Cochas')),
      '021406' => array('department' => '02', 'province' => '14', 'district' => '06', 'name' => t('Congas')),
      '021407' => array('department' => '02', 'province' => '14', 'district' => '07', 'name' => t('Llipa')),
      '021408' => array('department' => '02', 'province' => '14', 'district' => '08', 'name' => t('San cristobal de rajan')),
      '021409' => array('department' => '02', 'province' => '14', 'district' => '09', 'name' => t('San pedro')),
      '021410' => array('department' => '02', 'province' => '14', 'district' => '10', 'name' => t('Santiago de chilcas')),
      '021500' => array('department' => '02', 'province' => '15', 'district' => '00', 'name' => t('Pallasca')),
      '021501' => array('department' => '02', 'province' => '15', 'district' => '01', 'name' => t('Cabana')),
      '021502' => array('department' => '02', 'province' => '15', 'district' => '02', 'name' => t('Bolognesi')),
      '021503' => array('department' => '02', 'province' => '15', 'district' => '03', 'name' => t('Conchucos')),
      '021504' => array('department' => '02', 'province' => '15', 'district' => '04', 'name' => t('Huacaschuque')),
      '021505' => array('department' => '02', 'province' => '15', 'district' => '05', 'name' => t('Huandoval')),
      '021506' => array('department' => '02', 'province' => '15', 'district' => '06', 'name' => t('Lacabamba')),
      '021507' => array('department' => '02', 'province' => '15', 'district' => '07', 'name' => t('Llapo')),
      '021508' => array('department' => '02', 'province' => '15', 'district' => '08', 'name' => t('Pallasca')),
      '021509' => array('department' => '02', 'province' => '15', 'district' => '09', 'name' => t('Pampas')),
      '021510' => array('department' => '02', 'province' => '15', 'district' => '10', 'name' => t('Santa rosa')),
      '021511' => array('department' => '02', 'province' => '15', 'district' => '11', 'name' => t('Tauca')),
      '021600' => array('department' => '02', 'province' => '16', 'district' => '00', 'name' => t('Pomabamba')),
      '021601' => array('department' => '02', 'province' => '16', 'district' => '01', 'name' => t('Pomabamba')),
      '021602' => array('department' => '02', 'province' => '16', 'district' => '02', 'name' => t('Huayllan')),
      '021603' => array('department' => '02', 'province' => '16', 'district' => '03', 'name' => t('Parobamba')),
      '021604' => array('department' => '02', 'province' => '16', 'district' => '04', 'name' => t('Quinuabamba')),
      '021700' => array('department' => '02', 'province' => '17', 'district' => '00', 'name' => t('Recuay')),
      '021701' => array('department' => '02', 'province' => '17', 'district' => '01', 'name' => t('Recuay')),
      '021702' => array('department' => '02', 'province' => '17', 'district' => '02', 'name' => t('Catac')),
      '021703' => array('department' => '02', 'province' => '17', 'district' => '03', 'name' => t('Cotaparaco')),
      '021704' => array('department' => '02', 'province' => '17', 'district' => '04', 'name' => t('Huayllapampa')),
      '021705' => array('department' => '02', 'province' => '17', 'district' => '05', 'name' => t('Llacllin')),
      '021706' => array('department' => '02', 'province' => '17', 'district' => '06', 'name' => t('Marca')),
      '021707' => array('department' => '02', 'province' => '17', 'district' => '07', 'name' => t('Pampas chico')),
      '021708' => array('department' => '02', 'province' => '17', 'district' => '08', 'name' => t('Pararin')),
      '021709' => array('department' => '02', 'province' => '17', 'district' => '09', 'name' => t('Tapacocha')),
      '021710' => array('department' => '02', 'province' => '17', 'district' => '10', 'name' => t('Ticapampa')),
      '021800' => array('department' => '02', 'province' => '18', 'district' => '00', 'name' => t('Santa')),
      '021801' => array('department' => '02', 'province' => '18', 'district' => '01', 'name' => t('Chimbote')),
      '021802' => array('department' => '02', 'province' => '18', 'district' => '02', 'name' => t('Caceres del peru')),
      '021803' => array('department' => '02', 'province' => '18', 'district' => '03', 'name' => t('Coishco')),
      '021804' => array('department' => '02', 'province' => '18', 'district' => '04', 'name' => t('Macate')),
      '021805' => array('department' => '02', 'province' => '18', 'district' => '05', 'name' => t('Moro')),
      '021806' => array('department' => '02', 'province' => '18', 'district' => '06', 'name' => t('Nepeña')),
      '021807' => array('department' => '02', 'province' => '18', 'district' => '07', 'name' => t('Samanco')),
      '021808' => array('department' => '02', 'province' => '18', 'district' => '08', 'name' => t('Santa')),
      '021809' => array('department' => '02', 'province' => '18', 'district' => '09', 'name' => t('Nuevo chimbote')),
      '021900' => array('department' => '02', 'province' => '19', 'district' => '00', 'name' => t('Sihuas')),
      '021901' => array('department' => '02', 'province' => '19', 'district' => '01', 'name' => t('Sihuas')),
      '021902' => array('department' => '02', 'province' => '19', 'district' => '02', 'name' => t('Acobamba')),
      '021903' => array('department' => '02', 'province' => '19', 'district' => '03', 'name' => t('Alfonso ugarte')),
      '021904' => array('department' => '02', 'province' => '19', 'district' => '04', 'name' => t('Cashapampa')),
      '021905' => array('department' => '02', 'province' => '19', 'district' => '05', 'name' => t('Chingalpo')),
      '021906' => array('department' => '02', 'province' => '19', 'district' => '06', 'name' => t('Huayllabamba')),
      '021907' => array('department' => '02', 'province' => '19', 'district' => '07', 'name' => t('Quiches')),
      '021908' => array('department' => '02', 'province' => '19', 'district' => '08', 'name' => t('Ragash')),
      '021909' => array('department' => '02', 'province' => '19', 'district' => '09', 'name' => t('San juan')),
      '021910' => array('department' => '02', 'province' => '19', 'district' => '10', 'name' => t('Sicsibamba')),
      '022000' => array('department' => '02', 'province' => '20', 'district' => '00', 'name' => t('Yungay')),
      '022001' => array('department' => '02', 'province' => '20', 'district' => '01', 'name' => t('Yungay')),
      '022002' => array('department' => '02', 'province' => '20', 'district' => '02', 'name' => t('Cascapara')),
      '022003' => array('department' => '02', 'province' => '20', 'district' => '03', 'name' => t('Mancos')),
      '022004' => array('department' => '02', 'province' => '20', 'district' => '04', 'name' => t('Matacoto')),
      '022005' => array('department' => '02', 'province' => '20', 'district' => '05', 'name' => t('Quillo')),
      '022006' => array('department' => '02', 'province' => '20', 'district' => '06', 'name' => t('Ranrahirca')),
      '022007' => array('department' => '02', 'province' => '20', 'district' => '07', 'name' => t('Shupluy')),
      '022008' => array('department' => '02', 'province' => '20', 'district' => '08', 'name' => t('Yanama')),
      '030000' => array('department' => '03', 'province' => '00', 'district' => '00', 'name' => t('Apurimac')),
      '030100' => array('department' => '03', 'province' => '01', 'district' => '00', 'name' => t('Abancay')),
      '030101' => array('department' => '03', 'province' => '01', 'district' => '01', 'name' => t('Abancay')),
      '030102' => array('department' => '03', 'province' => '01', 'district' => '02', 'name' => t('Chacoche')),
      '030103' => array('department' => '03', 'province' => '01', 'district' => '03', 'name' => t('Circa')),
      '030104' => array('department' => '03', 'province' => '01', 'district' => '04', 'name' => t('Curahuasi')),
      '030105' => array('department' => '03', 'province' => '01', 'district' => '05', 'name' => t('Huanipaca')),
      '030106' => array('department' => '03', 'province' => '01', 'district' => '06', 'name' => t('Lambrama')),
      '030107' => array('department' => '03', 'province' => '01', 'district' => '07', 'name' => t('Pichirhua')),
      '030108' => array('department' => '03', 'province' => '01', 'district' => '08', 'name' => t('San pedro de cachora')),
      '030109' => array('department' => '03', 'province' => '01', 'district' => '09', 'name' => t('Tamburco')),
      '030200' => array('department' => '03', 'province' => '02', 'district' => '00', 'name' => t('Andahuaylas')),
      '030201' => array('department' => '03', 'province' => '02', 'district' => '01', 'name' => t('Andahuaylas')),
      '030202' => array('department' => '03', 'province' => '02', 'district' => '02', 'name' => t('Andarapa')),
      '030203' => array('department' => '03', 'province' => '02', 'district' => '03', 'name' => t('Chiara')),
      '030204' => array('department' => '03', 'province' => '02', 'district' => '04', 'name' => t('Huancarama')),
      '030205' => array('department' => '03', 'province' => '02', 'district' => '05', 'name' => t('Huancaray')),
      '030206' => array('department' => '03', 'province' => '02', 'district' => '06', 'name' => t('Huayana')),
      '030207' => array('department' => '03', 'province' => '02', 'district' => '07', 'name' => t('Kishuara')),
      '030208' => array('department' => '03', 'province' => '02', 'district' => '08', 'name' => t('Pacobamba')),
      '030209' => array('department' => '03', 'province' => '02', 'district' => '09', 'name' => t('Pacucha')),
      '030210' => array('department' => '03', 'province' => '02', 'district' => '10', 'name' => t('Pampachiri')),
      '030211' => array('department' => '03', 'province' => '02', 'district' => '11', 'name' => t('Pomacocha')),
      '030212' => array('department' => '03', 'province' => '02', 'district' => '12', 'name' => t('San antonio de cachi')),
      '030213' => array('department' => '03', 'province' => '02', 'district' => '13', 'name' => t('San jeronimo')),
      '030214' => array('department' => '03', 'province' => '02', 'district' => '14', 'name' => t('San miguel de chaccrampa')),
      '030215' => array('department' => '03', 'province' => '02', 'district' => '15', 'name' => t('Santa maria de chicmo')),
      '030216' => array('department' => '03', 'province' => '02', 'district' => '16', 'name' => t('Talavera')),
      '030217' => array('department' => '03', 'province' => '02', 'district' => '17', 'name' => t('Tumay huaraca')),
      '030218' => array('department' => '03', 'province' => '02', 'district' => '18', 'name' => t('Turpo')),
      '030219' => array('department' => '03', 'province' => '02', 'district' => '19', 'name' => t('Kaquiabamba')),
      '030300' => array('department' => '03', 'province' => '03', 'district' => '00', 'name' => t('Antabamba')),
      '030301' => array('department' => '03', 'province' => '03', 'district' => '01', 'name' => t('Antabamba')),
      '030302' => array('department' => '03', 'province' => '03', 'district' => '02', 'name' => t('El oro')),
      '030303' => array('department' => '03', 'province' => '03', 'district' => '03', 'name' => t('Huaquirca')),
      '030304' => array('department' => '03', 'province' => '03', 'district' => '04', 'name' => t('Juan espinoza medrano')),
      '030305' => array('department' => '03', 'province' => '03', 'district' => '05', 'name' => t('Oropesa')),
      '030306' => array('department' => '03', 'province' => '03', 'district' => '06', 'name' => t('Pachaconas')),
      '030307' => array('department' => '03', 'province' => '03', 'district' => '07', 'name' => t('Sabaino')),
      '030400' => array('department' => '03', 'province' => '04', 'district' => '00', 'name' => t('Aymaraes')),
      '030401' => array('department' => '03', 'province' => '04', 'district' => '01', 'name' => t('Chalhuanca')),
      '030402' => array('department' => '03', 'province' => '04', 'district' => '02', 'name' => t('Capaya')),
      '030403' => array('department' => '03', 'province' => '04', 'district' => '03', 'name' => t('Caraybamba')),
      '030404' => array('department' => '03', 'province' => '04', 'district' => '04', 'name' => t('Chapimarca')),
      '030405' => array('department' => '03', 'province' => '04', 'district' => '05', 'name' => t('Colcabamba')),
      '030406' => array('department' => '03', 'province' => '04', 'district' => '06', 'name' => t('Cotaruse')),
      '030407' => array('department' => '03', 'province' => '04', 'district' => '07', 'name' => t('Huayllo')),
      '030408' => array('department' => '03', 'province' => '04', 'district' => '08', 'name' => t('Justo apu sahuaraura')),
      '030409' => array('department' => '03', 'province' => '04', 'district' => '09', 'name' => t('Lucre')),
      '030410' => array('department' => '03', 'province' => '04', 'district' => '10', 'name' => t('Pocohuanca')),
      '030411' => array('department' => '03', 'province' => '04', 'district' => '11', 'name' => t('San juan de chacña')),
      '030412' => array('department' => '03', 'province' => '04', 'district' => '12', 'name' => t('Sañayca')),
      '030413' => array('department' => '03', 'province' => '04', 'district' => '13', 'name' => t('Soraya')),
      '030414' => array('department' => '03', 'province' => '04', 'district' => '14', 'name' => t('Tapairihua')),
      '030415' => array('department' => '03', 'province' => '04', 'district' => '15', 'name' => t('Tintay')),
      '030416' => array('department' => '03', 'province' => '04', 'district' => '16', 'name' => t('Toraya')),
      '030417' => array('department' => '03', 'province' => '04', 'district' => '17', 'name' => t('Yanaca')),
      '030500' => array('department' => '03', 'province' => '05', 'district' => '00', 'name' => t('Cotabambas')),
      '030501' => array('department' => '03', 'province' => '05', 'district' => '01', 'name' => t('Tambobamba')),
      '030502' => array('department' => '03', 'province' => '05', 'district' => '02', 'name' => t('Cotabambas')),
      '030503' => array('department' => '03', 'province' => '05', 'district' => '03', 'name' => t('Coyllurqui')),
      '030504' => array('department' => '03', 'province' => '05', 'district' => '04', 'name' => t('Haquira')),
      '030505' => array('department' => '03', 'province' => '05', 'district' => '05', 'name' => t('Mara')),
      '030506' => array('department' => '03', 'province' => '05', 'district' => '06', 'name' => t('Challhuahuacho')),
      '030600' => array('department' => '03', 'province' => '06', 'district' => '00', 'name' => t('Chincheros')),
      '030601' => array('department' => '03', 'province' => '06', 'district' => '01', 'name' => t('Chincheros')),
      '030602' => array('department' => '03', 'province' => '06', 'district' => '02', 'name' => t('Anco_huallo')),
      '030603' => array('department' => '03', 'province' => '06', 'district' => '03', 'name' => t('Cocharcas')),
      '030604' => array('department' => '03', 'province' => '06', 'district' => '04', 'name' => t('Huaccana')),
      '030605' => array('department' => '03', 'province' => '06', 'district' => '05', 'name' => t('Ocobamba')),
      '030606' => array('department' => '03', 'province' => '06', 'district' => '06', 'name' => t('Ongoy')),
      '030607' => array('department' => '03', 'province' => '06', 'district' => '07', 'name' => t('Uranmarca')),
      '030608' => array('department' => '03', 'province' => '06', 'district' => '08', 'name' => t('Ranracancha')),
      '030700' => array('department' => '03', 'province' => '07', 'district' => '00', 'name' => t('Grau')),
      '030701' => array('department' => '03', 'province' => '07', 'district' => '01', 'name' => t('Chuquibambilla')),
      '030702' => array('department' => '03', 'province' => '07', 'district' => '02', 'name' => t('Curpahuasi')),
      '030703' => array('department' => '03', 'province' => '07', 'district' => '03', 'name' => t('Gamarra')),
      '030704' => array('department' => '03', 'province' => '07', 'district' => '04', 'name' => t('Huayllati')),
      '030705' => array('department' => '03', 'province' => '07', 'district' => '05', 'name' => t('Mamara')),
      '030706' => array('department' => '03', 'province' => '07', 'district' => '06', 'name' => t('Micaela bastidas')),
      '030707' => array('department' => '03', 'province' => '07', 'district' => '07', 'name' => t('Pataypampa')),
      '030708' => array('department' => '03', 'province' => '07', 'district' => '08', 'name' => t('Progreso')),
      '030709' => array('department' => '03', 'province' => '07', 'district' => '09', 'name' => t('San antonio')),
      '030710' => array('department' => '03', 'province' => '07', 'district' => '10', 'name' => t('Santa rosa')),
      '030711' => array('department' => '03', 'province' => '07', 'district' => '11', 'name' => t('Turpay')),
      '030712' => array('department' => '03', 'province' => '07', 'district' => '12', 'name' => t('Vilcabamba')),
      '030713' => array('department' => '03', 'province' => '07', 'district' => '13', 'name' => t('Virundo')),
      '030714' => array('department' => '03', 'province' => '07', 'district' => '14', 'name' => t('Curasco')),
      '040000' => array('department' => '04', 'province' => '00', 'district' => '00', 'name' => t('Arequipa')),
      '040100' => array('department' => '04', 'province' => '01', 'district' => '00', 'name' => t('Arequipa')),
      '040101' => array('department' => '04', 'province' => '01', 'district' => '01', 'name' => t('Arequipa')),
      '040102' => array('department' => '04', 'province' => '01', 'district' => '02', 'name' => t('Alto selva alegre')),
      '040103' => array('department' => '04', 'province' => '01', 'district' => '03', 'name' => t('Cayma')),
      '040104' => array('department' => '04', 'province' => '01', 'district' => '04', 'name' => t('Cerro colorado')),
      '040105' => array('department' => '04', 'province' => '01', 'district' => '05', 'name' => t('Characato')),
      '040106' => array('department' => '04', 'province' => '01', 'district' => '06', 'name' => t('Chiguata')),
      '040107' => array('department' => '04', 'province' => '01', 'district' => '07', 'name' => t('Jacobo hunter')),
      '040108' => array('department' => '04', 'province' => '01', 'district' => '08', 'name' => t('La joya')),
      '040109' => array('department' => '04', 'province' => '01', 'district' => '09', 'name' => t('Mariano melgar')),
      '040110' => array('department' => '04', 'province' => '01', 'district' => '10', 'name' => t('Miraflores')),
      '040111' => array('department' => '04', 'province' => '01', 'district' => '11', 'name' => t('Mollebaya')),
      '040112' => array('department' => '04', 'province' => '01', 'district' => '12', 'name' => t('Paucarpata')),
      '040113' => array('department' => '04', 'province' => '01', 'district' => '13', 'name' => t('Pocsi')),
      '040114' => array('department' => '04', 'province' => '01', 'district' => '14', 'name' => t('Polobaya')),
      '040115' => array('department' => '04', 'province' => '01', 'district' => '15', 'name' => t('Quequeña')),
      '040116' => array('department' => '04', 'province' => '01', 'district' => '16', 'name' => t('Sabandia')),
      '040117' => array('department' => '04', 'province' => '01', 'district' => '17', 'name' => t('Sachaca')),
      '040118' => array('department' => '04', 'province' => '01', 'district' => '18', 'name' => t('San juan de siguas')),
      '040119' => array('department' => '04', 'province' => '01', 'district' => '19', 'name' => t('San juan de tarucani')),
      '040120' => array('department' => '04', 'province' => '01', 'district' => '20', 'name' => t('Santa isabel de siguas')),
      '040121' => array('department' => '04', 'province' => '01', 'district' => '21', 'name' => t('Santa rita de siguas')),
      '040122' => array('department' => '04', 'province' => '01', 'district' => '22', 'name' => t('Socabaya')),
      '040123' => array('department' => '04', 'province' => '01', 'district' => '23', 'name' => t('Tiabaya')),
      '040124' => array('department' => '04', 'province' => '01', 'district' => '24', 'name' => t('Uchumayo')),
      '040125' => array('department' => '04', 'province' => '01', 'district' => '25', 'name' => t('Vitor')),
      '040126' => array('department' => '04', 'province' => '01', 'district' => '26', 'name' => t('Yanahuara')),
      '040127' => array('department' => '04', 'province' => '01', 'district' => '27', 'name' => t('Yarabamba')),
      '040128' => array('department' => '04', 'province' => '01', 'district' => '28', 'name' => t('Yura')),
      '040129' => array('department' => '04', 'province' => '01', 'district' => '29', 'name' => t('Jose luis bustamante y rivero')),
      '040200' => array('department' => '04', 'province' => '02', 'district' => '00', 'name' => t('Camana')),
      '040201' => array('department' => '04', 'province' => '02', 'district' => '01', 'name' => t('Camana')),
      '040202' => array('department' => '04', 'province' => '02', 'district' => '02', 'name' => t('Jose maria quimper')),
      '040203' => array('department' => '04', 'province' => '02', 'district' => '03', 'name' => t('Mariano nicolas valcarcel')),
      '040204' => array('department' => '04', 'province' => '02', 'district' => '04', 'name' => t('Mariscal caceres')),
      '040205' => array('department' => '04', 'province' => '02', 'district' => '05', 'name' => t('Nicolas de pierola')),
      '040206' => array('department' => '04', 'province' => '02', 'district' => '06', 'name' => t('Ocoña')),
      '040207' => array('department' => '04', 'province' => '02', 'district' => '07', 'name' => t('Quilca')),
      '040208' => array('department' => '04', 'province' => '02', 'district' => '08', 'name' => t('Samuel pastor')),
      '040300' => array('department' => '04', 'province' => '03', 'district' => '00', 'name' => t('Caraveli')),
      '040301' => array('department' => '04', 'province' => '03', 'district' => '01', 'name' => t('Caraveli')),
      '040302' => array('department' => '04', 'province' => '03', 'district' => '02', 'name' => t('Acari')),
      '040303' => array('department' => '04', 'province' => '03', 'district' => '03', 'name' => t('Atico')),
      '040304' => array('department' => '04', 'province' => '03', 'district' => '04', 'name' => t('Atiquipa')),
      '040305' => array('department' => '04', 'province' => '03', 'district' => '05', 'name' => t('Bella union')),
      '040306' => array('department' => '04', 'province' => '03', 'district' => '06', 'name' => t('Cahuacho')),
      '040307' => array('department' => '04', 'province' => '03', 'district' => '07', 'name' => t('Chala')),
      '040308' => array('department' => '04', 'province' => '03', 'district' => '08', 'name' => t('Chaparra')),
      '040309' => array('department' => '04', 'province' => '03', 'district' => '09', 'name' => t('Huanuhuanu')),
      '040310' => array('department' => '04', 'province' => '03', 'district' => '10', 'name' => t('Jaqui')),
      '040311' => array('department' => '04', 'province' => '03', 'district' => '11', 'name' => t('Lomas')),
      '040312' => array('department' => '04', 'province' => '03', 'district' => '12', 'name' => t('Quicacha')),
      '040313' => array('department' => '04', 'province' => '03', 'district' => '13', 'name' => t('Yauca')),
      '040400' => array('department' => '04', 'province' => '04', 'district' => '00', 'name' => t('Castilla')),
      '040401' => array('department' => '04', 'province' => '04', 'district' => '01', 'name' => t('Aplao')),
      '040402' => array('department' => '04', 'province' => '04', 'district' => '02', 'name' => t('Andagua')),
      '040403' => array('department' => '04', 'province' => '04', 'district' => '03', 'name' => t('Ayo')),
      '040404' => array('department' => '04', 'province' => '04', 'district' => '04', 'name' => t('Chachas')),
      '040405' => array('department' => '04', 'province' => '04', 'district' => '05', 'name' => t('Chilcaymarca')),
      '040406' => array('department' => '04', 'province' => '04', 'district' => '06', 'name' => t('Choco')),
      '040407' => array('department' => '04', 'province' => '04', 'district' => '07', 'name' => t('Huancarqui')),
      '040408' => array('department' => '04', 'province' => '04', 'district' => '08', 'name' => t('Machaguay')),
      '040409' => array('department' => '04', 'province' => '04', 'district' => '09', 'name' => t('Orcopampa')),
      '040410' => array('department' => '04', 'province' => '04', 'district' => '10', 'name' => t('Pampacolca')),
      '040411' => array('department' => '04', 'province' => '04', 'district' => '11', 'name' => t('Tipan')),
      '040412' => array('department' => '04', 'province' => '04', 'district' => '12', 'name' => t('Uñon')),
      '040413' => array('department' => '04', 'province' => '04', 'district' => '13', 'name' => t('Uraca')),
      '040414' => array('department' => '04', 'province' => '04', 'district' => '14', 'name' => t('Viraco')),
      '040500' => array('department' => '04', 'province' => '05', 'district' => '00', 'name' => t('Caylloma')),
      '040501' => array('department' => '04', 'province' => '05', 'district' => '01', 'name' => t('Chivay')),
      '040502' => array('department' => '04', 'province' => '05', 'district' => '02', 'name' => t('Achoma')),
      '040503' => array('department' => '04', 'province' => '05', 'district' => '03', 'name' => t('Cabanaconde')),
      '040504' => array('department' => '04', 'province' => '05', 'district' => '04', 'name' => t('Callalli')),
      '040505' => array('department' => '04', 'province' => '05', 'district' => '05', 'name' => t('Caylloma')),
      '040506' => array('department' => '04', 'province' => '05', 'district' => '06', 'name' => t('Coporaque')),
      '040507' => array('department' => '04', 'province' => '05', 'district' => '07', 'name' => t('Huambo')),
      '040508' => array('department' => '04', 'province' => '05', 'district' => '08', 'name' => t('Huanca')),
      '040509' => array('department' => '04', 'province' => '05', 'district' => '09', 'name' => t('Ichupampa')),
      '040510' => array('department' => '04', 'province' => '05', 'district' => '10', 'name' => t('Lari')),
      '040511' => array('department' => '04', 'province' => '05', 'district' => '11', 'name' => t('Lluta')),
      '040512' => array('department' => '04', 'province' => '05', 'district' => '12', 'name' => t('Maca')),
      '040513' => array('department' => '04', 'province' => '05', 'district' => '13', 'name' => t('Madrigal')),
      '040514' => array('department' => '04', 'province' => '05', 'district' => '14', 'name' => t('San antonio de chuca')),
      '040515' => array('department' => '04', 'province' => '05', 'district' => '15', 'name' => t('Sibayo')),
      '040516' => array('department' => '04', 'province' => '05', 'district' => '16', 'name' => t('Tapay')),
      '040517' => array('department' => '04', 'province' => '05', 'district' => '17', 'name' => t('Tisco')),
      '040518' => array('department' => '04', 'province' => '05', 'district' => '18', 'name' => t('Tuti')),
      '040519' => array('department' => '04', 'province' => '05', 'district' => '19', 'name' => t('Yanque')),
      '040520' => array('department' => '04', 'province' => '05', 'district' => '20', 'name' => t('Majes')),
      '040600' => array('department' => '04', 'province' => '06', 'district' => '00', 'name' => t('Condesuyos')),
      '040601' => array('department' => '04', 'province' => '06', 'district' => '01', 'name' => t('Chuquibamba')),
      '040602' => array('department' => '04', 'province' => '06', 'district' => '02', 'name' => t('Andaray')),
      '040603' => array('department' => '04', 'province' => '06', 'district' => '03', 'name' => t('Cayarani')),
      '040604' => array('department' => '04', 'province' => '06', 'district' => '04', 'name' => t('Chichas')),
      '040605' => array('department' => '04', 'province' => '06', 'district' => '05', 'name' => t('Iray')),
      '040606' => array('department' => '04', 'province' => '06', 'district' => '06', 'name' => t('Rio grande')),
      '040607' => array('department' => '04', 'province' => '06', 'district' => '07', 'name' => t('Salamanca')),
      '040608' => array('department' => '04', 'province' => '06', 'district' => '08', 'name' => t('Yanaquihua')),
      '040700' => array('department' => '04', 'province' => '07', 'district' => '00', 'name' => t('Islay')),
      '040701' => array('department' => '04', 'province' => '07', 'district' => '01', 'name' => t('Mollendo')),
      '040702' => array('department' => '04', 'province' => '07', 'district' => '02', 'name' => t('Cocachacra')),
      '040703' => array('department' => '04', 'province' => '07', 'district' => '03', 'name' => t('Dean valdivia')),
      '040704' => array('department' => '04', 'province' => '07', 'district' => '04', 'name' => t('Islay')),
      '040705' => array('department' => '04', 'province' => '07', 'district' => '05', 'name' => t('Mejia')),
      '040706' => array('department' => '04', 'province' => '07', 'district' => '06', 'name' => t('Punta de bombon')),
      '040800' => array('department' => '04', 'province' => '08', 'district' => '00', 'name' => t('La union')),
      '040801' => array('department' => '04', 'province' => '08', 'district' => '01', 'name' => t('Cotahuasi')),
      '040802' => array('department' => '04', 'province' => '08', 'district' => '02', 'name' => t('Alca')),
      '040803' => array('department' => '04', 'province' => '08', 'district' => '03', 'name' => t('Charcana')),
      '040804' => array('department' => '04', 'province' => '08', 'district' => '04', 'name' => t('Huaynacotas')),
      '040805' => array('department' => '04', 'province' => '08', 'district' => '05', 'name' => t('Pampamarca')),
      '040806' => array('department' => '04', 'province' => '08', 'district' => '06', 'name' => t('Puyca')),
      '040807' => array('department' => '04', 'province' => '08', 'district' => '07', 'name' => t('Quechualla')),
      '040808' => array('department' => '04', 'province' => '08', 'district' => '08', 'name' => t('Sayla')),
      '040809' => array('department' => '04', 'province' => '08', 'district' => '09', 'name' => t('Tauria')),
      '040810' => array('department' => '04', 'province' => '08', 'district' => '10', 'name' => t('Tomepampa')),
      '040811' => array('department' => '04', 'province' => '08', 'district' => '11', 'name' => t('Toro')),
      '050000' => array('department' => '05', 'province' => '00', 'district' => '00', 'name' => t('Ayacucho')),
      '050100' => array('department' => '05', 'province' => '01', 'district' => '00', 'name' => t('Huamanga')),
      '050101' => array('department' => '05', 'province' => '01', 'district' => '01', 'name' => t('Ayacucho')),
      '050102' => array('department' => '05', 'province' => '01', 'district' => '02', 'name' => t('Acocro')),
      '050103' => array('department' => '05', 'province' => '01', 'district' => '03', 'name' => t('Acos vinchos')),
      '050104' => array('department' => '05', 'province' => '01', 'district' => '04', 'name' => t('Carmen alto')),
      '050105' => array('department' => '05', 'province' => '01', 'district' => '05', 'name' => t('Chiara')),
      '050106' => array('department' => '05', 'province' => '01', 'district' => '06', 'name' => t('Ocros')),
      '050107' => array('department' => '05', 'province' => '01', 'district' => '07', 'name' => t('Pacaycasa')),
      '050108' => array('department' => '05', 'province' => '01', 'district' => '08', 'name' => t('Quinua')),
      '050109' => array('department' => '05', 'province' => '01', 'district' => '09', 'name' => t('San jose de ticllas')),
      '050110' => array('department' => '05', 'province' => '01', 'district' => '10', 'name' => t('San juan bautista')),
      '050111' => array('department' => '05', 'province' => '01', 'district' => '11', 'name' => t('Santiago de pischa')),
      '050112' => array('department' => '05', 'province' => '01', 'district' => '12', 'name' => t('Socos')),
      '050113' => array('department' => '05', 'province' => '01', 'district' => '13', 'name' => t('Tambillo')),
      '050114' => array('department' => '05', 'province' => '01', 'district' => '14', 'name' => t('Vinchos')),
      '050115' => array('department' => '05', 'province' => '01', 'district' => '15', 'name' => t('Jesus nazareno')),
      '050200' => array('department' => '05', 'province' => '02', 'district' => '00', 'name' => t('Cangallo')),
      '050201' => array('department' => '05', 'province' => '02', 'district' => '01', 'name' => t('Cangallo')),
      '050202' => array('department' => '05', 'province' => '02', 'district' => '02', 'name' => t('Chuschi')),
      '050203' => array('department' => '05', 'province' => '02', 'district' => '03', 'name' => t('Los morochucos')),
      '050204' => array('department' => '05', 'province' => '02', 'district' => '04', 'name' => t('Maria parado de bellido')),
      '050205' => array('department' => '05', 'province' => '02', 'district' => '05', 'name' => t('Paras')),
      '050206' => array('department' => '05', 'province' => '02', 'district' => '06', 'name' => t('Totos')),
      '050300' => array('department' => '05', 'province' => '03', 'district' => '00', 'name' => t('Huanca sancos')),
      '050301' => array('department' => '05', 'province' => '03', 'district' => '01', 'name' => t('Sancos')),
      '050302' => array('department' => '05', 'province' => '03', 'district' => '02', 'name' => t('Carapo')),
      '050303' => array('department' => '05', 'province' => '03', 'district' => '03', 'name' => t('Sacsamarca')),
      '050304' => array('department' => '05', 'province' => '03', 'district' => '04', 'name' => t('Santiago de lucanamarca')),
      '050400' => array('department' => '05', 'province' => '04', 'district' => '00', 'name' => t('Huanta')),
      '050401' => array('department' => '05', 'province' => '04', 'district' => '01', 'name' => t('Huanta')),
      '050402' => array('department' => '05', 'province' => '04', 'district' => '02', 'name' => t('Ayahuanco')),
      '050403' => array('department' => '05', 'province' => '04', 'district' => '03', 'name' => t('Huamanguilla')),
      '050404' => array('department' => '05', 'province' => '04', 'district' => '04', 'name' => t('Iguain')),
      '050405' => array('department' => '05', 'province' => '04', 'district' => '05', 'name' => t('Luricocha')),
      '050406' => array('department' => '05', 'province' => '04', 'district' => '06', 'name' => t('Santillana')),
      '050407' => array('department' => '05', 'province' => '04', 'district' => '07', 'name' => t('Sivia')),
      '050408' => array('department' => '05', 'province' => '04', 'district' => '08', 'name' => t('Llochegua')),
      '050500' => array('department' => '05', 'province' => '05', 'district' => '00', 'name' => t('La mar')),
      '050501' => array('department' => '05', 'province' => '05', 'district' => '01', 'name' => t('San miguel')),
      '050502' => array('department' => '05', 'province' => '05', 'district' => '02', 'name' => t('Anco')),
      '050503' => array('department' => '05', 'province' => '05', 'district' => '03', 'name' => t('Ayna')),
      '050504' => array('department' => '05', 'province' => '05', 'district' => '04', 'name' => t('Chilcas')),
      '050505' => array('department' => '05', 'province' => '05', 'district' => '05', 'name' => t('Chungui')),
      '050506' => array('department' => '05', 'province' => '05', 'district' => '06', 'name' => t('Luis carranza')),
      '050507' => array('department' => '05', 'province' => '05', 'district' => '07', 'name' => t('Santa rosa')),
      '050508' => array('department' => '05', 'province' => '05', 'district' => '08', 'name' => t('Tambo')),
      '050509' => array('department' => '05', 'province' => '05', 'district' => '09', 'name' => t('Samugari')),
      '050600' => array('department' => '05', 'province' => '06', 'district' => '00', 'name' => t('Lucanas')),
      '050601' => array('department' => '05', 'province' => '06', 'district' => '01', 'name' => t('Puquio')),
      '050602' => array('department' => '05', 'province' => '06', 'district' => '02', 'name' => t('Aucara')),
      '050603' => array('department' => '05', 'province' => '06', 'district' => '03', 'name' => t('Cabana')),
      '050604' => array('department' => '05', 'province' => '06', 'district' => '04', 'name' => t('Carmen salcedo')),
      '050605' => array('department' => '05', 'province' => '06', 'district' => '05', 'name' => t('Chaviña')),
      '050606' => array('department' => '05', 'province' => '06', 'district' => '06', 'name' => t('Chipao')),
      '050607' => array('department' => '05', 'province' => '06', 'district' => '07', 'name' => t('Huac-huas')),
      '050608' => array('department' => '05', 'province' => '06', 'district' => '08', 'name' => t('Laramate')),
      '050609' => array('department' => '05', 'province' => '06', 'district' => '09', 'name' => t('Leoncio prado')),
      '050610' => array('department' => '05', 'province' => '06', 'district' => '10', 'name' => t('Llauta')),
      '050611' => array('department' => '05', 'province' => '06', 'district' => '11', 'name' => t('Lucanas')),
      '050612' => array('department' => '05', 'province' => '06', 'district' => '12', 'name' => t('Ocaña')),
      '050613' => array('department' => '05', 'province' => '06', 'district' => '13', 'name' => t('Otoca')),
      '050614' => array('department' => '05', 'province' => '06', 'district' => '14', 'name' => t('Saisa')),
      '050615' => array('department' => '05', 'province' => '06', 'district' => '15', 'name' => t('San cristobal')),
      '050616' => array('department' => '05', 'province' => '06', 'district' => '16', 'name' => t('San juan')),
      '050617' => array('department' => '05', 'province' => '06', 'district' => '17', 'name' => t('San pedro')),
      '050618' => array('department' => '05', 'province' => '06', 'district' => '18', 'name' => t('San pedro de palco')),
      '050619' => array('department' => '05', 'province' => '06', 'district' => '19', 'name' => t('Sancos')),
      '050620' => array('department' => '05', 'province' => '06', 'district' => '20', 'name' => t('Santa ana de huaycahuacho')),
      '050621' => array('department' => '05', 'province' => '06', 'district' => '21', 'name' => t('Santa lucia')),
      '050700' => array('department' => '05', 'province' => '07', 'district' => '00', 'name' => t('Parinacochas')),
      '050701' => array('department' => '05', 'province' => '07', 'district' => '01', 'name' => t('Coracora')),
      '050702' => array('department' => '05', 'province' => '07', 'district' => '02', 'name' => t('Chumpi')),
      '050703' => array('department' => '05', 'province' => '07', 'district' => '03', 'name' => t('Coronel castañeda')),
      '050704' => array('department' => '05', 'province' => '07', 'district' => '04', 'name' => t('Pacapausa')),
      '050705' => array('department' => '05', 'province' => '07', 'district' => '05', 'name' => t('Pullo')),
      '050706' => array('department' => '05', 'province' => '07', 'district' => '06', 'name' => t('Puyusca')),
      '050707' => array('department' => '05', 'province' => '07', 'district' => '07', 'name' => t('San francisco de ravacayco')),
      '050708' => array('department' => '05', 'province' => '07', 'district' => '08', 'name' => t('Upahuacho')),
      '050800' => array('department' => '05', 'province' => '08', 'district' => '00', 'name' => t('Paucar del sara sara')),
      '050801' => array('department' => '05', 'province' => '08', 'district' => '01', 'name' => t('Pausa')),
      '050802' => array('department' => '05', 'province' => '08', 'district' => '02', 'name' => t('Colta')),
      '050803' => array('department' => '05', 'province' => '08', 'district' => '03', 'name' => t('Corculla')),
      '050804' => array('department' => '05', 'province' => '08', 'district' => '04', 'name' => t('Lampa')),
      '050805' => array('department' => '05', 'province' => '08', 'district' => '05', 'name' => t('Marcabamba')),
      '050806' => array('department' => '05', 'province' => '08', 'district' => '06', 'name' => t('Oyolo')),
      '050807' => array('department' => '05', 'province' => '08', 'district' => '07', 'name' => t('Pararca')),
      '050808' => array('department' => '05', 'province' => '08', 'district' => '08', 'name' => t('San javier de alpabamba')),
      '050809' => array('department' => '05', 'province' => '08', 'district' => '09', 'name' => t('San jose de ushua')),
      '050810' => array('department' => '05', 'province' => '08', 'district' => '10', 'name' => t('Sara sara')),
      '050900' => array('department' => '05', 'province' => '09', 'district' => '00', 'name' => t('Sucre')),
      '050901' => array('department' => '05', 'province' => '09', 'district' => '01', 'name' => t('Querobamba')),
      '050902' => array('department' => '05', 'province' => '09', 'district' => '02', 'name' => t('Belen')),
      '050903' => array('department' => '05', 'province' => '09', 'district' => '03', 'name' => t('Chalcos')),
      '050904' => array('department' => '05', 'province' => '09', 'district' => '04', 'name' => t('Chilcayoc')),
      '050905' => array('department' => '05', 'province' => '09', 'district' => '05', 'name' => t('Huacaña')),
      '050906' => array('department' => '05', 'province' => '09', 'district' => '06', 'name' => t('Morcolla')),
      '050907' => array('department' => '05', 'province' => '09', 'district' => '07', 'name' => t('Paico')),
      '050908' => array('department' => '05', 'province' => '09', 'district' => '08', 'name' => t('San pedro de larcay')),
      '050909' => array('department' => '05', 'province' => '09', 'district' => '09', 'name' => t('San salvador de quije')),
      '050910' => array('department' => '05', 'province' => '09', 'district' => '10', 'name' => t('Santiago de paucaray')),
      '050911' => array('department' => '05', 'province' => '09', 'district' => '11', 'name' => t('Soras')),
      '051000' => array('department' => '05', 'province' => '10', 'district' => '00', 'name' => t('Victor fajardo')),
      '051001' => array('department' => '05', 'province' => '10', 'district' => '01', 'name' => t('Huancapi')),
      '051002' => array('department' => '05', 'province' => '10', 'district' => '02', 'name' => t('Alcamenca')),
      '051003' => array('department' => '05', 'province' => '10', 'district' => '03', 'name' => t('Apongo')),
      '051004' => array('department' => '05', 'province' => '10', 'district' => '04', 'name' => t('Asquipata')),
      '051005' => array('department' => '05', 'province' => '10', 'district' => '05', 'name' => t('Canaria')),
      '051006' => array('department' => '05', 'province' => '10', 'district' => '06', 'name' => t('Cayara')),
      '051007' => array('department' => '05', 'province' => '10', 'district' => '07', 'name' => t('Colca')),
      '051008' => array('department' => '05', 'province' => '10', 'district' => '08', 'name' => t('Huamanquiquia')),
      '051009' => array('department' => '05', 'province' => '10', 'district' => '09', 'name' => t('Huancaraylla')),
      '051010' => array('department' => '05', 'province' => '10', 'district' => '10', 'name' => t('Huaya')),
      '051011' => array('department' => '05', 'province' => '10', 'district' => '11', 'name' => t('Sarhua')),
      '051012' => array('department' => '05', 'province' => '10', 'district' => '12', 'name' => t('Vilcanchos')),
      '051100' => array('department' => '05', 'province' => '11', 'district' => '00', 'name' => t('Vilcas huaman')),
      '051101' => array('department' => '05', 'province' => '11', 'district' => '01', 'name' => t('Vilcas huaman')),
      '051102' => array('department' => '05', 'province' => '11', 'district' => '02', 'name' => t('Accomarca')),
      '051103' => array('department' => '05', 'province' => '11', 'district' => '03', 'name' => t('Carhuanca')),
      '051104' => array('department' => '05', 'province' => '11', 'district' => '04', 'name' => t('Concepcion')),
      '051105' => array('department' => '05', 'province' => '11', 'district' => '05', 'name' => t('Huambalpa')),
      '051106' => array('department' => '05', 'province' => '11', 'district' => '06', 'name' => t('Independencia')),
      '051107' => array('department' => '05', 'province' => '11', 'district' => '07', 'name' => t('Saurama')),
      '051108' => array('department' => '05', 'province' => '11', 'district' => '08', 'name' => t('Vischongo')),
      '060000' => array('department' => '06', 'province' => '00', 'district' => '00', 'name' => t('Cajamarca')),
      '060100' => array('department' => '06', 'province' => '01', 'district' => '00', 'name' => t('Cajamarca')),
      '060101' => array('department' => '06', 'province' => '01', 'district' => '01', 'name' => t('Cajamarca')),
      '060102' => array('department' => '06', 'province' => '01', 'district' => '02', 'name' => t('Asuncion')),
      '060103' => array('department' => '06', 'province' => '01', 'district' => '03', 'name' => t('Chetilla')),
      '060104' => array('department' => '06', 'province' => '01', 'district' => '04', 'name' => t('Cospan')),
      '060105' => array('department' => '06', 'province' => '01', 'district' => '05', 'name' => t('Encañada')),
      '060106' => array('department' => '06', 'province' => '01', 'district' => '06', 'name' => t('Jesus')),
      '060107' => array('department' => '06', 'province' => '01', 'district' => '07', 'name' => t('Llacanora')),
      '060108' => array('department' => '06', 'province' => '01', 'district' => '08', 'name' => t('Los baños del inca')),
      '060109' => array('department' => '06', 'province' => '01', 'district' => '09', 'name' => t('Magdalena')),
      '060110' => array('department' => '06', 'province' => '01', 'district' => '10', 'name' => t('Matara')),
      '060111' => array('department' => '06', 'province' => '01', 'district' => '11', 'name' => t('Namora')),
      '060112' => array('department' => '06', 'province' => '01', 'district' => '12', 'name' => t('San juan')),
      '060200' => array('department' => '06', 'province' => '02', 'district' => '00', 'name' => t('Cajabamba')),
      '060201' => array('department' => '06', 'province' => '02', 'district' => '01', 'name' => t('Cajabamba')),
      '060202' => array('department' => '06', 'province' => '02', 'district' => '02', 'name' => t('Cachachi')),
      '060203' => array('department' => '06', 'province' => '02', 'district' => '03', 'name' => t('Condebamba')),
      '060204' => array('department' => '06', 'province' => '02', 'district' => '04', 'name' => t('Sitacocha')),
      '060300' => array('department' => '06', 'province' => '03', 'district' => '00', 'name' => t('Celendin')),
      '060301' => array('department' => '06', 'province' => '03', 'district' => '01', 'name' => t('Celendin')),
      '060302' => array('department' => '06', 'province' => '03', 'district' => '02', 'name' => t('Chumuch')),
      '060303' => array('department' => '06', 'province' => '03', 'district' => '03', 'name' => t('Cortegana')),
      '060304' => array('department' => '06', 'province' => '03', 'district' => '04', 'name' => t('Huasmin')),
      '060305' => array('department' => '06', 'province' => '03', 'district' => '05', 'name' => t('Jorge chavez')),
      '060306' => array('department' => '06', 'province' => '03', 'district' => '06', 'name' => t('Jose galvez')),
      '060307' => array('department' => '06', 'province' => '03', 'district' => '07', 'name' => t('Miguel iglesias')),
      '060308' => array('department' => '06', 'province' => '03', 'district' => '08', 'name' => t('Oxamarca')),
      '060309' => array('department' => '06', 'province' => '03', 'district' => '09', 'name' => t('Sorochuco')),
      '060310' => array('department' => '06', 'province' => '03', 'district' => '10', 'name' => t('Sucre')),
      '060311' => array('department' => '06', 'province' => '03', 'district' => '11', 'name' => t('Utco')),
      '060312' => array('department' => '06', 'province' => '03', 'district' => '12', 'name' => t('La libertad de pallan')),
      '060400' => array('department' => '06', 'province' => '04', 'district' => '00', 'name' => t('Chota')),
      '060401' => array('department' => '06', 'province' => '04', 'district' => '01', 'name' => t('Chota')),
      '060402' => array('department' => '06', 'province' => '04', 'district' => '02', 'name' => t('Anguia')),
      '060403' => array('department' => '06', 'province' => '04', 'district' => '03', 'name' => t('Chadin')),
      '060404' => array('department' => '06', 'province' => '04', 'district' => '04', 'name' => t('Chiguirip')),
      '060405' => array('department' => '06', 'province' => '04', 'district' => '05', 'name' => t('Chimban')),
      '060406' => array('department' => '06', 'province' => '04', 'district' => '06', 'name' => t('Choropampa')),
      '060407' => array('department' => '06', 'province' => '04', 'district' => '07', 'name' => t('Cochabamba')),
      '060408' => array('department' => '06', 'province' => '04', 'district' => '08', 'name' => t('Conchan')),
      '060409' => array('department' => '06', 'province' => '04', 'district' => '09', 'name' => t('Huambos')),
      '060410' => array('department' => '06', 'province' => '04', 'district' => '10', 'name' => t('Lajas')),
      '060411' => array('department' => '06', 'province' => '04', 'district' => '11', 'name' => t('Llama')),
      '060412' => array('department' => '06', 'province' => '04', 'district' => '12', 'name' => t('Miracosta')),
      '060413' => array('department' => '06', 'province' => '04', 'district' => '13', 'name' => t('Paccha')),
      '060414' => array('department' => '06', 'province' => '04', 'district' => '14', 'name' => t('Pion')),
      '060415' => array('department' => '06', 'province' => '04', 'district' => '15', 'name' => t('Querocoto')),
      '060416' => array('department' => '06', 'province' => '04', 'district' => '16', 'name' => t('San juan de licupis')),
      '060417' => array('department' => '06', 'province' => '04', 'district' => '17', 'name' => t('Tacabamba')),
      '060418' => array('department' => '06', 'province' => '04', 'district' => '18', 'name' => t('Tocmoche')),
      '060419' => array('department' => '06', 'province' => '04', 'district' => '19', 'name' => t('Chalamarca')),
      '060500' => array('department' => '06', 'province' => '05', 'district' => '00', 'name' => t('Contumaza')),
      '060501' => array('department' => '06', 'province' => '05', 'district' => '01', 'name' => t('Contumaza')),
      '060502' => array('department' => '06', 'province' => '05', 'district' => '02', 'name' => t('Chilete')),
      '060503' => array('department' => '06', 'province' => '05', 'district' => '03', 'name' => t('Cupisnique')),
      '060504' => array('department' => '06', 'province' => '05', 'district' => '04', 'name' => t('Guzmango')),
      '060505' => array('department' => '06', 'province' => '05', 'district' => '05', 'name' => t('San benito')),
      '060506' => array('department' => '06', 'province' => '05', 'district' => '06', 'name' => t('Santa cruz de toled')),
      '060507' => array('department' => '06', 'province' => '05', 'district' => '07', 'name' => t('Tantarica')),
      '060508' => array('department' => '06', 'province' => '05', 'district' => '08', 'name' => t('Yonan')),
      '060600' => array('department' => '06', 'province' => '06', 'district' => '00', 'name' => t('Cutervo')),
      '060601' => array('department' => '06', 'province' => '06', 'district' => '01', 'name' => t('Cutervo')),
      '060602' => array('department' => '06', 'province' => '06', 'district' => '02', 'name' => t('Callayuc')),
      '060603' => array('department' => '06', 'province' => '06', 'district' => '03', 'name' => t('Choros')),
      '060604' => array('department' => '06', 'province' => '06', 'district' => '04', 'name' => t('Cujillo')),
      '060605' => array('department' => '06', 'province' => '06', 'district' => '05', 'name' => t('La ramada')),
      '060606' => array('department' => '06', 'province' => '06', 'district' => '06', 'name' => t('Pimpingos')),
      '060607' => array('department' => '06', 'province' => '06', 'district' => '07', 'name' => t('Querocotillo')),
      '060608' => array('department' => '06', 'province' => '06', 'district' => '08', 'name' => t('San andres de cutervo')),
      '060609' => array('department' => '06', 'province' => '06', 'district' => '09', 'name' => t('San juan de cutervo')),
      '060610' => array('department' => '06', 'province' => '06', 'district' => '10', 'name' => t('San luis de lucma')),
      '060611' => array('department' => '06', 'province' => '06', 'district' => '11', 'name' => t('Santa cruz')),
      '060612' => array('department' => '06', 'province' => '06', 'district' => '12', 'name' => t('Santo domingo de la capilla')),
      '060613' => array('department' => '06', 'province' => '06', 'district' => '13', 'name' => t('Santo tomas')),
      '060614' => array('department' => '06', 'province' => '06', 'district' => '14', 'name' => t('Socota')),
      '060615' => array('department' => '06', 'province' => '06', 'district' => '15', 'name' => t('Toribio casanova')),
      '060700' => array('department' => '06', 'province' => '07', 'district' => '00', 'name' => t('Hualgayoc')),
      '060701' => array('department' => '06', 'province' => '07', 'district' => '01', 'name' => t('Bambamarca')),
      '060702' => array('department' => '06', 'province' => '07', 'district' => '02', 'name' => t('Chugur')),
      '060703' => array('department' => '06', 'province' => '07', 'district' => '03', 'name' => t('Hualgayoc')),
      '060800' => array('department' => '06', 'province' => '08', 'district' => '00', 'name' => t('Jaen')),
      '060801' => array('department' => '06', 'province' => '08', 'district' => '01', 'name' => t('Jaen')),
      '060802' => array('department' => '06', 'province' => '08', 'district' => '02', 'name' => t('Bellavista')),
      '060803' => array('department' => '06', 'province' => '08', 'district' => '03', 'name' => t('Chontali')),
      '060804' => array('department' => '06', 'province' => '08', 'district' => '04', 'name' => t('Colasay')),
      '060805' => array('department' => '06', 'province' => '08', 'district' => '05', 'name' => t('Huabal')),
      '060806' => array('department' => '06', 'province' => '08', 'district' => '06', 'name' => t('Las pirias')),
      '060807' => array('department' => '06', 'province' => '08', 'district' => '07', 'name' => t('Pomahuaca')),
      '060808' => array('department' => '06', 'province' => '08', 'district' => '08', 'name' => t('Pucara')),
      '060809' => array('department' => '06', 'province' => '08', 'district' => '09', 'name' => t('Sallique')),
      '060810' => array('department' => '06', 'province' => '08', 'district' => '10', 'name' => t('San felipe')),
      '060811' => array('department' => '06', 'province' => '08', 'district' => '11', 'name' => t('San jose del alto')),
      '060812' => array('department' => '06', 'province' => '08', 'district' => '12', 'name' => t('Santa rosa')),
      '060900' => array('department' => '06', 'province' => '09', 'district' => '00', 'name' => t('San ignacio')),
      '060901' => array('department' => '06', 'province' => '09', 'district' => '01', 'name' => t('San ignacio')),
      '060902' => array('department' => '06', 'province' => '09', 'district' => '02', 'name' => t('Chirinos')),
      '060903' => array('department' => '06', 'province' => '09', 'district' => '03', 'name' => t('Huarango')),
      '060904' => array('department' => '06', 'province' => '09', 'district' => '04', 'name' => t('La coipa')),
      '060905' => array('department' => '06', 'province' => '09', 'district' => '05', 'name' => t('Namballe')),
      '060906' => array('department' => '06', 'province' => '09', 'district' => '06', 'name' => t('San jose de lourdes')),
      '060907' => array('department' => '06', 'province' => '09', 'district' => '07', 'name' => t('Tabaconas')),
      '061000' => array('department' => '06', 'province' => '10', 'district' => '00', 'name' => t('San marcos')),
      '061001' => array('department' => '06', 'province' => '10', 'district' => '01', 'name' => t('Pedro galvez')),
      '061002' => array('department' => '06', 'province' => '10', 'district' => '02', 'name' => t('Chancay')),
      '061003' => array('department' => '06', 'province' => '10', 'district' => '03', 'name' => t('Eduardo villanueva')),
      '061004' => array('department' => '06', 'province' => '10', 'district' => '04', 'name' => t('Gregorio pita')),
      '061005' => array('department' => '06', 'province' => '10', 'district' => '05', 'name' => t('Ichocan')),
      '061006' => array('department' => '06', 'province' => '10', 'district' => '06', 'name' => t('Jose manuel quiroz')),
      '061007' => array('department' => '06', 'province' => '10', 'district' => '07', 'name' => t('Jose sabogal')),
      '061100' => array('department' => '06', 'province' => '11', 'district' => '00', 'name' => t('San miguel')),
      '061101' => array('department' => '06', 'province' => '11', 'district' => '01', 'name' => t('San miguel')),
      '061102' => array('department' => '06', 'province' => '11', 'district' => '02', 'name' => t('Bolivar')),
      '061103' => array('department' => '06', 'province' => '11', 'district' => '03', 'name' => t('Calquis')),
      '061104' => array('department' => '06', 'province' => '11', 'district' => '04', 'name' => t('Catilluc')),
      '061105' => array('department' => '06', 'province' => '11', 'district' => '05', 'name' => t('El prado')),
      '061106' => array('department' => '06', 'province' => '11', 'district' => '06', 'name' => t('La florida')),
      '061107' => array('department' => '06', 'province' => '11', 'district' => '07', 'name' => t('Llapa')),
      '061108' => array('department' => '06', 'province' => '11', 'district' => '08', 'name' => t('Nanchoc')),
      '061109' => array('department' => '06', 'province' => '11', 'district' => '09', 'name' => t('Niepos')),
      '061110' => array('department' => '06', 'province' => '11', 'district' => '10', 'name' => t('San gregorio')),
      '061111' => array('department' => '06', 'province' => '11', 'district' => '11', 'name' => t('San silvestre de cochan')),
      '061112' => array('department' => '06', 'province' => '11', 'district' => '12', 'name' => t('Tongod')),
      '061113' => array('department' => '06', 'province' => '11', 'district' => '13', 'name' => t('Union agua blanca')),
      '061200' => array('department' => '06', 'province' => '12', 'district' => '00', 'name' => t('San pablo')),
      '061201' => array('department' => '06', 'province' => '12', 'district' => '01', 'name' => t('San pablo')),
      '061202' => array('department' => '06', 'province' => '12', 'district' => '02', 'name' => t('San bernardino')),
      '061203' => array('department' => '06', 'province' => '12', 'district' => '03', 'name' => t('San luis')),
      '061204' => array('department' => '06', 'province' => '12', 'district' => '04', 'name' => t('Tumbaden')),
      '061300' => array('department' => '06', 'province' => '13', 'district' => '00', 'name' => t('Santa cruz')),
      '061301' => array('department' => '06', 'province' => '13', 'district' => '01', 'name' => t('Santa cruz')),
      '061302' => array('department' => '06', 'province' => '13', 'district' => '02', 'name' => t('Andabamba')),
      '061303' => array('department' => '06', 'province' => '13', 'district' => '03', 'name' => t('Catache')),
      '061304' => array('department' => '06', 'province' => '13', 'district' => '04', 'name' => t('Chancaybaños')),
      '061305' => array('department' => '06', 'province' => '13', 'district' => '05', 'name' => t('La esperanza')),
      '061306' => array('department' => '06', 'province' => '13', 'district' => '06', 'name' => t('Ninabamba')),
      '061307' => array('department' => '06', 'province' => '13', 'district' => '07', 'name' => t('Pulan')),
      '061308' => array('department' => '06', 'province' => '13', 'district' => '08', 'name' => t('Saucepampa')),
      '061309' => array('department' => '06', 'province' => '13', 'district' => '09', 'name' => t('Sexi')),
      '061310' => array('department' => '06', 'province' => '13', 'district' => '10', 'name' => t('Uticyacu')),
      '061311' => array('department' => '06', 'province' => '13', 'district' => '11', 'name' => t('Yauyucan')),
      '070000' => array('department' => '07', 'province' => '00', 'district' => '00', 'name' => t('Callao')),
      '070100' => array('department' => '07', 'province' => '01', 'district' => '00', 'name' => t('Callao')),
      '070101' => array('department' => '07', 'province' => '01', 'district' => '01', 'name' => t('Callao')),
      '070102' => array('department' => '07', 'province' => '01', 'district' => '02', 'name' => t('Bellavista')),
      '070103' => array('department' => '07', 'province' => '01', 'district' => '03', 'name' => t('Carmen de la legua reynoso')),
      '070104' => array('department' => '07', 'province' => '01', 'district' => '04', 'name' => t('La perla')),
      '070105' => array('department' => '07', 'province' => '01', 'district' => '05', 'name' => t('La punta')),
      '070106' => array('department' => '07', 'province' => '01', 'district' => '06', 'name' => t('Ventanilla')),
      '080000' => array('department' => '08', 'province' => '00', 'district' => '00', 'name' => t('Cusco')),
      '080100' => array('department' => '08', 'province' => '01', 'district' => '00', 'name' => t('Cusco')),
      '080101' => array('department' => '08', 'province' => '01', 'district' => '01', 'name' => t('Cusco')),
      '080102' => array('department' => '08', 'province' => '01', 'district' => '02', 'name' => t('Ccorca')),
      '080103' => array('department' => '08', 'province' => '01', 'district' => '03', 'name' => t('Poroy')),
      '080104' => array('department' => '08', 'province' => '01', 'district' => '04', 'name' => t('San jeronimo')),
      '080105' => array('department' => '08', 'province' => '01', 'district' => '05', 'name' => t('San sebastian')),
      '080106' => array('department' => '08', 'province' => '01', 'district' => '06', 'name' => t('Santiago')),
      '080107' => array('department' => '08', 'province' => '01', 'district' => '07', 'name' => t('Saylla')),
      '080108' => array('department' => '08', 'province' => '01', 'district' => '08', 'name' => t('Wanchaq')),
      '080200' => array('department' => '08', 'province' => '02', 'district' => '00', 'name' => t('Acomayo')),
      '080201' => array('department' => '08', 'province' => '02', 'district' => '01', 'name' => t('Acomayo')),
      '080202' => array('department' => '08', 'province' => '02', 'district' => '02', 'name' => t('Acopia')),
      '080203' => array('department' => '08', 'province' => '02', 'district' => '03', 'name' => t('Acos')),
      '080204' => array('department' => '08', 'province' => '02', 'district' => '04', 'name' => t('Mosoc llacta')),
      '080205' => array('department' => '08', 'province' => '02', 'district' => '05', 'name' => t('Pomacanchi')),
      '080206' => array('department' => '08', 'province' => '02', 'district' => '06', 'name' => t('Rondocan')),
      '080207' => array('department' => '08', 'province' => '02', 'district' => '07', 'name' => t('Sangarara')),
      '080300' => array('department' => '08', 'province' => '03', 'district' => '00', 'name' => t('Anta')),
      '080301' => array('department' => '08', 'province' => '03', 'district' => '01', 'name' => t('Anta')),
      '080302' => array('department' => '08', 'province' => '03', 'district' => '02', 'name' => t('Ancahuasi')),
      '080303' => array('department' => '08', 'province' => '03', 'district' => '03', 'name' => t('Cachimayo')),
      '080304' => array('department' => '08', 'province' => '03', 'district' => '04', 'name' => t('Chinchaypujio')),
      '080305' => array('department' => '08', 'province' => '03', 'district' => '05', 'name' => t('Huarocondo')),
      '080306' => array('department' => '08', 'province' => '03', 'district' => '06', 'name' => t('Limatambo')),
      '080307' => array('department' => '08', 'province' => '03', 'district' => '07', 'name' => t('Mollepata')),
      '080308' => array('department' => '08', 'province' => '03', 'district' => '08', 'name' => t('Pucyura')),
      '080309' => array('department' => '08', 'province' => '03', 'district' => '09', 'name' => t('Zurite')),
      '080400' => array('department' => '08', 'province' => '04', 'district' => '00', 'name' => t('Calca')),
      '080401' => array('department' => '08', 'province' => '04', 'district' => '01', 'name' => t('Calca')),
      '080402' => array('department' => '08', 'province' => '04', 'district' => '02', 'name' => t('Coya')),
      '080403' => array('department' => '08', 'province' => '04', 'district' => '03', 'name' => t('Lamay')),
      '080404' => array('department' => '08', 'province' => '04', 'district' => '04', 'name' => t('Lares')),
      '080405' => array('department' => '08', 'province' => '04', 'district' => '05', 'name' => t('Pisac')),
      '080406' => array('department' => '08', 'province' => '04', 'district' => '06', 'name' => t('San salvador')),
      '080407' => array('department' => '08', 'province' => '04', 'district' => '07', 'name' => t('Taray')),
      '080408' => array('department' => '08', 'province' => '04', 'district' => '08', 'name' => t('Yanatile')),
      '080500' => array('department' => '08', 'province' => '05', 'district' => '00', 'name' => t('Canas')),
      '080501' => array('department' => '08', 'province' => '05', 'district' => '01', 'name' => t('Yanaoca')),
      '080502' => array('department' => '08', 'province' => '05', 'district' => '02', 'name' => t('Checca')),
      '080503' => array('department' => '08', 'province' => '05', 'district' => '03', 'name' => t('Kunturkanki')),
      '080504' => array('department' => '08', 'province' => '05', 'district' => '04', 'name' => t('Langui')),
      '080505' => array('department' => '08', 'province' => '05', 'district' => '05', 'name' => t('Layo')),
      '080506' => array('department' => '08', 'province' => '05', 'district' => '06', 'name' => t('Pampamarca')),
      '080507' => array('department' => '08', 'province' => '05', 'district' => '07', 'name' => t('Quehue')),
      '080508' => array('department' => '08', 'province' => '05', 'district' => '08', 'name' => t('Tupac amaru')),
      '080600' => array('department' => '08', 'province' => '06', 'district' => '00', 'name' => t('Canchis')),
      '080601' => array('department' => '08', 'province' => '06', 'district' => '01', 'name' => t('Sicuani')),
      '080602' => array('department' => '08', 'province' => '06', 'district' => '02', 'name' => t('Checacupe')),
      '080603' => array('department' => '08', 'province' => '06', 'district' => '03', 'name' => t('Combapata')),
      '080604' => array('department' => '08', 'province' => '06', 'district' => '04', 'name' => t('Marangani')),
      '080605' => array('department' => '08', 'province' => '06', 'district' => '05', 'name' => t('Pitumarca')),
      '080606' => array('department' => '08', 'province' => '06', 'district' => '06', 'name' => t('San pablo')),
      '080607' => array('department' => '08', 'province' => '06', 'district' => '07', 'name' => t('San pedro')),
      '080608' => array('department' => '08', 'province' => '06', 'district' => '08', 'name' => t('Tinta')),
      '080700' => array('department' => '08', 'province' => '07', 'district' => '00', 'name' => t('Chumbivilcas')),
      '080701' => array('department' => '08', 'province' => '07', 'district' => '01', 'name' => t('Santo tomas')),
      '080702' => array('department' => '08', 'province' => '07', 'district' => '02', 'name' => t('Capacmarca')),
      '080703' => array('department' => '08', 'province' => '07', 'district' => '03', 'name' => t('Chamaca')),
      '080704' => array('department' => '08', 'province' => '07', 'district' => '04', 'name' => t('Colquemarca')),
      '080705' => array('department' => '08', 'province' => '07', 'district' => '05', 'name' => t('Livitaca')),
      '080706' => array('department' => '08', 'province' => '07', 'district' => '06', 'name' => t('Llusco')),
      '080707' => array('department' => '08', 'province' => '07', 'district' => '07', 'name' => t('Quiñota')),
      '080708' => array('department' => '08', 'province' => '07', 'district' => '08', 'name' => t('Velille')),
      '080800' => array('department' => '08', 'province' => '08', 'district' => '00', 'name' => t('Espinar')),
      '080801' => array('department' => '08', 'province' => '08', 'district' => '01', 'name' => t('Espinar')),
      '080802' => array('department' => '08', 'province' => '08', 'district' => '02', 'name' => t('Condoroma')),
      '080803' => array('department' => '08', 'province' => '08', 'district' => '03', 'name' => t('Coporaque')),
      '080804' => array('department' => '08', 'province' => '08', 'district' => '04', 'name' => t('Ocoruro')),
      '080805' => array('department' => '08', 'province' => '08', 'district' => '05', 'name' => t('Pallpata')),
      '080806' => array('department' => '08', 'province' => '08', 'district' => '06', 'name' => t('Pichigua')),
      '080807' => array('department' => '08', 'province' => '08', 'district' => '07', 'name' => t('Suyckutambo')),
      '080808' => array('department' => '08', 'province' => '08', 'district' => '08', 'name' => t('Alto pichigua')),
      '080900' => array('department' => '08', 'province' => '09', 'district' => '00', 'name' => t('La convencion')),
      '080901' => array('department' => '08', 'province' => '09', 'district' => '01', 'name' => t('Santa ana')),
      '080902' => array('department' => '08', 'province' => '09', 'district' => '02', 'name' => t('Echarate')),
      '080903' => array('department' => '08', 'province' => '09', 'district' => '03', 'name' => t('Huayopata')),
      '080904' => array('department' => '08', 'province' => '09', 'district' => '04', 'name' => t('Maranura')),
      '080905' => array('department' => '08', 'province' => '09', 'district' => '05', 'name' => t('Ocobamba')),
      '080906' => array('department' => '08', 'province' => '09', 'district' => '06', 'name' => t('Quellouno')),
      '080907' => array('department' => '08', 'province' => '09', 'district' => '07', 'name' => t('Kimbiri')),
      '080908' => array('department' => '08', 'province' => '09', 'district' => '08', 'name' => t('Santa teresa')),
      '080909' => array('department' => '08', 'province' => '09', 'district' => '09', 'name' => t('Vilcabamba')),
      '080910' => array('department' => '08', 'province' => '09', 'district' => '10', 'name' => t('Pichari')),
      '081000' => array('department' => '08', 'province' => '10', 'district' => '00', 'name' => t('Paruro')),
      '081001' => array('department' => '08', 'province' => '10', 'district' => '01', 'name' => t('Paruro')),
      '081002' => array('department' => '08', 'province' => '10', 'district' => '02', 'name' => t('Accha')),
      '081003' => array('department' => '08', 'province' => '10', 'district' => '03', 'name' => t('Ccapi')),
      '081004' => array('department' => '08', 'province' => '10', 'district' => '04', 'name' => t('Colcha')),
      '081005' => array('department' => '08', 'province' => '10', 'district' => '05', 'name' => t('Huanoquite')),
      '081006' => array('department' => '08', 'province' => '10', 'district' => '06', 'name' => t('Omacha')),
      '081007' => array('department' => '08', 'province' => '10', 'district' => '07', 'name' => t('Paccaritambo')),
      '081008' => array('department' => '08', 'province' => '10', 'district' => '08', 'name' => t('Pillpinto')),
      '081009' => array('department' => '08', 'province' => '10', 'district' => '09', 'name' => t('Yaurisque')),
      '081100' => array('department' => '08', 'province' => '11', 'district' => '00', 'name' => t('Paucartambo')),
      '081101' => array('department' => '08', 'province' => '11', 'district' => '01', 'name' => t('Paucartambo')),
      '081102' => array('department' => '08', 'province' => '11', 'district' => '02', 'name' => t('Caicay')),
      '081103' => array('department' => '08', 'province' => '11', 'district' => '03', 'name' => t('Challabamba')),
      '081104' => array('department' => '08', 'province' => '11', 'district' => '04', 'name' => t('Colquepata')),
      '081105' => array('department' => '08', 'province' => '11', 'district' => '05', 'name' => t('Huancarani')),
      '081106' => array('department' => '08', 'province' => '11', 'district' => '06', 'name' => t('Kosñipata')),
      '081200' => array('department' => '08', 'province' => '12', 'district' => '00', 'name' => t('Quispicanchi')),
      '081201' => array('department' => '08', 'province' => '12', 'district' => '01', 'name' => t('Urcos')),
      '081202' => array('department' => '08', 'province' => '12', 'district' => '02', 'name' => t('Andahuaylillas')),
      '081203' => array('department' => '08', 'province' => '12', 'district' => '03', 'name' => t('Camanti')),
      '081204' => array('department' => '08', 'province' => '12', 'district' => '04', 'name' => t('Ccarhuayo')),
      '081205' => array('department' => '08', 'province' => '12', 'district' => '05', 'name' => t('Ccatca')),
      '081206' => array('department' => '08', 'province' => '12', 'district' => '06', 'name' => t('Cusipata')),
      '081207' => array('department' => '08', 'province' => '12', 'district' => '07', 'name' => t('Huaro')),
      '081208' => array('department' => '08', 'province' => '12', 'district' => '08', 'name' => t('Lucre')),
      '081209' => array('department' => '08', 'province' => '12', 'district' => '09', 'name' => t('Marcapata')),
      '081210' => array('department' => '08', 'province' => '12', 'district' => '10', 'name' => t('Ocongate')),
      '081211' => array('department' => '08', 'province' => '12', 'district' => '11', 'name' => t('Oropesa')),
      '081212' => array('department' => '08', 'province' => '12', 'district' => '12', 'name' => t('Quiquijana')),
      '081300' => array('department' => '08', 'province' => '13', 'district' => '00', 'name' => t('Urubamba')),
      '081301' => array('department' => '08', 'province' => '13', 'district' => '01', 'name' => t('Urubamba')),
      '081302' => array('department' => '08', 'province' => '13', 'district' => '02', 'name' => t('Chinchero')),
      '081303' => array('department' => '08', 'province' => '13', 'district' => '03', 'name' => t('Huayllabamba')),
      '081304' => array('department' => '08', 'province' => '13', 'district' => '04', 'name' => t('Machupicchu')),
      '081305' => array('department' => '08', 'province' => '13', 'district' => '05', 'name' => t('Maras')),
      '081306' => array('department' => '08', 'province' => '13', 'district' => '06', 'name' => t('Ollantaytambo')),
      '081307' => array('department' => '08', 'province' => '13', 'district' => '07', 'name' => t('Yucay')),
      '090000' => array('department' => '09', 'province' => '00', 'district' => '00', 'name' => t('Huancavelica')),
      '090100' => array('department' => '09', 'province' => '01', 'district' => '00', 'name' => t('Huancavelica')),
      '090101' => array('department' => '09', 'province' => '01', 'district' => '01', 'name' => t('Huancavelica')),
      '090102' => array('department' => '09', 'province' => '01', 'district' => '02', 'name' => t('Acobambilla')),
      '090103' => array('department' => '09', 'province' => '01', 'district' => '03', 'name' => t('Acoria')),
      '090104' => array('department' => '09', 'province' => '01', 'district' => '04', 'name' => t('Conayca')),
      '090105' => array('department' => '09', 'province' => '01', 'district' => '05', 'name' => t('Cuenca')),
      '090106' => array('department' => '09', 'province' => '01', 'district' => '06', 'name' => t('Huachocolpa')),
      '090107' => array('department' => '09', 'province' => '01', 'district' => '07', 'name' => t('Huayllahuara')),
      '090108' => array('department' => '09', 'province' => '01', 'district' => '08', 'name' => t('Izcuchaca')),
      '090109' => array('department' => '09', 'province' => '01', 'district' => '09', 'name' => t('Laria')),
      '090110' => array('department' => '09', 'province' => '01', 'district' => '10', 'name' => t('Manta')),
      '090111' => array('department' => '09', 'province' => '01', 'district' => '11', 'name' => t('Mariscal caceres')),
      '090112' => array('department' => '09', 'province' => '01', 'district' => '12', 'name' => t('Moya')),
      '090113' => array('department' => '09', 'province' => '01', 'district' => '13', 'name' => t('Nuevo occoro')),
      '090114' => array('department' => '09', 'province' => '01', 'district' => '14', 'name' => t('Palca')),
      '090115' => array('department' => '09', 'province' => '01', 'district' => '15', 'name' => t('Pilchaca')),
      '090116' => array('department' => '09', 'province' => '01', 'district' => '16', 'name' => t('Vilca')),
      '090117' => array('department' => '09', 'province' => '01', 'district' => '17', 'name' => t('Yauli')),
      '090118' => array('department' => '09', 'province' => '01', 'district' => '18', 'name' => t('Ascension')),
      '090119' => array('department' => '09', 'province' => '01', 'district' => '19', 'name' => t('Huando')),
      '090200' => array('department' => '09', 'province' => '02', 'district' => '00', 'name' => t('Acobamba')),
      '090201' => array('department' => '09', 'province' => '02', 'district' => '01', 'name' => t('Acobamba')),
      '090202' => array('department' => '09', 'province' => '02', 'district' => '02', 'name' => t('Andabamba')),
      '090203' => array('department' => '09', 'province' => '02', 'district' => '03', 'name' => t('Anta')),
      '090204' => array('department' => '09', 'province' => '02', 'district' => '04', 'name' => t('Caja')),
      '090205' => array('department' => '09', 'province' => '02', 'district' => '05', 'name' => t('Marcas')),
      '090206' => array('department' => '09', 'province' => '02', 'district' => '06', 'name' => t('Paucara')),
      '090207' => array('department' => '09', 'province' => '02', 'district' => '07', 'name' => t('Pomacocha')),
      '090208' => array('department' => '09', 'province' => '02', 'district' => '08', 'name' => t('Rosario')),
      '090300' => array('department' => '09', 'province' => '03', 'district' => '00', 'name' => t('Angaraes')),
      '090301' => array('department' => '09', 'province' => '03', 'district' => '01', 'name' => t('Lircay')),
      '090302' => array('department' => '09', 'province' => '03', 'district' => '02', 'name' => t('Anchonga')),
      '090303' => array('department' => '09', 'province' => '03', 'district' => '03', 'name' => t('Callanmarca')),
      '090304' => array('department' => '09', 'province' => '03', 'district' => '04', 'name' => t('Ccochaccasa')),
      '090305' => array('department' => '09', 'province' => '03', 'district' => '05', 'name' => t('Chincho')),
      '090306' => array('department' => '09', 'province' => '03', 'district' => '06', 'name' => t('Congalla')),
      '090307' => array('department' => '09', 'province' => '03', 'district' => '07', 'name' => t('Huanca-huanca')),
      '090308' => array('department' => '09', 'province' => '03', 'district' => '08', 'name' => t('Huayllay grande')),
      '090309' => array('department' => '09', 'province' => '03', 'district' => '09', 'name' => t('Julcamarca')),
      '090310' => array('department' => '09', 'province' => '03', 'district' => '10', 'name' => t('San antonio de antaparco')),
      '090311' => array('department' => '09', 'province' => '03', 'district' => '11', 'name' => t('Santo tomas de pata')),
      '090312' => array('department' => '09', 'province' => '03', 'district' => '12', 'name' => t('Secclla')),
      '090400' => array('department' => '09', 'province' => '04', 'district' => '00', 'name' => t('Castrovirreyna')),
      '090401' => array('department' => '09', 'province' => '04', 'district' => '01', 'name' => t('Castrovirreyna')),
      '090402' => array('department' => '09', 'province' => '04', 'district' => '02', 'name' => t('Arma')),
      '090403' => array('department' => '09', 'province' => '04', 'district' => '03', 'name' => t('Aurahua')),
      '090404' => array('department' => '09', 'province' => '04', 'district' => '04', 'name' => t('Capillas')),
      '090405' => array('department' => '09', 'province' => '04', 'district' => '05', 'name' => t('Chupamarca')),
      '090406' => array('department' => '09', 'province' => '04', 'district' => '06', 'name' => t('Cocas')),
      '090407' => array('department' => '09', 'province' => '04', 'district' => '07', 'name' => t('Huachos')),
      '090408' => array('department' => '09', 'province' => '04', 'district' => '08', 'name' => t('Huamatambo')),
      '090409' => array('department' => '09', 'province' => '04', 'district' => '09', 'name' => t('Mollepampa')),
      '090410' => array('department' => '09', 'province' => '04', 'district' => '10', 'name' => t('San juan')),
      '090411' => array('department' => '09', 'province' => '04', 'district' => '11', 'name' => t('Santa ana')),
      '090412' => array('department' => '09', 'province' => '04', 'district' => '12', 'name' => t('Tantara')),
      '090413' => array('department' => '09', 'province' => '04', 'district' => '13', 'name' => t('Ticrapo')),
      '090500' => array('department' => '09', 'province' => '05', 'district' => '00', 'name' => t('Churcampa')),
      '090501' => array('department' => '09', 'province' => '05', 'district' => '01', 'name' => t('Churcampa')),
      '090502' => array('department' => '09', 'province' => '05', 'district' => '02', 'name' => t('Anco')),
      '090503' => array('department' => '09', 'province' => '05', 'district' => '03', 'name' => t('Chinchihuasi')),
      '090504' => array('department' => '09', 'province' => '05', 'district' => '04', 'name' => t('El carmen')),
      '090505' => array('department' => '09', 'province' => '05', 'district' => '05', 'name' => t('La merced')),
      '090506' => array('department' => '09', 'province' => '05', 'district' => '06', 'name' => t('Locroja')),
      '090507' => array('department' => '09', 'province' => '05', 'district' => '07', 'name' => t('Paucarbamba')),
      '090508' => array('department' => '09', 'province' => '05', 'district' => '08', 'name' => t('San miguel de mayocc')),
      '090509' => array('department' => '09', 'province' => '05', 'district' => '09', 'name' => t('San pedro de coris')),
      '090510' => array('department' => '09', 'province' => '05', 'district' => '10', 'name' => t('Pachamarca')),
      '090511' => array('department' => '09', 'province' => '05', 'district' => '11', 'name' => t('Cosme')),
      '090600' => array('department' => '09', 'province' => '06', 'district' => '00', 'name' => t('Huaytara')),
      '090601' => array('department' => '09', 'province' => '06', 'district' => '01', 'name' => t('Huaytara')),
      '090602' => array('department' => '09', 'province' => '06', 'district' => '02', 'name' => t('Ayavi')),
      '090603' => array('department' => '09', 'province' => '06', 'district' => '03', 'name' => t('Cordova')),
      '090604' => array('department' => '09', 'province' => '06', 'district' => '04', 'name' => t('Huayacundo arma')),
      '090605' => array('department' => '09', 'province' => '06', 'district' => '05', 'name' => t('Laramarca')),
      '090606' => array('department' => '09', 'province' => '06', 'district' => '06', 'name' => t('Ocoyo')),
      '090607' => array('department' => '09', 'province' => '06', 'district' => '07', 'name' => t('Pilpichaca')),
      '090608' => array('department' => '09', 'province' => '06', 'district' => '08', 'name' => t('Querco')),
      '090609' => array('department' => '09', 'province' => '06', 'district' => '09', 'name' => t('Quito-arma')),
      '090610' => array('department' => '09', 'province' => '06', 'district' => '10', 'name' => t('San antonio de cusicancha')),
      '090611' => array('department' => '09', 'province' => '06', 'district' => '11', 'name' => t('San francisco de sangayaico')),
      '090612' => array('department' => '09', 'province' => '06', 'district' => '12', 'name' => t('San isidro')),
      '090613' => array('department' => '09', 'province' => '06', 'district' => '13', 'name' => t('Santiago de chocorvos')),
      '090614' => array('department' => '09', 'province' => '06', 'district' => '14', 'name' => t('Santiago de quirahuara')),
      '090615' => array('department' => '09', 'province' => '06', 'district' => '15', 'name' => t('Santo domingo de capillas')),
      '090616' => array('department' => '09', 'province' => '06', 'district' => '16', 'name' => t('Tambo')),
      '090700' => array('department' => '09', 'province' => '07', 'district' => '00', 'name' => t('Tayacaja')),
      '090701' => array('department' => '09', 'province' => '07', 'district' => '01', 'name' => t('Pampas')),
      '090702' => array('department' => '09', 'province' => '07', 'district' => '02', 'name' => t('Acostambo')),
      '090703' => array('department' => '09', 'province' => '07', 'district' => '03', 'name' => t('Acraquia')),
      '090704' => array('department' => '09', 'province' => '07', 'district' => '04', 'name' => t('Ahuaycha')),
      '090705' => array('department' => '09', 'province' => '07', 'district' => '05', 'name' => t('Colcabamba')),
      '090706' => array('department' => '09', 'province' => '07', 'district' => '06', 'name' => t('Daniel hernandez')),
      '090707' => array('department' => '09', 'province' => '07', 'district' => '07', 'name' => t('Huachocolpa')),
      '090709' => array('department' => '09', 'province' => '07', 'district' => '09', 'name' => t('Huaribamba')),
      '090710' => array('department' => '09', 'province' => '07', 'district' => '10', 'name' => t('Ñahuimpuquio')),
      '090711' => array('department' => '09', 'province' => '07', 'district' => '11', 'name' => t('Pazos')),
      '090713' => array('department' => '09', 'province' => '07', 'district' => '13', 'name' => t('Quishuar')),
      '090714' => array('department' => '09', 'province' => '07', 'district' => '14', 'name' => t('Salcabamba')),
      '090715' => array('department' => '09', 'province' => '07', 'district' => '15', 'name' => t('Salcahuasi')),
      '090716' => array('department' => '09', 'province' => '07', 'district' => '16', 'name' => t('San marcos de rocchac')),
      '090717' => array('department' => '09', 'province' => '07', 'district' => '17', 'name' => t('Surcubamba')),
      '090718' => array('department' => '09', 'province' => '07', 'district' => '18', 'name' => t('Tintay puncu')),
      '100000' => array('department' => '10', 'province' => '00', 'district' => '00', 'name' => t('Huanuco')),
      '100100' => array('department' => '10', 'province' => '01', 'district' => '00', 'name' => t('Huanuco')),
      '100101' => array('department' => '10', 'province' => '01', 'district' => '01', 'name' => t('Huanuco')),
      '100102' => array('department' => '10', 'province' => '01', 'district' => '02', 'name' => t('Amarilis')),
      '100103' => array('department' => '10', 'province' => '01', 'district' => '03', 'name' => t('Chinchao')),
      '100104' => array('department' => '10', 'province' => '01', 'district' => '04', 'name' => t('Churubamba')),
      '100105' => array('department' => '10', 'province' => '01', 'district' => '05', 'name' => t('Margos')),
      '100106' => array('department' => '10', 'province' => '01', 'district' => '06', 'name' => t('Quisqui (kichki)')),
      '100107' => array('department' => '10', 'province' => '01', 'district' => '07', 'name' => t('San francisco de cayran')),
      '100108' => array('department' => '10', 'province' => '01', 'district' => '08', 'name' => t('San pedro de chaulan')),
      '100109' => array('department' => '10', 'province' => '01', 'district' => '09', 'name' => t('Santa maria del valle')),
      '100110' => array('department' => '10', 'province' => '01', 'district' => '10', 'name' => t('Yarumayo')),
      '100111' => array('department' => '10', 'province' => '01', 'district' => '11', 'name' => t('Pillco marca')),
      '100112' => array('department' => '10', 'province' => '01', 'district' => '12', 'name' => t('Yacus')),
      '100200' => array('department' => '10', 'province' => '02', 'district' => '00', 'name' => t('Ambo')),
      '100201' => array('department' => '10', 'province' => '02', 'district' => '01', 'name' => t('Ambo')),
      '100202' => array('department' => '10', 'province' => '02', 'district' => '02', 'name' => t('Cayna')),
      '100203' => array('department' => '10', 'province' => '02', 'district' => '03', 'name' => t('Colpas')),
      '100204' => array('department' => '10', 'province' => '02', 'district' => '04', 'name' => t('Conchamarca')),
      '100205' => array('department' => '10', 'province' => '02', 'district' => '05', 'name' => t('Huacar')),
      '100206' => array('department' => '10', 'province' => '02', 'district' => '06', 'name' => t('San francisco')),
      '100207' => array('department' => '10', 'province' => '02', 'district' => '07', 'name' => t('San rafael')),
      '100208' => array('department' => '10', 'province' => '02', 'district' => '08', 'name' => t('Tomay kichwa')),
      '100300' => array('department' => '10', 'province' => '03', 'district' => '00', 'name' => t('Dos de mayo')),
      '100301' => array('department' => '10', 'province' => '03', 'district' => '01', 'name' => t('La union')),
      '100307' => array('department' => '10', 'province' => '03', 'district' => '07', 'name' => t('Chuquis')),
      '100311' => array('department' => '10', 'province' => '03', 'district' => '11', 'name' => t('Marias')),
      '100313' => array('department' => '10', 'province' => '03', 'district' => '13', 'name' => t('Pachas')),
      '100316' => array('department' => '10', 'province' => '03', 'district' => '16', 'name' => t('Quivilla')),
      '100317' => array('department' => '10', 'province' => '03', 'district' => '17', 'name' => t('Ripan')),
      '100321' => array('department' => '10', 'province' => '03', 'district' => '21', 'name' => t('Shunqui')),
      '100322' => array('department' => '10', 'province' => '03', 'district' => '22', 'name' => t('Sillapata')),
      '100323' => array('department' => '10', 'province' => '03', 'district' => '23', 'name' => t('Yanas')),
      '100400' => array('department' => '10', 'province' => '04', 'district' => '00', 'name' => t('Huacaybamba')),
      '100401' => array('department' => '10', 'province' => '04', 'district' => '01', 'name' => t('Huacaybamba')),
      '100402' => array('department' => '10', 'province' => '04', 'district' => '02', 'name' => t('Canchabamba')),
      '100403' => array('department' => '10', 'province' => '04', 'district' => '03', 'name' => t('Cochabamba')),
      '100404' => array('department' => '10', 'province' => '04', 'district' => '04', 'name' => t('Pinra')),
      '100500' => array('department' => '10', 'province' => '05', 'district' => '00', 'name' => t('Huamalies')),
      '100501' => array('department' => '10', 'province' => '05', 'district' => '01', 'name' => t('Llata')),
      '100502' => array('department' => '10', 'province' => '05', 'district' => '02', 'name' => t('Arancay')),
      '100503' => array('department' => '10', 'province' => '05', 'district' => '03', 'name' => t('Chavin de pariarca')),
      '100504' => array('department' => '10', 'province' => '05', 'district' => '04', 'name' => t('Jacas grande')),
      '100505' => array('department' => '10', 'province' => '05', 'district' => '05', 'name' => t('Jircan')),
      '100506' => array('department' => '10', 'province' => '05', 'district' => '06', 'name' => t('Miraflores')),
      '100507' => array('department' => '10', 'province' => '05', 'district' => '07', 'name' => t('Monzon')),
      '100508' => array('department' => '10', 'province' => '05', 'district' => '08', 'name' => t('Punchao')),
      '100509' => array('department' => '10', 'province' => '05', 'district' => '09', 'name' => t('Puños')),
      '100510' => array('department' => '10', 'province' => '05', 'district' => '10', 'name' => t('Singa')),
      '100511' => array('department' => '10', 'province' => '05', 'district' => '11', 'name' => t('Tantamayo')),
      '100600' => array('department' => '10', 'province' => '06', 'district' => '00', 'name' => t('Leoncio prado')),
      '100601' => array('department' => '10', 'province' => '06', 'district' => '01', 'name' => t('Rupa-rupa')),
      '100602' => array('department' => '10', 'province' => '06', 'district' => '02', 'name' => t('Daniel alomia robles')),
      '100603' => array('department' => '10', 'province' => '06', 'district' => '03', 'name' => t('Hermilio valdizan')),
      '100604' => array('department' => '10', 'province' => '06', 'district' => '04', 'name' => t('Jose crespo y castillo')),
      '100605' => array('department' => '10', 'province' => '06', 'district' => '05', 'name' => t('Luyando')),
      '100606' => array('department' => '10', 'province' => '06', 'district' => '06', 'name' => t('Mariano damaso beraun')),
      '100700' => array('department' => '10', 'province' => '07', 'district' => '00', 'name' => t('Marañon')),
      '100701' => array('department' => '10', 'province' => '07', 'district' => '01', 'name' => t('Huacrachuco')),
      '100702' => array('department' => '10', 'province' => '07', 'district' => '02', 'name' => t('Cholon')),
      '100703' => array('department' => '10', 'province' => '07', 'district' => '03', 'name' => t('San buenaventura')),
      '100800' => array('department' => '10', 'province' => '08', 'district' => '00', 'name' => t('Pachitea')),
      '100801' => array('department' => '10', 'province' => '08', 'district' => '01', 'name' => t('Panao')),
      '100802' => array('department' => '10', 'province' => '08', 'district' => '02', 'name' => t('Chaglla')),
      '100803' => array('department' => '10', 'province' => '08', 'district' => '03', 'name' => t('Molino')),
      '100804' => array('department' => '10', 'province' => '08', 'district' => '04', 'name' => t('Umari')),
      '100900' => array('department' => '10', 'province' => '09', 'district' => '00', 'name' => t('Puerto inca')),
      '100901' => array('department' => '10', 'province' => '09', 'district' => '01', 'name' => t('Puerto inca')),
      '100902' => array('department' => '10', 'province' => '09', 'district' => '02', 'name' => t('Codo del pozuzo')),
      '100903' => array('department' => '10', 'province' => '09', 'district' => '03', 'name' => t('Honoria')),
      '100904' => array('department' => '10', 'province' => '09', 'district' => '04', 'name' => t('Tournavista')),
      '100905' => array('department' => '10', 'province' => '09', 'district' => '05', 'name' => t('Yuyapichis')),
      '101000' => array('department' => '10', 'province' => '10', 'district' => '00', 'name' => t('Lauricocha')),
      '101001' => array('department' => '10', 'province' => '10', 'district' => '01', 'name' => t('Jesus')),
      '101002' => array('department' => '10', 'province' => '10', 'district' => '02', 'name' => t('Baños')),
      '101003' => array('department' => '10', 'province' => '10', 'district' => '03', 'name' => t('Jivia')),
      '101004' => array('department' => '10', 'province' => '10', 'district' => '04', 'name' => t('Queropalca')),
      '101005' => array('department' => '10', 'province' => '10', 'district' => '05', 'name' => t('Rondos')),
      '101006' => array('department' => '10', 'province' => '10', 'district' => '06', 'name' => t('San francisco de asis')),
      '101007' => array('department' => '10', 'province' => '10', 'district' => '07', 'name' => t('San miguel de cauri')),
      '101100' => array('department' => '10', 'province' => '11', 'district' => '00', 'name' => t('Yarowilca')),
      '101101' => array('department' => '10', 'province' => '11', 'district' => '01', 'name' => t('Chavinillo')),
      '101102' => array('department' => '10', 'province' => '11', 'district' => '02', 'name' => t('Cahuac')),
      '101103' => array('department' => '10', 'province' => '11', 'district' => '03', 'name' => t('Chacabamba')),
      '101104' => array('department' => '10', 'province' => '11', 'district' => '04', 'name' => t('Aparicio pomares')),
      '101105' => array('department' => '10', 'province' => '11', 'district' => '05', 'name' => t('Jacas chico')),
      '101106' => array('department' => '10', 'province' => '11', 'district' => '06', 'name' => t('Obas')),
      '101107' => array('department' => '10', 'province' => '11', 'district' => '07', 'name' => t('Pampamarca')),
      '101108' => array('department' => '10', 'province' => '11', 'district' => '08', 'name' => t('Choras')),
      '110000' => array('department' => '11', 'province' => '00', 'district' => '00', 'name' => t('Ica')),
      '110100' => array('department' => '11', 'province' => '01', 'district' => '00', 'name' => t('Ica')),
      '110101' => array('department' => '11', 'province' => '01', 'district' => '01', 'name' => t('Ica')),
      '110102' => array('department' => '11', 'province' => '01', 'district' => '02', 'name' => t('La tinguiña')),
      '110103' => array('department' => '11', 'province' => '01', 'district' => '03', 'name' => t('Los aquijes')),
      '110104' => array('department' => '11', 'province' => '01', 'district' => '04', 'name' => t('Ocucaje')),
      '110105' => array('department' => '11', 'province' => '01', 'district' => '05', 'name' => t('Pachacutec')),
      '110106' => array('department' => '11', 'province' => '01', 'district' => '06', 'name' => t('Parcona')),
      '110107' => array('department' => '11', 'province' => '01', 'district' => '07', 'name' => t('Pueblo nuevo')),
      '110108' => array('department' => '11', 'province' => '01', 'district' => '08', 'name' => t('Salas')),
      '110109' => array('department' => '11', 'province' => '01', 'district' => '09', 'name' => t('San jose de los molinos')),
      '110110' => array('department' => '11', 'province' => '01', 'district' => '10', 'name' => t('San juan bautista')),
      '110111' => array('department' => '11', 'province' => '01', 'district' => '11', 'name' => t('Santiago')),
      '110112' => array('department' => '11', 'province' => '01', 'district' => '12', 'name' => t('Subtanjalla')),
      '110113' => array('department' => '11', 'province' => '01', 'district' => '13', 'name' => t('Tate')),
      '110114' => array('department' => '11', 'province' => '01', 'district' => '14', 'name' => t('Yauca del rosario')),
      '110200' => array('department' => '11', 'province' => '02', 'district' => '00', 'name' => t('Chincha')),
      '110201' => array('department' => '11', 'province' => '02', 'district' => '01', 'name' => t('Chincha alta')),
      '110202' => array('department' => '11', 'province' => '02', 'district' => '02', 'name' => t('Alto laran')),
      '110203' => array('department' => '11', 'province' => '02', 'district' => '03', 'name' => t('Chavin')),
      '110204' => array('department' => '11', 'province' => '02', 'district' => '04', 'name' => t('Chincha baja')),
      '110205' => array('department' => '11', 'province' => '02', 'district' => '05', 'name' => t('El carmen')),
      '110206' => array('department' => '11', 'province' => '02', 'district' => '06', 'name' => t('Grocio prado')),
      '110207' => array('department' => '11', 'province' => '02', 'district' => '07', 'name' => t('Pueblo nuevo')),
      '110208' => array('department' => '11', 'province' => '02', 'district' => '08', 'name' => t('San juan de yanac')),
      '110209' => array('department' => '11', 'province' => '02', 'district' => '09', 'name' => t('San pedro de huacarpana')),
      '110210' => array('department' => '11', 'province' => '02', 'district' => '10', 'name' => t('Sunampe')),
      '110211' => array('department' => '11', 'province' => '02', 'district' => '11', 'name' => t('Tambo de mora')),
      '110300' => array('department' => '11', 'province' => '03', 'district' => '00', 'name' => t('Nazca')),
      '110301' => array('department' => '11', 'province' => '03', 'district' => '01', 'name' => t('Nazca')),
      '110302' => array('department' => '11', 'province' => '03', 'district' => '02', 'name' => t('Changuillo')),
      '110303' => array('department' => '11', 'province' => '03', 'district' => '03', 'name' => t('El ingenio')),
      '110304' => array('department' => '11', 'province' => '03', 'district' => '04', 'name' => t('Marcona')),
      '110305' => array('department' => '11', 'province' => '03', 'district' => '05', 'name' => t('Vista alegre')),
      '110400' => array('department' => '11', 'province' => '04', 'district' => '00', 'name' => t('Palpa')),
      '110401' => array('department' => '11', 'province' => '04', 'district' => '01', 'name' => t('Palpa')),
      '110402' => array('department' => '11', 'province' => '04', 'district' => '02', 'name' => t('Llipata')),
      '110403' => array('department' => '11', 'province' => '04', 'district' => '03', 'name' => t('Rio grande')),
      '110404' => array('department' => '11', 'province' => '04', 'district' => '04', 'name' => t('Santa cruz')),
      '110405' => array('department' => '11', 'province' => '04', 'district' => '05', 'name' => t('Tibillo')),
      '110500' => array('department' => '11', 'province' => '05', 'district' => '00', 'name' => t('Pisco')),
      '110501' => array('department' => '11', 'province' => '05', 'district' => '01', 'name' => t('Pisco')),
      '110502' => array('department' => '11', 'province' => '05', 'district' => '02', 'name' => t('Huancano')),
      '110503' => array('department' => '11', 'province' => '05', 'district' => '03', 'name' => t('Humay')),
      '110504' => array('department' => '11', 'province' => '05', 'district' => '04', 'name' => t('Independencia')),
      '110505' => array('department' => '11', 'province' => '05', 'district' => '05', 'name' => t('Paracas')),
      '110506' => array('department' => '11', 'province' => '05', 'district' => '06', 'name' => t('San andres')),
      '110507' => array('department' => '11', 'province' => '05', 'district' => '07', 'name' => t('San clemente')),
      '110508' => array('department' => '11', 'province' => '05', 'district' => '08', 'name' => t('Tupac amaru inca')),
      '120000' => array('department' => '12', 'province' => '00', 'district' => '00', 'name' => t('Junin')),
      '120100' => array('department' => '12', 'province' => '01', 'district' => '00', 'name' => t('Huancayo')),
      '120101' => array('department' => '12', 'province' => '01', 'district' => '01', 'name' => t('Huancayo')),
      '120104' => array('department' => '12', 'province' => '01', 'district' => '04', 'name' => t('Carhuacallanga')),
      '120105' => array('department' => '12', 'province' => '01', 'district' => '05', 'name' => t('Chacapampa')),
      '120106' => array('department' => '12', 'province' => '01', 'district' => '06', 'name' => t('Chicche')),
      '120107' => array('department' => '12', 'province' => '01', 'district' => '07', 'name' => t('Chilca')),
      '120108' => array('department' => '12', 'province' => '01', 'district' => '08', 'name' => t('Chongos alto')),
      '120111' => array('department' => '12', 'province' => '01', 'district' => '11', 'name' => t('Chupuro')),
      '120112' => array('department' => '12', 'province' => '01', 'district' => '12', 'name' => t('Colca')),
      '120113' => array('department' => '12', 'province' => '01', 'district' => '13', 'name' => t('Cullhuas')),
      '120114' => array('department' => '12', 'province' => '01', 'district' => '14', 'name' => t('El tambo')),
      '120116' => array('department' => '12', 'province' => '01', 'district' => '16', 'name' => t('Huacrapuquio')),
      '120117' => array('department' => '12', 'province' => '01', 'district' => '17', 'name' => t('Hualhuas')),
      '120119' => array('department' => '12', 'province' => '01', 'district' => '19', 'name' => t('Huancan')),
      '120120' => array('department' => '12', 'province' => '01', 'district' => '20', 'name' => t('Huasicancha')),
      '120121' => array('department' => '12', 'province' => '01', 'district' => '21', 'name' => t('Huayucachi')),
      '120122' => array('department' => '12', 'province' => '01', 'district' => '22', 'name' => t('Ingenio')),
      '120124' => array('department' => '12', 'province' => '01', 'district' => '24', 'name' => t('Pariahuanca')),
      '120125' => array('department' => '12', 'province' => '01', 'district' => '25', 'name' => t('Pilcomayo')),
      '120126' => array('department' => '12', 'province' => '01', 'district' => '26', 'name' => t('Pucara')),
      '120127' => array('department' => '12', 'province' => '01', 'district' => '27', 'name' => t('Quichuay')),
      '120128' => array('department' => '12', 'province' => '01', 'district' => '28', 'name' => t('Quilcas')),
      '120129' => array('department' => '12', 'province' => '01', 'district' => '29', 'name' => t('San agustin')),
      '120130' => array('department' => '12', 'province' => '01', 'district' => '30', 'name' => t('San jeronimo de tunan')),
      '120132' => array('department' => '12', 'province' => '01', 'district' => '32', 'name' => t('Saño')),
      '120133' => array('department' => '12', 'province' => '01', 'district' => '33', 'name' => t('Sapallanga')),
      '120134' => array('department' => '12', 'province' => '01', 'district' => '34', 'name' => t('Sicaya')),
      '120135' => array('department' => '12', 'province' => '01', 'district' => '35', 'name' => t('Santo domingo de acobamba')),
      '120136' => array('department' => '12', 'province' => '01', 'district' => '36', 'name' => t('Viques')),
      '120200' => array('department' => '12', 'province' => '02', 'district' => '00', 'name' => t('Concepcion')),
      '120201' => array('department' => '12', 'province' => '02', 'district' => '01', 'name' => t('Concepcion')),
      '120202' => array('department' => '12', 'province' => '02', 'district' => '02', 'name' => t('Aco')),
      '120203' => array('department' => '12', 'province' => '02', 'district' => '03', 'name' => t('Andamarca')),
      '120204' => array('department' => '12', 'province' => '02', 'district' => '04', 'name' => t('Chambara')),
      '120205' => array('department' => '12', 'province' => '02', 'district' => '05', 'name' => t('Cochas')),
      '120206' => array('department' => '12', 'province' => '02', 'district' => '06', 'name' => t('Comas')),
      '120207' => array('department' => '12', 'province' => '02', 'district' => '07', 'name' => t('Heroinas toledo')),
      '120208' => array('department' => '12', 'province' => '02', 'district' => '08', 'name' => t('Manzanares')),
      '120209' => array('department' => '12', 'province' => '02', 'district' => '09', 'name' => t('Mariscal castilla')),
      '120210' => array('department' => '12', 'province' => '02', 'district' => '10', 'name' => t('Matahuasi')),
      '120211' => array('department' => '12', 'province' => '02', 'district' => '11', 'name' => t('Mito')),
      '120212' => array('department' => '12', 'province' => '02', 'district' => '12', 'name' => t('Nueve de julio')),
      '120213' => array('department' => '12', 'province' => '02', 'district' => '13', 'name' => t('Orcotuna')),
      '120214' => array('department' => '12', 'province' => '02', 'district' => '14', 'name' => t('San jose de quero')),
      '120215' => array('department' => '12', 'province' => '02', 'district' => '15', 'name' => t('Santa rosa de ocopa')),
      '120300' => array('department' => '12', 'province' => '03', 'district' => '00', 'name' => t('Chanchamayo')),
      '120301' => array('department' => '12', 'province' => '03', 'district' => '01', 'name' => t('Chanchamayo')),
      '120302' => array('department' => '12', 'province' => '03', 'district' => '02', 'name' => t('Perene')),
      '120303' => array('department' => '12', 'province' => '03', 'district' => '03', 'name' => t('Pichanaqui')),
      '120304' => array('department' => '12', 'province' => '03', 'district' => '04', 'name' => t('San luis de shuaro')),
      '120305' => array('department' => '12', 'province' => '03', 'district' => '05', 'name' => t('San ramon')),
      '120306' => array('department' => '12', 'province' => '03', 'district' => '06', 'name' => t('Vitoc')),
      '120400' => array('department' => '12', 'province' => '04', 'district' => '00', 'name' => t('Jauja')),
      '120401' => array('department' => '12', 'province' => '04', 'district' => '01', 'name' => t('Jauja')),
      '120402' => array('department' => '12', 'province' => '04', 'district' => '02', 'name' => t('Acolla')),
      '120403' => array('department' => '12', 'province' => '04', 'district' => '03', 'name' => t('Apata')),
      '120404' => array('department' => '12', 'province' => '04', 'district' => '04', 'name' => t('Ataura')),
      '120405' => array('department' => '12', 'province' => '04', 'district' => '05', 'name' => t('Canchayllo')),
      '120406' => array('department' => '12', 'province' => '04', 'district' => '06', 'name' => t('Curicaca')),
      '120407' => array('department' => '12', 'province' => '04', 'district' => '07', 'name' => t('El mantaro')),
      '120408' => array('department' => '12', 'province' => '04', 'district' => '08', 'name' => t('Huamali')),
      '120409' => array('department' => '12', 'province' => '04', 'district' => '09', 'name' => t('Huaripampa')),
      '120410' => array('department' => '12', 'province' => '04', 'district' => '10', 'name' => t('Huertas')),
      '120411' => array('department' => '12', 'province' => '04', 'district' => '11', 'name' => t('Janjaillo')),
      '120412' => array('department' => '12', 'province' => '04', 'district' => '12', 'name' => t('Julcan')),
      '120413' => array('department' => '12', 'province' => '04', 'district' => '13', 'name' => t('Leonor ordoñez')),
      '120414' => array('department' => '12', 'province' => '04', 'district' => '14', 'name' => t('Llocllapampa')),
      '120415' => array('department' => '12', 'province' => '04', 'district' => '15', 'name' => t('Marco')),
      '120416' => array('department' => '12', 'province' => '04', 'district' => '16', 'name' => t('Masma')),
      '120417' => array('department' => '12', 'province' => '04', 'district' => '17', 'name' => t('Masma chicche')),
      '120418' => array('department' => '12', 'province' => '04', 'district' => '18', 'name' => t('Molinos')),
      '120419' => array('department' => '12', 'province' => '04', 'district' => '19', 'name' => t('Monobamba')),
      '120420' => array('department' => '12', 'province' => '04', 'district' => '20', 'name' => t('Muqui')),
      '120421' => array('department' => '12', 'province' => '04', 'district' => '21', 'name' => t('Muquiyauyo')),
      '120422' => array('department' => '12', 'province' => '04', 'district' => '22', 'name' => t('Paca')),
      '120423' => array('department' => '12', 'province' => '04', 'district' => '23', 'name' => t('Paccha')),
      '120424' => array('department' => '12', 'province' => '04', 'district' => '24', 'name' => t('Pancan')),
      '120425' => array('department' => '12', 'province' => '04', 'district' => '25', 'name' => t('Parco')),
      '120426' => array('department' => '12', 'province' => '04', 'district' => '26', 'name' => t('Pomacancha')),
      '120427' => array('department' => '12', 'province' => '04', 'district' => '27', 'name' => t('Ricran')),
      '120428' => array('department' => '12', 'province' => '04', 'district' => '28', 'name' => t('San lorenzo')),
      '120429' => array('department' => '12', 'province' => '04', 'district' => '29', 'name' => t('San pedro de chunan')),
      '120430' => array('department' => '12', 'province' => '04', 'district' => '30', 'name' => t('Sausa')),
      '120431' => array('department' => '12', 'province' => '04', 'district' => '31', 'name' => t('Sincos')),
      '120432' => array('department' => '12', 'province' => '04', 'district' => '32', 'name' => t('Tunan marca')),
      '120433' => array('department' => '12', 'province' => '04', 'district' => '33', 'name' => t('Yauli')),
      '120434' => array('department' => '12', 'province' => '04', 'district' => '34', 'name' => t('Yauyos')),
      '120500' => array('department' => '12', 'province' => '05', 'district' => '00', 'name' => t('Junin')),
      '120501' => array('department' => '12', 'province' => '05', 'district' => '01', 'name' => t('Junin')),
      '120502' => array('department' => '12', 'province' => '05', 'district' => '02', 'name' => t('Carhuamayo')),
      '120503' => array('department' => '12', 'province' => '05', 'district' => '03', 'name' => t('Ondores')),
      '120504' => array('department' => '12', 'province' => '05', 'district' => '04', 'name' => t('Ulcumayo')),
      '120600' => array('department' => '12', 'province' => '06', 'district' => '00', 'name' => t('Satipo')),
      '120601' => array('department' => '12', 'province' => '06', 'district' => '01', 'name' => t('Satipo')),
      '120602' => array('department' => '12', 'province' => '06', 'district' => '02', 'name' => t('Coviriali')),
      '120603' => array('department' => '12', 'province' => '06', 'district' => '03', 'name' => t('Llaylla')),
      '120605' => array('department' => '12', 'province' => '06', 'district' => '05', 'name' => t('Pampa hermosa')),
      '120607' => array('department' => '12', 'province' => '06', 'district' => '07', 'name' => t('Rio negro')),
      '120608' => array('department' => '12', 'province' => '06', 'district' => '08', 'name' => t('Rio tambo')),
      '120699' => array('department' => '12', 'province' => '06', 'district' => '99', 'name' => t('Mazamari - pangoa')),
      '120700' => array('department' => '12', 'province' => '07', 'district' => '00', 'name' => t('Tarma')),
      '120701' => array('department' => '12', 'province' => '07', 'district' => '01', 'name' => t('Tarma')),
      '120702' => array('department' => '12', 'province' => '07', 'district' => '02', 'name' => t('Acobamba')),
      '120703' => array('department' => '12', 'province' => '07', 'district' => '03', 'name' => t('Huaricolca')),
      '120704' => array('department' => '12', 'province' => '07', 'district' => '04', 'name' => t('Huasahuasi')),
      '120705' => array('department' => '12', 'province' => '07', 'district' => '05', 'name' => t('La union')),
      '120706' => array('department' => '12', 'province' => '07', 'district' => '06', 'name' => t('Palca')),
      '120707' => array('department' => '12', 'province' => '07', 'district' => '07', 'name' => t('Palcamayo')),
      '120708' => array('department' => '12', 'province' => '07', 'district' => '08', 'name' => t('San pedro de cajas')),
      '120709' => array('department' => '12', 'province' => '07', 'district' => '09', 'name' => t('Tapo')),
      '120800' => array('department' => '12', 'province' => '08', 'district' => '00', 'name' => t('Yauli')),
      '120801' => array('department' => '12', 'province' => '08', 'district' => '01', 'name' => t('La oroya')),
      '120802' => array('department' => '12', 'province' => '08', 'district' => '02', 'name' => t('Chacapalpa')),
      '120803' => array('department' => '12', 'province' => '08', 'district' => '03', 'name' => t('Huay-huay')),
      '120804' => array('department' => '12', 'province' => '08', 'district' => '04', 'name' => t('Marcapomacocha')),
      '120805' => array('department' => '12', 'province' => '08', 'district' => '05', 'name' => t('Morococha')),
      '120806' => array('department' => '12', 'province' => '08', 'district' => '06', 'name' => t('Paccha')),
      '120807' => array('department' => '12', 'province' => '08', 'district' => '07', 'name' => t('Santa barbara de carhuacayan')),
      '120808' => array('department' => '12', 'province' => '08', 'district' => '08', 'name' => t('Santa rosa de sacco')),
      '120809' => array('department' => '12', 'province' => '08', 'district' => '09', 'name' => t('Suitucancha')),
      '120810' => array('department' => '12', 'province' => '08', 'district' => '10', 'name' => t('Yauli')),
      '120900' => array('department' => '12', 'province' => '09', 'district' => '00', 'name' => t('Chupaca')),
      '120901' => array('department' => '12', 'province' => '09', 'district' => '01', 'name' => t('Chupaca')),
      '120902' => array('department' => '12', 'province' => '09', 'district' => '02', 'name' => t('Ahuac')),
      '120903' => array('department' => '12', 'province' => '09', 'district' => '03', 'name' => t('Chongos bajo')),
      '120904' => array('department' => '12', 'province' => '09', 'district' => '04', 'name' => t('Huachac')),
      '120905' => array('department' => '12', 'province' => '09', 'district' => '05', 'name' => t('Huamancaca chico')),
      '120906' => array('department' => '12', 'province' => '09', 'district' => '06', 'name' => t('San juan de iscos')),
      '120907' => array('department' => '12', 'province' => '09', 'district' => '07', 'name' => t('San juan de jarpa')),
      '120908' => array('department' => '12', 'province' => '09', 'district' => '08', 'name' => t('Tres de diciembre')),
      '120909' => array('department' => '12', 'province' => '09', 'district' => '09', 'name' => t('Yanacancha')),
      '130000' => array('department' => '13', 'province' => '00', 'district' => '00', 'name' => t('La libertad')),
      '130100' => array('department' => '13', 'province' => '01', 'district' => '00', 'name' => t('Trujillo')),
      '130101' => array('department' => '13', 'province' => '01', 'district' => '01', 'name' => t('Trujillo')),
      '130102' => array('department' => '13', 'province' => '01', 'district' => '02', 'name' => t('El porvenir')),
      '130103' => array('department' => '13', 'province' => '01', 'district' => '03', 'name' => t('Florencia de mora')),
      '130104' => array('department' => '13', 'province' => '01', 'district' => '04', 'name' => t('Huanchaco')),
      '130105' => array('department' => '13', 'province' => '01', 'district' => '05', 'name' => t('La esperanza')),
      '130106' => array('department' => '13', 'province' => '01', 'district' => '06', 'name' => t('Laredo')),
      '130107' => array('department' => '13', 'province' => '01', 'district' => '07', 'name' => t('Moche')),
      '130108' => array('department' => '13', 'province' => '01', 'district' => '08', 'name' => t('Poroto')),
      '130109' => array('department' => '13', 'province' => '01', 'district' => '09', 'name' => t('Salaverry')),
      '130110' => array('department' => '13', 'province' => '01', 'district' => '10', 'name' => t('Simbal')),
      '130111' => array('department' => '13', 'province' => '01', 'district' => '11', 'name' => t('Victor larco herrera')),
      '130200' => array('department' => '13', 'province' => '02', 'district' => '00', 'name' => t('Ascope')),
      '130201' => array('department' => '13', 'province' => '02', 'district' => '01', 'name' => t('Ascope')),
      '130202' => array('department' => '13', 'province' => '02', 'district' => '02', 'name' => t('Chicama')),
      '130203' => array('department' => '13', 'province' => '02', 'district' => '03', 'name' => t('Chocope')),
      '130204' => array('department' => '13', 'province' => '02', 'district' => '04', 'name' => t('Magdalena de cao')),
      '130205' => array('department' => '13', 'province' => '02', 'district' => '05', 'name' => t('Paijan')),
      '130206' => array('department' => '13', 'province' => '02', 'district' => '06', 'name' => t('Razuri')),
      '130207' => array('department' => '13', 'province' => '02', 'district' => '07', 'name' => t('Santiago de cao')),
      '130208' => array('department' => '13', 'province' => '02', 'district' => '08', 'name' => t('Casa grande')),
      '130300' => array('department' => '13', 'province' => '03', 'district' => '00', 'name' => t('Bolivar')),
      '130301' => array('department' => '13', 'province' => '03', 'district' => '01', 'name' => t('Bolivar')),
      '130302' => array('department' => '13', 'province' => '03', 'district' => '02', 'name' => t('Bambamarca')),
      '130303' => array('department' => '13', 'province' => '03', 'district' => '03', 'name' => t('Condormarca')),
      '130304' => array('department' => '13', 'province' => '03', 'district' => '04', 'name' => t('Longotea')),
      '130305' => array('department' => '13', 'province' => '03', 'district' => '05', 'name' => t('Uchumarca')),
      '130306' => array('department' => '13', 'province' => '03', 'district' => '06', 'name' => t('Ucuncha')),
      '130400' => array('department' => '13', 'province' => '04', 'district' => '00', 'name' => t('Chepen')),
      '130401' => array('department' => '13', 'province' => '04', 'district' => '01', 'name' => t('Chepen')),
      '130402' => array('department' => '13', 'province' => '04', 'district' => '02', 'name' => t('Pacanga')),
      '130403' => array('department' => '13', 'province' => '04', 'district' => '03', 'name' => t('Pueblo nuevo')),
      '130500' => array('department' => '13', 'province' => '05', 'district' => '00', 'name' => t('Julcan')),
      '130501' => array('department' => '13', 'province' => '05', 'district' => '01', 'name' => t('Julcan')),
      '130502' => array('department' => '13', 'province' => '05', 'district' => '02', 'name' => t('Calamarca')),
      '130503' => array('department' => '13', 'province' => '05', 'district' => '03', 'name' => t('Carabamba')),
      '130504' => array('department' => '13', 'province' => '05', 'district' => '04', 'name' => t('Huaso')),
      '130600' => array('department' => '13', 'province' => '06', 'district' => '00', 'name' => t('Otuzco')),
      '130601' => array('department' => '13', 'province' => '06', 'district' => '01', 'name' => t('Otuzco')),
      '130602' => array('department' => '13', 'province' => '06', 'district' => '02', 'name' => t('Agallpampa')),
      '130604' => array('department' => '13', 'province' => '06', 'district' => '04', 'name' => t('Charat')),
      '130605' => array('department' => '13', 'province' => '06', 'district' => '05', 'name' => t('Huaranchal')),
      '130606' => array('department' => '13', 'province' => '06', 'district' => '06', 'name' => t('La cuesta')),
      '130608' => array('department' => '13', 'province' => '06', 'district' => '08', 'name' => t('Mache')),
      '130610' => array('department' => '13', 'province' => '06', 'district' => '10', 'name' => t('Paranday')),
      '130611' => array('department' => '13', 'province' => '06', 'district' => '11', 'name' => t('Salpo')),
      '130613' => array('department' => '13', 'province' => '06', 'district' => '13', 'name' => t('Sinsicap')),
      '130614' => array('department' => '13', 'province' => '06', 'district' => '14', 'name' => t('Usquil')),
      '130700' => array('department' => '13', 'province' => '07', 'district' => '00', 'name' => t('Pacasmayo')),
      '130701' => array('department' => '13', 'province' => '07', 'district' => '01', 'name' => t('San pedro de lloc')),
      '130702' => array('department' => '13', 'province' => '07', 'district' => '02', 'name' => t('Guadalupe')),
      '130703' => array('department' => '13', 'province' => '07', 'district' => '03', 'name' => t('Jequetepeque')),
      '130704' => array('department' => '13', 'province' => '07', 'district' => '04', 'name' => t('Pacasmayo')),
      '130705' => array('department' => '13', 'province' => '07', 'district' => '05', 'name' => t('San jose')),
      '130800' => array('department' => '13', 'province' => '08', 'district' => '00', 'name' => t('Pataz')),
      '130801' => array('department' => '13', 'province' => '08', 'district' => '01', 'name' => t('Tayabamba')),
      '130802' => array('department' => '13', 'province' => '08', 'district' => '02', 'name' => t('Buldibuyo')),
      '130803' => array('department' => '13', 'province' => '08', 'district' => '03', 'name' => t('Chillia')),
      '130804' => array('department' => '13', 'province' => '08', 'district' => '04', 'name' => t('Huancaspata')),
      '130805' => array('department' => '13', 'province' => '08', 'district' => '05', 'name' => t('Huaylillas')),
      '130806' => array('department' => '13', 'province' => '08', 'district' => '06', 'name' => t('Huayo')),
      '130807' => array('department' => '13', 'province' => '08', 'district' => '07', 'name' => t('Ongon')),
      '130808' => array('department' => '13', 'province' => '08', 'district' => '08', 'name' => t('Parcoy')),
      '130809' => array('department' => '13', 'province' => '08', 'district' => '09', 'name' => t('Pataz')),
      '130810' => array('department' => '13', 'province' => '08', 'district' => '10', 'name' => t('Pias')),
      '130811' => array('department' => '13', 'province' => '08', 'district' => '11', 'name' => t('Santiago de challas')),
      '130812' => array('department' => '13', 'province' => '08', 'district' => '12', 'name' => t('Taurija')),
      '130813' => array('department' => '13', 'province' => '08', 'district' => '13', 'name' => t('Urpay')),
      '130900' => array('department' => '13', 'province' => '09', 'district' => '00', 'name' => t('Sanchez carrion')),
      '130901' => array('department' => '13', 'province' => '09', 'district' => '01', 'name' => t('Huamachuco')),
      '130902' => array('department' => '13', 'province' => '09', 'district' => '02', 'name' => t('Chugay')),
      '130903' => array('department' => '13', 'province' => '09', 'district' => '03', 'name' => t('Cochorco')),
      '130904' => array('department' => '13', 'province' => '09', 'district' => '04', 'name' => t('Curgos')),
      '130905' => array('department' => '13', 'province' => '09', 'district' => '05', 'name' => t('Marcabal')),
      '130906' => array('department' => '13', 'province' => '09', 'district' => '06', 'name' => t('Sanagoran')),
      '130907' => array('department' => '13', 'province' => '09', 'district' => '07', 'name' => t('Sarin')),
      '130908' => array('department' => '13', 'province' => '09', 'district' => '08', 'name' => t('Sartimbamba')),
      '131000' => array('department' => '13', 'province' => '10', 'district' => '00', 'name' => t('Santiago de chuco')),
      '131001' => array('department' => '13', 'province' => '10', 'district' => '01', 'name' => t('Santiago de chuco')),
      '131002' => array('department' => '13', 'province' => '10', 'district' => '02', 'name' => t('Angasmarca')),
      '131003' => array('department' => '13', 'province' => '10', 'district' => '03', 'name' => t('Cachicadan')),
      '131004' => array('department' => '13', 'province' => '10', 'district' => '04', 'name' => t('Mollebamba')),
      '131005' => array('department' => '13', 'province' => '10', 'district' => '05', 'name' => t('Mollepata')),
      '131006' => array('department' => '13', 'province' => '10', 'district' => '06', 'name' => t('Quiruvilca')),
      '131007' => array('department' => '13', 'province' => '10', 'district' => '07', 'name' => t('Santa cruz de chuca')),
      '131008' => array('department' => '13', 'province' => '10', 'district' => '08', 'name' => t('Sitabamba')),
      '131100' => array('department' => '13', 'province' => '11', 'district' => '00', 'name' => t('Gran chimu')),
      '131101' => array('department' => '13', 'province' => '11', 'district' => '01', 'name' => t('Cascas')),
      '131102' => array('department' => '13', 'province' => '11', 'district' => '02', 'name' => t('Lucma')),
      '131103' => array('department' => '13', 'province' => '11', 'district' => '03', 'name' => t('Marmot')),
      '131104' => array('department' => '13', 'province' => '11', 'district' => '04', 'name' => t('Sayapullo')),
      '131200' => array('department' => '13', 'province' => '12', 'district' => '00', 'name' => t('Viru')),
      '131201' => array('department' => '13', 'province' => '12', 'district' => '01', 'name' => t('Viru')),
      '131202' => array('department' => '13', 'province' => '12', 'district' => '02', 'name' => t('Chao')),
      '131203' => array('department' => '13', 'province' => '12', 'district' => '03', 'name' => t('Guadalupito')),
      '140000' => array('department' => '14', 'province' => '00', 'district' => '00', 'name' => t('Lambayeque')),
      '140100' => array('department' => '14', 'province' => '01', 'district' => '00', 'name' => t('Chiclayo')),
      '140101' => array('department' => '14', 'province' => '01', 'district' => '01', 'name' => t('Chiclayo')),
      '140102' => array('department' => '14', 'province' => '01', 'district' => '02', 'name' => t('Chongoyape')),
      '140103' => array('department' => '14', 'province' => '01', 'district' => '03', 'name' => t('Eten')),
      '140104' => array('department' => '14', 'province' => '01', 'district' => '04', 'name' => t('Eten puerto')),
      '140105' => array('department' => '14', 'province' => '01', 'district' => '05', 'name' => t('Jose leonardo ortiz')),
      '140106' => array('department' => '14', 'province' => '01', 'district' => '06', 'name' => t('La victoria')),
      '140107' => array('department' => '14', 'province' => '01', 'district' => '07', 'name' => t('Lagunas')),
      '140108' => array('department' => '14', 'province' => '01', 'district' => '08', 'name' => t('Monsefu')),
      '140109' => array('department' => '14', 'province' => '01', 'district' => '09', 'name' => t('Nueva arica')),
      '140110' => array('department' => '14', 'province' => '01', 'district' => '10', 'name' => t('Oyotun')),
      '140111' => array('department' => '14', 'province' => '01', 'district' => '11', 'name' => t('Picsi')),
      '140112' => array('department' => '14', 'province' => '01', 'district' => '12', 'name' => t('Pimentel')),
      '140113' => array('department' => '14', 'province' => '01', 'district' => '13', 'name' => t('Reque')),
      '140114' => array('department' => '14', 'province' => '01', 'district' => '14', 'name' => t('Santa rosa')),
      '140115' => array('department' => '14', 'province' => '01', 'district' => '15', 'name' => t('Saña')),
      '140116' => array('department' => '14', 'province' => '01', 'district' => '16', 'name' => t('Cayalti')),
      '140117' => array('department' => '14', 'province' => '01', 'district' => '17', 'name' => t('Patapo')),
      '140118' => array('department' => '14', 'province' => '01', 'district' => '18', 'name' => t('Pomalca')),
      '140119' => array('department' => '14', 'province' => '01', 'district' => '19', 'name' => t('Pucala')),
      '140120' => array('department' => '14', 'province' => '01', 'district' => '20', 'name' => t('Tuman')),
      '140200' => array('department' => '14', 'province' => '02', 'district' => '00', 'name' => t('Ferreñafe')),
      '140201' => array('department' => '14', 'province' => '02', 'district' => '01', 'name' => t('Ferreñafe')),
      '140202' => array('department' => '14', 'province' => '02', 'district' => '02', 'name' => t('Cañaris')),
      '140203' => array('department' => '14', 'province' => '02', 'district' => '03', 'name' => t('Incahuasi')),
      '140204' => array('department' => '14', 'province' => '02', 'district' => '04', 'name' => t('Manuel antonio mesones muro')),
      '140205' => array('department' => '14', 'province' => '02', 'district' => '05', 'name' => t('Pitipo')),
      '140206' => array('department' => '14', 'province' => '02', 'district' => '06', 'name' => t('Pueblo nuevo')),
      '140300' => array('department' => '14', 'province' => '03', 'district' => '00', 'name' => t('Lambayeque')),
      '140301' => array('department' => '14', 'province' => '03', 'district' => '01', 'name' => t('Lambayeque')),
      '140302' => array('department' => '14', 'province' => '03', 'district' => '02', 'name' => t('Chochope')),
      '140303' => array('department' => '14', 'province' => '03', 'district' => '03', 'name' => t('Illimo')),
      '140304' => array('department' => '14', 'province' => '03', 'district' => '04', 'name' => t('Jayanca')),
      '140305' => array('department' => '14', 'province' => '03', 'district' => '05', 'name' => t('Mochumi')),
      '140306' => array('department' => '14', 'province' => '03', 'district' => '06', 'name' => t('Morrope')),
      '140307' => array('department' => '14', 'province' => '03', 'district' => '07', 'name' => t('Motupe')),
      '140308' => array('department' => '14', 'province' => '03', 'district' => '08', 'name' => t('Olmos')),
      '140309' => array('department' => '14', 'province' => '03', 'district' => '09', 'name' => t('Pacora')),
      '140310' => array('department' => '14', 'province' => '03', 'district' => '10', 'name' => t('Salas')),
      '140311' => array('department' => '14', 'province' => '03', 'district' => '11', 'name' => t('San jose')),
      '140312' => array('department' => '14', 'province' => '03', 'district' => '12', 'name' => t('Tucume')),
      '150000' => array('department' => '15', 'province' => '00', 'district' => '00', 'name' => t('Lima')),
      '150100' => array('department' => '15', 'province' => '01', 'district' => '00', 'name' => t('Lima')),
      '150101' => array('department' => '15', 'province' => '01', 'district' => '01', 'name' => t('Lima')),
      '150102' => array('department' => '15', 'province' => '01', 'district' => '02', 'name' => t('Ancon')),
      '150103' => array('department' => '15', 'province' => '01', 'district' => '03', 'name' => t('Ate')),
      '150104' => array('department' => '15', 'province' => '01', 'district' => '04', 'name' => t('Barranco')),
      '150105' => array('department' => '15', 'province' => '01', 'district' => '05', 'name' => t('Breña')),
      '150106' => array('department' => '15', 'province' => '01', 'district' => '06', 'name' => t('Carabayllo')),
      '150107' => array('department' => '15', 'province' => '01', 'district' => '07', 'name' => t('Chaclacayo')),
      '150108' => array('department' => '15', 'province' => '01', 'district' => '08', 'name' => t('Chorrillos')),
      '150109' => array('department' => '15', 'province' => '01', 'district' => '09', 'name' => t('Cieneguilla')),
      '150110' => array('department' => '15', 'province' => '01', 'district' => '10', 'name' => t('Comas')),
      '150111' => array('department' => '15', 'province' => '01', 'district' => '11', 'name' => t('El agustino')),
      '150112' => array('department' => '15', 'province' => '01', 'district' => '12', 'name' => t('Independencia')),
      '150113' => array('department' => '15', 'province' => '01', 'district' => '13', 'name' => t('Jesus maria')),
      '150114' => array('department' => '15', 'province' => '01', 'district' => '14', 'name' => t('La molina')),
      '150115' => array('department' => '15', 'province' => '01', 'district' => '15', 'name' => t('La victoria')),
      '150116' => array('department' => '15', 'province' => '01', 'district' => '16', 'name' => t('Lince')),
      '150117' => array('department' => '15', 'province' => '01', 'district' => '17', 'name' => t('Los olivos')),
      '150118' => array('department' => '15', 'province' => '01', 'district' => '18', 'name' => t('Lurigancho')),
      '150119' => array('department' => '15', 'province' => '01', 'district' => '19', 'name' => t('Lurin')),
      '150120' => array('department' => '15', 'province' => '01', 'district' => '20', 'name' => t('Magdalena del mar')),
      '150121' => array('department' => '15', 'province' => '01', 'district' => '21', 'name' => t('Pueblo libre')),
      '150122' => array('department' => '15', 'province' => '01', 'district' => '22', 'name' => t('Miraflores')),
      '150123' => array('department' => '15', 'province' => '01', 'district' => '23', 'name' => t('Pachacamac')),
      '150124' => array('department' => '15', 'province' => '01', 'district' => '24', 'name' => t('Pucusana')),
      '150125' => array('department' => '15', 'province' => '01', 'district' => '25', 'name' => t('Puente piedra')),
      '150126' => array('department' => '15', 'province' => '01', 'district' => '26', 'name' => t('Punta hermosa')),
      '150127' => array('department' => '15', 'province' => '01', 'district' => '27', 'name' => t('Punta negra')),
      '150128' => array('department' => '15', 'province' => '01', 'district' => '28', 'name' => t('Rimac')),
      '150129' => array('department' => '15', 'province' => '01', 'district' => '29', 'name' => t('San bartolo')),
      '150130' => array('department' => '15', 'province' => '01', 'district' => '30', 'name' => t('San borja')),
      '150131' => array('department' => '15', 'province' => '01', 'district' => '31', 'name' => t('San isidro')),
      '150132' => array('department' => '15', 'province' => '01', 'district' => '32', 'name' => t('San juan de lurigancho')),
      '150133' => array('department' => '15', 'province' => '01', 'district' => '33', 'name' => t('San juan de miraflores')),
      '150134' => array('department' => '15', 'province' => '01', 'district' => '34', 'name' => t('San luis')),
      '150135' => array('department' => '15', 'province' => '01', 'district' => '35', 'name' => t('San martin de porres')),
      '150136' => array('department' => '15', 'province' => '01', 'district' => '36', 'name' => t('San miguel')),
      '150137' => array('department' => '15', 'province' => '01', 'district' => '37', 'name' => t('Santa anita')),
      '150138' => array('department' => '15', 'province' => '01', 'district' => '38', 'name' => t('Santa maria del mar')),
      '150139' => array('department' => '15', 'province' => '01', 'district' => '39', 'name' => t('Santa rosa')),
      '150140' => array('department' => '15', 'province' => '01', 'district' => '40', 'name' => t('Santiago de surco')),
      '150141' => array('department' => '15', 'province' => '01', 'district' => '41', 'name' => t('Surquillo')),
      '150142' => array('department' => '15', 'province' => '01', 'district' => '42', 'name' => t('Villa el salvador')),
      '150143' => array('department' => '15', 'province' => '01', 'district' => '43', 'name' => t('Villa maria del triunfo')),
      '150200' => array('department' => '15', 'province' => '02', 'district' => '00', 'name' => t('Barranca')),
      '150201' => array('department' => '15', 'province' => '02', 'district' => '01', 'name' => t('Barranca')),
      '150202' => array('department' => '15', 'province' => '02', 'district' => '02', 'name' => t('Paramonga')),
      '150203' => array('department' => '15', 'province' => '02', 'district' => '03', 'name' => t('Pativilca')),
      '150204' => array('department' => '15', 'province' => '02', 'district' => '04', 'name' => t('Supe')),
      '150205' => array('department' => '15', 'province' => '02', 'district' => '05', 'name' => t('Supe puerto')),
      '150300' => array('department' => '15', 'province' => '03', 'district' => '00', 'name' => t('Cajatambo')),
      '150301' => array('department' => '15', 'province' => '03', 'district' => '01', 'name' => t('Cajatambo')),
      '150302' => array('department' => '15', 'province' => '03', 'district' => '02', 'name' => t('Copa')),
      '150303' => array('department' => '15', 'province' => '03', 'district' => '03', 'name' => t('Gorgor')),
      '150304' => array('department' => '15', 'province' => '03', 'district' => '04', 'name' => t('Huancapon')),
      '150305' => array('department' => '15', 'province' => '03', 'district' => '05', 'name' => t('Manas')),
      '150400' => array('department' => '15', 'province' => '04', 'district' => '00', 'name' => t('Canta')),
      '150401' => array('department' => '15', 'province' => '04', 'district' => '01', 'name' => t('Canta')),
      '150402' => array('department' => '15', 'province' => '04', 'district' => '02', 'name' => t('Arahuay')),
      '150403' => array('department' => '15', 'province' => '04', 'district' => '03', 'name' => t('Huamantanga')),
      '150404' => array('department' => '15', 'province' => '04', 'district' => '04', 'name' => t('Huaros')),
      '150405' => array('department' => '15', 'province' => '04', 'district' => '05', 'name' => t('Lachaqui')),
      '150406' => array('department' => '15', 'province' => '04', 'district' => '06', 'name' => t('San buenaventura')),
      '150407' => array('department' => '15', 'province' => '04', 'district' => '07', 'name' => t('Santa rosa de quives')),
      '150500' => array('department' => '15', 'province' => '05', 'district' => '00', 'name' => t('Cañete')),
      '150501' => array('department' => '15', 'province' => '05', 'district' => '01', 'name' => t('San vicente de cañete')),
      '150502' => array('department' => '15', 'province' => '05', 'district' => '02', 'name' => t('Asia')),
      '150503' => array('department' => '15', 'province' => '05', 'district' => '03', 'name' => t('Calango')),
      '150504' => array('department' => '15', 'province' => '05', 'district' => '04', 'name' => t('Cerro azul')),
      '150505' => array('department' => '15', 'province' => '05', 'district' => '05', 'name' => t('Chilca')),
      '150506' => array('department' => '15', 'province' => '05', 'district' => '06', 'name' => t('Coayllo')),
      '150507' => array('department' => '15', 'province' => '05', 'district' => '07', 'name' => t('Imperial')),
      '150508' => array('department' => '15', 'province' => '05', 'district' => '08', 'name' => t('Lunahuana')),
      '150509' => array('department' => '15', 'province' => '05', 'district' => '09', 'name' => t('Mala')),
      '150510' => array('department' => '15', 'province' => '05', 'district' => '10', 'name' => t('Nuevo imperial')),
      '150511' => array('department' => '15', 'province' => '05', 'district' => '11', 'name' => t('Pacaran')),
      '150512' => array('department' => '15', 'province' => '05', 'district' => '12', 'name' => t('Quilmana')),
      '150513' => array('department' => '15', 'province' => '05', 'district' => '13', 'name' => t('San antonio')),
      '150514' => array('department' => '15', 'province' => '05', 'district' => '14', 'name' => t('San luis')),
      '150515' => array('department' => '15', 'province' => '05', 'district' => '15', 'name' => t('Santa cruz de flores')),
      '150516' => array('department' => '15', 'province' => '05', 'district' => '16', 'name' => t('Zuñiga')),
      '150600' => array('department' => '15', 'province' => '06', 'district' => '00', 'name' => t('Huaral')),
      '150601' => array('department' => '15', 'province' => '06', 'district' => '01', 'name' => t('Huaral')),
      '150602' => array('department' => '15', 'province' => '06', 'district' => '02', 'name' => t('Atavillos alto')),
      '150603' => array('department' => '15', 'province' => '06', 'district' => '03', 'name' => t('Atavillos bajo')),
      '150604' => array('department' => '15', 'province' => '06', 'district' => '04', 'name' => t('Aucallama')),
      '150605' => array('department' => '15', 'province' => '06', 'district' => '05', 'name' => t('Chancay')),
      '150606' => array('department' => '15', 'province' => '06', 'district' => '06', 'name' => t('Ihuari')),
      '150607' => array('department' => '15', 'province' => '06', 'district' => '07', 'name' => t('Lampian')),
      '150608' => array('department' => '15', 'province' => '06', 'district' => '08', 'name' => t('Pacaraos')),
      '150609' => array('department' => '15', 'province' => '06', 'district' => '09', 'name' => t('San miguel de acos')),
      '150610' => array('department' => '15', 'province' => '06', 'district' => '10', 'name' => t('Santa cruz de andamarca')),
      '150611' => array('department' => '15', 'province' => '06', 'district' => '11', 'name' => t('Sumbilca')),
      '150612' => array('department' => '15', 'province' => '06', 'district' => '12', 'name' => t('Veintisiete de noviembre')),
      '150700' => array('department' => '15', 'province' => '07', 'district' => '00', 'name' => t('Huarochiri')),
      '150701' => array('department' => '15', 'province' => '07', 'district' => '01', 'name' => t('Matucana')),
      '150702' => array('department' => '15', 'province' => '07', 'district' => '02', 'name' => t('Antioquia')),
      '150703' => array('department' => '15', 'province' => '07', 'district' => '03', 'name' => t('Callahuanca')),
      '150704' => array('department' => '15', 'province' => '07', 'district' => '04', 'name' => t('Carampoma')),
      '150705' => array('department' => '15', 'province' => '07', 'district' => '05', 'name' => t('Chicla')),
      '150706' => array('department' => '15', 'province' => '07', 'district' => '06', 'name' => t('Cuenca')),
      '150707' => array('department' => '15', 'province' => '07', 'district' => '07', 'name' => t('Huachupampa')),
      '150708' => array('department' => '15', 'province' => '07', 'district' => '08', 'name' => t('Huanza')),
      '150709' => array('department' => '15', 'province' => '07', 'district' => '09', 'name' => t('Huarochiri')),
      '150710' => array('department' => '15', 'province' => '07', 'district' => '10', 'name' => t('Lahuaytambo')),
      '150711' => array('department' => '15', 'province' => '07', 'district' => '11', 'name' => t('Langa')),
      '150712' => array('department' => '15', 'province' => '07', 'district' => '12', 'name' => t('Laraos')),
      '150713' => array('department' => '15', 'province' => '07', 'district' => '13', 'name' => t('Mariatana')),
      '150714' => array('department' => '15', 'province' => '07', 'district' => '14', 'name' => t('Ricardo palma')),
      '150715' => array('department' => '15', 'province' => '07', 'district' => '15', 'name' => t('San andres de tupicocha')),
      '150716' => array('department' => '15', 'province' => '07', 'district' => '16', 'name' => t('San antonio')),
      '150717' => array('department' => '15', 'province' => '07', 'district' => '17', 'name' => t('San bartolome')),
      '150718' => array('department' => '15', 'province' => '07', 'district' => '18', 'name' => t('San damian')),
      '150719' => array('department' => '15', 'province' => '07', 'district' => '19', 'name' => t('San juan de iris')),
      '150720' => array('department' => '15', 'province' => '07', 'district' => '20', 'name' => t('San juan de tantaranche')),
      '150721' => array('department' => '15', 'province' => '07', 'district' => '21', 'name' => t('San lorenzo de quinti')),
      '150722' => array('department' => '15', 'province' => '07', 'district' => '22', 'name' => t('San mateo')),
      '150723' => array('department' => '15', 'province' => '07', 'district' => '23', 'name' => t('San mateo de otao')),
      '150724' => array('department' => '15', 'province' => '07', 'district' => '24', 'name' => t('San pedro de casta')),
      '150725' => array('department' => '15', 'province' => '07', 'district' => '25', 'name' => t('San pedro de huancayre')),
      '150726' => array('department' => '15', 'province' => '07', 'district' => '26', 'name' => t('Sangallaya')),
      '150727' => array('department' => '15', 'province' => '07', 'district' => '27', 'name' => t('Santa cruz de cocachacra')),
      '150728' => array('department' => '15', 'province' => '07', 'district' => '28', 'name' => t('Santa eulalia')),
      '150729' => array('department' => '15', 'province' => '07', 'district' => '29', 'name' => t('Santiago de anchucaya')),
      '150730' => array('department' => '15', 'province' => '07', 'district' => '30', 'name' => t('Santiago de tuna')),
      '150731' => array('department' => '15', 'province' => '07', 'district' => '31', 'name' => t('Santo domingo de los olleros')),
      '150732' => array('department' => '15', 'province' => '07', 'district' => '32', 'name' => t('Surco')),
      '150800' => array('department' => '15', 'province' => '08', 'district' => '00', 'name' => t('Huaura')),
      '150801' => array('department' => '15', 'province' => '08', 'district' => '01', 'name' => t('Huacho')),
      '150802' => array('department' => '15', 'province' => '08', 'district' => '02', 'name' => t('Ambar')),
      '150803' => array('department' => '15', 'province' => '08', 'district' => '03', 'name' => t('Caleta de carquin')),
      '150804' => array('department' => '15', 'province' => '08', 'district' => '04', 'name' => t('Checras')),
      '150805' => array('department' => '15', 'province' => '08', 'district' => '05', 'name' => t('Hualmay')),
      '150806' => array('department' => '15', 'province' => '08', 'district' => '06', 'name' => t('Huaura')),
      '150807' => array('department' => '15', 'province' => '08', 'district' => '07', 'name' => t('Leoncio prado')),
      '150808' => array('department' => '15', 'province' => '08', 'district' => '08', 'name' => t('Paccho')),
      '150809' => array('department' => '15', 'province' => '08', 'district' => '09', 'name' => t('Santa leonor')),
      '150810' => array('department' => '15', 'province' => '08', 'district' => '10', 'name' => t('Santa maria')),
      '150811' => array('department' => '15', 'province' => '08', 'district' => '11', 'name' => t('Sayan')),
      '150812' => array('department' => '15', 'province' => '08', 'district' => '12', 'name' => t('Vegueta')),
      '150900' => array('department' => '15', 'province' => '09', 'district' => '00', 'name' => t('Oyon')),
      '150901' => array('department' => '15', 'province' => '09', 'district' => '01', 'name' => t('Oyon')),
      '150902' => array('department' => '15', 'province' => '09', 'district' => '02', 'name' => t('Andajes')),
      '150903' => array('department' => '15', 'province' => '09', 'district' => '03', 'name' => t('Caujul')),
      '150904' => array('department' => '15', 'province' => '09', 'district' => '04', 'name' => t('Cochamarca')),
      '150905' => array('department' => '15', 'province' => '09', 'district' => '05', 'name' => t('Navan')),
      '150906' => array('department' => '15', 'province' => '09', 'district' => '06', 'name' => t('Pachangara')),
      '151000' => array('department' => '15', 'province' => '10', 'district' => '00', 'name' => t('Yauyos')),
      '151001' => array('department' => '15', 'province' => '10', 'district' => '01', 'name' => t('Yauyos')),
      '151002' => array('department' => '15', 'province' => '10', 'district' => '02', 'name' => t('Alis')),
      '151003' => array('department' => '15', 'province' => '10', 'district' => '03', 'name' => t('Allauca')),
      '151004' => array('department' => '15', 'province' => '10', 'district' => '04', 'name' => t('Ayaviri')),
      '151005' => array('department' => '15', 'province' => '10', 'district' => '05', 'name' => t('Azangaro')),
      '151006' => array('department' => '15', 'province' => '10', 'district' => '06', 'name' => t('Cacra')),
      '151007' => array('department' => '15', 'province' => '10', 'district' => '07', 'name' => t('Carania')),
      '151008' => array('department' => '15', 'province' => '10', 'district' => '08', 'name' => t('Catahuasi')),
      '151009' => array('department' => '15', 'province' => '10', 'district' => '09', 'name' => t('Chocos')),
      '151010' => array('department' => '15', 'province' => '10', 'district' => '10', 'name' => t('Cochas')),
      '151011' => array('department' => '15', 'province' => '10', 'district' => '11', 'name' => t('Colonia')),
      '151012' => array('department' => '15', 'province' => '10', 'district' => '12', 'name' => t('Hongos')),
      '151013' => array('department' => '15', 'province' => '10', 'district' => '13', 'name' => t('Huampara')),
      '151014' => array('department' => '15', 'province' => '10', 'district' => '14', 'name' => t('Huancaya')),
      '151015' => array('department' => '15', 'province' => '10', 'district' => '15', 'name' => t('Huangascar')),
      '151016' => array('department' => '15', 'province' => '10', 'district' => '16', 'name' => t('Huantan')),
      '151017' => array('department' => '15', 'province' => '10', 'district' => '17', 'name' => t('Huañec')),
      '151018' => array('department' => '15', 'province' => '10', 'district' => '18', 'name' => t('Laraos')),
      '151019' => array('department' => '15', 'province' => '10', 'district' => '19', 'name' => t('Lincha')),
      '151020' => array('department' => '15', 'province' => '10', 'district' => '20', 'name' => t('Madean')),
      '151021' => array('department' => '15', 'province' => '10', 'district' => '21', 'name' => t('Miraflores')),
      '151022' => array('department' => '15', 'province' => '10', 'district' => '22', 'name' => t('Omas')),
      '151023' => array('department' => '15', 'province' => '10', 'district' => '23', 'name' => t('Putinza')),
      '151024' => array('department' => '15', 'province' => '10', 'district' => '24', 'name' => t('Quinches')),
      '151025' => array('department' => '15', 'province' => '10', 'district' => '25', 'name' => t('Quinocay')),
      '151026' => array('department' => '15', 'province' => '10', 'district' => '26', 'name' => t('San joaquin')),
      '151027' => array('department' => '15', 'province' => '10', 'district' => '27', 'name' => t('San pedro de pilas')),
      '151028' => array('department' => '15', 'province' => '10', 'district' => '28', 'name' => t('Tanta')),
      '151029' => array('department' => '15', 'province' => '10', 'district' => '29', 'name' => t('Tauripampa')),
      '151030' => array('department' => '15', 'province' => '10', 'district' => '30', 'name' => t('Tomas')),
      '151031' => array('department' => '15', 'province' => '10', 'district' => '31', 'name' => t('Tupe')),
      '151032' => array('department' => '15', 'province' => '10', 'district' => '32', 'name' => t('Viñac')),
      '151033' => array('department' => '15', 'province' => '10', 'district' => '33', 'name' => t('Vitis')),
      '160000' => array('department' => '16', 'province' => '00', 'district' => '00', 'name' => t('Loreto')),
      '160100' => array('department' => '16', 'province' => '01', 'district' => '00', 'name' => t('Maynas')),
      '160101' => array('department' => '16', 'province' => '01', 'district' => '01', 'name' => t('Iquitos')),
      '160102' => array('department' => '16', 'province' => '01', 'district' => '02', 'name' => t('Alto nanay')),
      '160103' => array('department' => '16', 'province' => '01', 'district' => '03', 'name' => t('Fernando lores')),
      '160104' => array('department' => '16', 'province' => '01', 'district' => '04', 'name' => t('Indiana')),
      '160105' => array('department' => '16', 'province' => '01', 'district' => '05', 'name' => t('Las amazonas')),
      '160106' => array('department' => '16', 'province' => '01', 'district' => '06', 'name' => t('Mazan')),
      '160107' => array('department' => '16', 'province' => '01', 'district' => '07', 'name' => t('Napo')),
      '160108' => array('department' => '16', 'province' => '01', 'district' => '08', 'name' => t('Punchana')),
      '160109' => array('department' => '16', 'province' => '01', 'district' => '09', 'name' => t('Putumayo')),
      '160110' => array('department' => '16', 'province' => '01', 'district' => '10', 'name' => t('Torres causana')),
      '160112' => array('department' => '16', 'province' => '01', 'district' => '12', 'name' => t('Belen')),
      '160113' => array('department' => '16', 'province' => '01', 'district' => '13', 'name' => t('San juan bautista')),
      '160114' => array('department' => '16', 'province' => '01', 'district' => '14', 'name' => t('Teniente manuel clavero')),
      '160200' => array('department' => '16', 'province' => '02', 'district' => '00', 'name' => t('Alto amazonas')),
      '160201' => array('department' => '16', 'province' => '02', 'district' => '01', 'name' => t('Yurimaguas')),
      '160202' => array('department' => '16', 'province' => '02', 'district' => '02', 'name' => t('Balsapuerto')),
      '160205' => array('department' => '16', 'province' => '02', 'district' => '05', 'name' => t('Jeberos')),
      '160206' => array('department' => '16', 'province' => '02', 'district' => '06', 'name' => t('Lagunas')),
      '160210' => array('department' => '16', 'province' => '02', 'district' => '10', 'name' => t('Santa cruz')),
      '160211' => array('department' => '16', 'province' => '02', 'district' => '11', 'name' => t('Teniente cesar lopez rojas')),
      '160300' => array('department' => '16', 'province' => '03', 'district' => '00', 'name' => t('Loreto')),
      '160301' => array('department' => '16', 'province' => '03', 'district' => '01', 'name' => t('Nauta')),
      '160302' => array('department' => '16', 'province' => '03', 'district' => '02', 'name' => t('Parinari')),
      '160303' => array('department' => '16', 'province' => '03', 'district' => '03', 'name' => t('Tigre')),
      '160304' => array('department' => '16', 'province' => '03', 'district' => '04', 'name' => t('Trompeteros')),
      '160305' => array('department' => '16', 'province' => '03', 'district' => '05', 'name' => t('Urarinas')),
      '160400' => array('department' => '16', 'province' => '04', 'district' => '00', 'name' => t('Mariscal ramon castilla')),
      '160401' => array('department' => '16', 'province' => '04', 'district' => '01', 'name' => t('Ramon castilla')),
      '160402' => array('department' => '16', 'province' => '04', 'district' => '02', 'name' => t('Pebas')),
      '160403' => array('department' => '16', 'province' => '04', 'district' => '03', 'name' => t('Yavari')),
      '160404' => array('department' => '16', 'province' => '04', 'district' => '04', 'name' => t('San pablo')),
      '160500' => array('department' => '16', 'province' => '05', 'district' => '00', 'name' => t('Requena')),
      '160501' => array('department' => '16', 'province' => '05', 'district' => '01', 'name' => t('Requena')),
      '160502' => array('department' => '16', 'province' => '05', 'district' => '02', 'name' => t('Alto tapiche')),
      '160503' => array('department' => '16', 'province' => '05', 'district' => '03', 'name' => t('Capelo')),
      '160504' => array('department' => '16', 'province' => '05', 'district' => '04', 'name' => t('Emilio san martin')),
      '160505' => array('department' => '16', 'province' => '05', 'district' => '05', 'name' => t('Maquia')),
      '160506' => array('department' => '16', 'province' => '05', 'district' => '06', 'name' => t('Puinahua')),
      '160507' => array('department' => '16', 'province' => '05', 'district' => '07', 'name' => t('Saquena')),
      '160508' => array('department' => '16', 'province' => '05', 'district' => '08', 'name' => t('Soplin')),
      '160509' => array('department' => '16', 'province' => '05', 'district' => '09', 'name' => t('Tapiche')),
      '160510' => array('department' => '16', 'province' => '05', 'district' => '10', 'name' => t('Jenaro herrera')),
      '160511' => array('department' => '16', 'province' => '05', 'district' => '11', 'name' => t('Yaquerana')),
      '160600' => array('department' => '16', 'province' => '06', 'district' => '00', 'name' => t('Ucayali')),
      '160601' => array('department' => '16', 'province' => '06', 'district' => '01', 'name' => t('Contamana')),
      '160602' => array('department' => '16', 'province' => '06', 'district' => '02', 'name' => t('Inahuaya')),
      '160603' => array('department' => '16', 'province' => '06', 'district' => '03', 'name' => t('Padre marquez')),
      '160604' => array('department' => '16', 'province' => '06', 'district' => '04', 'name' => t('Pampa hermosa')),
      '160605' => array('department' => '16', 'province' => '06', 'district' => '05', 'name' => t('Sarayacu')),
      '160606' => array('department' => '16', 'province' => '06', 'district' => '06', 'name' => t('Vargas guerra')),
      '160700' => array('department' => '16', 'province' => '07', 'district' => '00', 'name' => t('Datem del marañon')),
      '160701' => array('department' => '16', 'province' => '07', 'district' => '01', 'name' => t('Barranca')),
      '160702' => array('department' => '16', 'province' => '07', 'district' => '02', 'name' => t('Cahuapanas')),
      '160703' => array('department' => '16', 'province' => '07', 'district' => '03', 'name' => t('Manseriche')),
      '160704' => array('department' => '16', 'province' => '07', 'district' => '04', 'name' => t('Morona')),
      '160705' => array('department' => '16', 'province' => '07', 'district' => '05', 'name' => t('Pastaza')),
      '160706' => array('department' => '16', 'province' => '07', 'district' => '06', 'name' => t('Andoas')),
      '170000' => array('department' => '17', 'province' => '00', 'district' => '00', 'name' => t('Madre de dios')),
      '170100' => array('department' => '17', 'province' => '01', 'district' => '00', 'name' => t('Tambopata')),
      '170101' => array('department' => '17', 'province' => '01', 'district' => '01', 'name' => t('Tambopata')),
      '170102' => array('department' => '17', 'province' => '01', 'district' => '02', 'name' => t('Inambari')),
      '170103' => array('department' => '17', 'province' => '01', 'district' => '03', 'name' => t('Las piedras')),
      '170104' => array('department' => '17', 'province' => '01', 'district' => '04', 'name' => t('Laberinto')),
      '170200' => array('department' => '17', 'province' => '02', 'district' => '00', 'name' => t('Manu')),
      '170201' => array('department' => '17', 'province' => '02', 'district' => '01', 'name' => t('Manu')),
      '170202' => array('department' => '17', 'province' => '02', 'district' => '02', 'name' => t('Fitzcarrald')),
      '170203' => array('department' => '17', 'province' => '02', 'district' => '03', 'name' => t('Madre de dios')),
      '170204' => array('department' => '17', 'province' => '02', 'district' => '04', 'name' => t('Huepetuhe')),
      '170300' => array('department' => '17', 'province' => '03', 'district' => '00', 'name' => t('Tahuamanu')),
      '170301' => array('department' => '17', 'province' => '03', 'district' => '01', 'name' => t('Iñapari')),
      '170302' => array('department' => '17', 'province' => '03', 'district' => '02', 'name' => t('Iberia')),
      '170303' => array('department' => '17', 'province' => '03', 'district' => '03', 'name' => t('Tahuamanu')),
      '180000' => array('department' => '18', 'province' => '00', 'district' => '00', 'name' => t('Moquegua')),
      '180100' => array('department' => '18', 'province' => '01', 'district' => '00', 'name' => t('Mariscal nieto')),
      '180101' => array('department' => '18', 'province' => '01', 'district' => '01', 'name' => t('Moquegua')),
      '180102' => array('department' => '18', 'province' => '01', 'district' => '02', 'name' => t('Carumas')),
      '180103' => array('department' => '18', 'province' => '01', 'district' => '03', 'name' => t('Cuchumbaya')),
      '180104' => array('department' => '18', 'province' => '01', 'district' => '04', 'name' => t('Samegua')),
      '180105' => array('department' => '18', 'province' => '01', 'district' => '05', 'name' => t('San cristobal')),
      '180106' => array('department' => '18', 'province' => '01', 'district' => '06', 'name' => t('Torata')),
      '180200' => array('department' => '18', 'province' => '02', 'district' => '00', 'name' => t('General sanchez cerro')),
      '180201' => array('department' => '18', 'province' => '02', 'district' => '01', 'name' => t('Omate')),
      '180202' => array('department' => '18', 'province' => '02', 'district' => '02', 'name' => t('Chojata')),
      '180203' => array('department' => '18', 'province' => '02', 'district' => '03', 'name' => t('Coalaque')),
      '180204' => array('department' => '18', 'province' => '02', 'district' => '04', 'name' => t('Ichuña')),
      '180205' => array('department' => '18', 'province' => '02', 'district' => '05', 'name' => t('La capilla')),
      '180206' => array('department' => '18', 'province' => '02', 'district' => '06', 'name' => t('Lloque')),
      '180207' => array('department' => '18', 'province' => '02', 'district' => '07', 'name' => t('Matalaque')),
      '180208' => array('department' => '18', 'province' => '02', 'district' => '08', 'name' => t('Puquina')),
      '180209' => array('department' => '18', 'province' => '02', 'district' => '09', 'name' => t('Quinistaquillas')),
      '180210' => array('department' => '18', 'province' => '02', 'district' => '10', 'name' => t('Ubinas')),
      '180211' => array('department' => '18', 'province' => '02', 'district' => '11', 'name' => t('Yunga')),
      '180300' => array('department' => '18', 'province' => '03', 'district' => '00', 'name' => t('Ilo')),
      '180301' => array('department' => '18', 'province' => '03', 'district' => '01', 'name' => t('Ilo')),
      '180302' => array('department' => '18', 'province' => '03', 'district' => '02', 'name' => t('El algarrobal')),
      '180303' => array('department' => '18', 'province' => '03', 'district' => '03', 'name' => t('Pacocha')),
      '190000' => array('department' => '19', 'province' => '00', 'district' => '00', 'name' => t('Pasco')),
      '190100' => array('department' => '19', 'province' => '01', 'district' => '00', 'name' => t('Pasco')),
      '190101' => array('department' => '19', 'province' => '01', 'district' => '01', 'name' => t('Chaupimarca')),
      '190102' => array('department' => '19', 'province' => '01', 'district' => '02', 'name' => t('Huachon')),
      '190103' => array('department' => '19', 'province' => '01', 'district' => '03', 'name' => t('Huariaca')),
      '190104' => array('department' => '19', 'province' => '01', 'district' => '04', 'name' => t('Huayllay')),
      '190105' => array('department' => '19', 'province' => '01', 'district' => '05', 'name' => t('Ninacaca')),
      '190106' => array('department' => '19', 'province' => '01', 'district' => '06', 'name' => t('Pallanchacra')),
      '190107' => array('department' => '19', 'province' => '01', 'district' => '07', 'name' => t('Paucartambo')),
      '190108' => array('department' => '19', 'province' => '01', 'district' => '08', 'name' => t('San francisco de asis de yarusyacan')),
      '190109' => array('department' => '19', 'province' => '01', 'district' => '09', 'name' => t('Simon bolivar')),
      '190110' => array('department' => '19', 'province' => '01', 'district' => '10', 'name' => t('Ticlacayan')),
      '190111' => array('department' => '19', 'province' => '01', 'district' => '11', 'name' => t('Tinyahuarco')),
      '190112' => array('department' => '19', 'province' => '01', 'district' => '12', 'name' => t('Vicco')),
      '190113' => array('department' => '19', 'province' => '01', 'district' => '13', 'name' => t('Yanacancha')),
      '190200' => array('department' => '19', 'province' => '02', 'district' => '00', 'name' => t('Daniel alcides carrion')),
      '190201' => array('department' => '19', 'province' => '02', 'district' => '01', 'name' => t('Yanahuanca')),
      '190202' => array('department' => '19', 'province' => '02', 'district' => '02', 'name' => t('Chacayan')),
      '190203' => array('department' => '19', 'province' => '02', 'district' => '03', 'name' => t('Goyllarisquizga')),
      '190204' => array('department' => '19', 'province' => '02', 'district' => '04', 'name' => t('Paucar')),
      '190205' => array('department' => '19', 'province' => '02', 'district' => '05', 'name' => t('San pedro de pillao')),
      '190206' => array('department' => '19', 'province' => '02', 'district' => '06', 'name' => t('Santa ana de tusi')),
      '190207' => array('department' => '19', 'province' => '02', 'district' => '07', 'name' => t('Tapuc')),
      '190208' => array('department' => '19', 'province' => '02', 'district' => '08', 'name' => t('Vilcabamba')),
      '190300' => array('department' => '19', 'province' => '03', 'district' => '00', 'name' => t('Oxapampa')),
      '190301' => array('department' => '19', 'province' => '03', 'district' => '01', 'name' => t('Oxapampa')),
      '190302' => array('department' => '19', 'province' => '03', 'district' => '02', 'name' => t('Chontabamba')),
      '190303' => array('department' => '19', 'province' => '03', 'district' => '03', 'name' => t('Huancabamba')),
      '190304' => array('department' => '19', 'province' => '03', 'district' => '04', 'name' => t('Palcazu')),
      '190305' => array('department' => '19', 'province' => '03', 'district' => '05', 'name' => t('Pozuzo')),
      '190306' => array('department' => '19', 'province' => '03', 'district' => '06', 'name' => t('Puerto bermudez')),
      '190307' => array('department' => '19', 'province' => '03', 'district' => '07', 'name' => t('Villa rica')),
      '190308' => array('department' => '19', 'province' => '03', 'district' => '08', 'name' => t('Constitucion')),
      '200000' => array('department' => '20', 'province' => '00', 'district' => '00', 'name' => t('Piura')),
      '200100' => array('department' => '20', 'province' => '01', 'district' => '00', 'name' => t('Piura')),
      '200101' => array('department' => '20', 'province' => '01', 'district' => '01', 'name' => t('Piura')),
      '200104' => array('department' => '20', 'province' => '01', 'district' => '04', 'name' => t('Castilla')),
      '200105' => array('department' => '20', 'province' => '01', 'district' => '05', 'name' => t('Catacaos')),
      '200107' => array('department' => '20', 'province' => '01', 'district' => '07', 'name' => t('Cura mori')),
      '200108' => array('department' => '20', 'province' => '01', 'district' => '08', 'name' => t('El tallan')),
      '200109' => array('department' => '20', 'province' => '01', 'district' => '09', 'name' => t('La arena')),
      '200110' => array('department' => '20', 'province' => '01', 'district' => '10', 'name' => t('La union')),
      '200111' => array('department' => '20', 'province' => '01', 'district' => '11', 'name' => t('Las lomas')),
      '200114' => array('department' => '20', 'province' => '01', 'district' => '14', 'name' => t('Tambo grande')),
      '200200' => array('department' => '20', 'province' => '02', 'district' => '00', 'name' => t('Ayabaca')),
      '200201' => array('department' => '20', 'province' => '02', 'district' => '01', 'name' => t('Ayabaca')),
      '200202' => array('department' => '20', 'province' => '02', 'district' => '02', 'name' => t('Frias')),
      '200203' => array('department' => '20', 'province' => '02', 'district' => '03', 'name' => t('Jilili')),
      '200204' => array('department' => '20', 'province' => '02', 'district' => '04', 'name' => t('Lagunas')),
      '200205' => array('department' => '20', 'province' => '02', 'district' => '05', 'name' => t('Montero')),
      '200206' => array('department' => '20', 'province' => '02', 'district' => '06', 'name' => t('Pacaipampa')),
      '200207' => array('department' => '20', 'province' => '02', 'district' => '07', 'name' => t('Paimas')),
      '200208' => array('department' => '20', 'province' => '02', 'district' => '08', 'name' => t('Sapillica')),
      '200209' => array('department' => '20', 'province' => '02', 'district' => '09', 'name' => t('Sicchez')),
      '200210' => array('department' => '20', 'province' => '02', 'district' => '10', 'name' => t('Suyo')),
      '200300' => array('department' => '20', 'province' => '03', 'district' => '00', 'name' => t('Huancabamba')),
      '200301' => array('department' => '20', 'province' => '03', 'district' => '01', 'name' => t('Huancabamba')),
      '200302' => array('department' => '20', 'province' => '03', 'district' => '02', 'name' => t('Canchaque')),
      '200303' => array('department' => '20', 'province' => '03', 'district' => '03', 'name' => t('El carmen de la frontera')),
      '200304' => array('department' => '20', 'province' => '03', 'district' => '04', 'name' => t('Huarmaca')),
      '200305' => array('department' => '20', 'province' => '03', 'district' => '05', 'name' => t('Lalaquiz')),
      '200306' => array('department' => '20', 'province' => '03', 'district' => '06', 'name' => t('San miguel de el faique')),
      '200307' => array('department' => '20', 'province' => '03', 'district' => '07', 'name' => t('Sondor')),
      '200308' => array('department' => '20', 'province' => '03', 'district' => '08', 'name' => t('Sondorillo')),
      '200400' => array('department' => '20', 'province' => '04', 'district' => '00', 'name' => t('Morropon')),
      '200401' => array('department' => '20', 'province' => '04', 'district' => '01', 'name' => t('Chulucanas')),
      '200402' => array('department' => '20', 'province' => '04', 'district' => '02', 'name' => t('Buenos aires')),
      '200403' => array('department' => '20', 'province' => '04', 'district' => '03', 'name' => t('Chalaco')),
      '200404' => array('department' => '20', 'province' => '04', 'district' => '04', 'name' => t('La matanza')),
      '200405' => array('department' => '20', 'province' => '04', 'district' => '05', 'name' => t('Morropon')),
      '200406' => array('department' => '20', 'province' => '04', 'district' => '06', 'name' => t('Salitral')),
      '200407' => array('department' => '20', 'province' => '04', 'district' => '07', 'name' => t('San juan de bigote')),
      '200408' => array('department' => '20', 'province' => '04', 'district' => '08', 'name' => t('Santa catalina de mossa')),
      '200409' => array('department' => '20', 'province' => '04', 'district' => '09', 'name' => t('Santo domingo')),
      '200410' => array('department' => '20', 'province' => '04', 'district' => '10', 'name' => t('Yamango')),
      '200500' => array('department' => '20', 'province' => '05', 'district' => '00', 'name' => t('Paita')),
      '200501' => array('department' => '20', 'province' => '05', 'district' => '01', 'name' => t('Paita')),
      '200502' => array('department' => '20', 'province' => '05', 'district' => '02', 'name' => t('Amotape')),
      '200503' => array('department' => '20', 'province' => '05', 'district' => '03', 'name' => t('Arenal')),
      '200504' => array('department' => '20', 'province' => '05', 'district' => '04', 'name' => t('Colan')),
      '200505' => array('department' => '20', 'province' => '05', 'district' => '05', 'name' => t('La huaca')),
      '200506' => array('department' => '20', 'province' => '05', 'district' => '06', 'name' => t('Tamarindo')),
      '200507' => array('department' => '20', 'province' => '05', 'district' => '07', 'name' => t('Vichayal')),
      '200600' => array('department' => '20', 'province' => '06', 'district' => '00', 'name' => t('Sullana')),
      '200601' => array('department' => '20', 'province' => '06', 'district' => '01', 'name' => t('Sullana')),
      '200602' => array('department' => '20', 'province' => '06', 'district' => '02', 'name' => t('Bellavista')),
      '200603' => array('department' => '20', 'province' => '06', 'district' => '03', 'name' => t('Ignacio escudero')),
      '200604' => array('department' => '20', 'province' => '06', 'district' => '04', 'name' => t('Lancones')),
      '200605' => array('department' => '20', 'province' => '06', 'district' => '05', 'name' => t('Marcavelica')),
      '200606' => array('department' => '20', 'province' => '06', 'district' => '06', 'name' => t('Miguel checa')),
      '200607' => array('department' => '20', 'province' => '06', 'district' => '07', 'name' => t('Querecotillo')),
      '200608' => array('department' => '20', 'province' => '06', 'district' => '08', 'name' => t('Salitral')),
      '200700' => array('department' => '20', 'province' => '07', 'district' => '00', 'name' => t('Talara')),
      '200701' => array('department' => '20', 'province' => '07', 'district' => '01', 'name' => t('Pariñas')),
      '200702' => array('department' => '20', 'province' => '07', 'district' => '02', 'name' => t('El alto')),
      '200703' => array('department' => '20', 'province' => '07', 'district' => '03', 'name' => t('La brea')),
      '200704' => array('department' => '20', 'province' => '07', 'district' => '04', 'name' => t('Lobitos')),
      '200705' => array('department' => '20', 'province' => '07', 'district' => '05', 'name' => t('Los organos')),
      '200706' => array('department' => '20', 'province' => '07', 'district' => '06', 'name' => t('Mancora')),
      '200800' => array('department' => '20', 'province' => '08', 'district' => '00', 'name' => t('Sechura')),
      '200801' => array('department' => '20', 'province' => '08', 'district' => '01', 'name' => t('Sechura')),
      '200802' => array('department' => '20', 'province' => '08', 'district' => '02', 'name' => t('Bellavista de la union')),
      '200803' => array('department' => '20', 'province' => '08', 'district' => '03', 'name' => t('Bernal')),
      '200804' => array('department' => '20', 'province' => '08', 'district' => '04', 'name' => t('Cristo nos valga')),
      '200805' => array('department' => '20', 'province' => '08', 'district' => '05', 'name' => t('Vice')),
      '200806' => array('department' => '20', 'province' => '08', 'district' => '06', 'name' => t('Rinconada llicuar')),
      '210000' => array('department' => '21', 'province' => '00', 'district' => '00', 'name' => t('Puno')),
      '210100' => array('department' => '21', 'province' => '01', 'district' => '00', 'name' => t('Puno')),
      '210101' => array('department' => '21', 'province' => '01', 'district' => '01', 'name' => t('Puno')),
      '210102' => array('department' => '21', 'province' => '01', 'district' => '02', 'name' => t('Acora')),
      '210103' => array('department' => '21', 'province' => '01', 'district' => '03', 'name' => t('Amantani')),
      '210104' => array('department' => '21', 'province' => '01', 'district' => '04', 'name' => t('Atuncolla')),
      '210105' => array('department' => '21', 'province' => '01', 'district' => '05', 'name' => t('Capachica')),
      '210106' => array('department' => '21', 'province' => '01', 'district' => '06', 'name' => t('Chucuito')),
      '210107' => array('department' => '21', 'province' => '01', 'district' => '07', 'name' => t('Coata')),
      '210108' => array('department' => '21', 'province' => '01', 'district' => '08', 'name' => t('Huata')),
      '210109' => array('department' => '21', 'province' => '01', 'district' => '09', 'name' => t('Mañazo')),
      '210110' => array('department' => '21', 'province' => '01', 'district' => '10', 'name' => t('Paucarcolla')),
      '210111' => array('department' => '21', 'province' => '01', 'district' => '11', 'name' => t('Pichacani')),
      '210112' => array('department' => '21', 'province' => '01', 'district' => '12', 'name' => t('Plateria')),
      '210113' => array('department' => '21', 'province' => '01', 'district' => '13', 'name' => t('San antonio')),
      '210114' => array('department' => '21', 'province' => '01', 'district' => '14', 'name' => t('Tiquillaca')),
      '210115' => array('department' => '21', 'province' => '01', 'district' => '15', 'name' => t('Vilque')),
      '210200' => array('department' => '21', 'province' => '02', 'district' => '00', 'name' => t('Azangaro')),
      '210201' => array('department' => '21', 'province' => '02', 'district' => '01', 'name' => t('Azangaro')),
      '210202' => array('department' => '21', 'province' => '02', 'district' => '02', 'name' => t('Achaya')),
      '210203' => array('department' => '21', 'province' => '02', 'district' => '03', 'name' => t('Arapa')),
      '210204' => array('department' => '21', 'province' => '02', 'district' => '04', 'name' => t('Asillo')),
      '210205' => array('department' => '21', 'province' => '02', 'district' => '05', 'name' => t('Caminaca')),
      '210206' => array('department' => '21', 'province' => '02', 'district' => '06', 'name' => t('Chupa')),
      '210207' => array('department' => '21', 'province' => '02', 'district' => '07', 'name' => t('Jose domingo choquehuanca')),
      '210208' => array('department' => '21', 'province' => '02', 'district' => '08', 'name' => t('Muñani')),
      '210209' => array('department' => '21', 'province' => '02', 'district' => '09', 'name' => t('Potoni')),
      '210210' => array('department' => '21', 'province' => '02', 'district' => '10', 'name' => t('Saman')),
      '210211' => array('department' => '21', 'province' => '02', 'district' => '11', 'name' => t('San anton')),
      '210212' => array('department' => '21', 'province' => '02', 'district' => '12', 'name' => t('San jose')),
      '210213' => array('department' => '21', 'province' => '02', 'district' => '13', 'name' => t('San juan de salinas')),
      '210214' => array('department' => '21', 'province' => '02', 'district' => '14', 'name' => t('Santiago de pupuja')),
      '210215' => array('department' => '21', 'province' => '02', 'district' => '15', 'name' => t('Tirapata')),
      '210300' => array('department' => '21', 'province' => '03', 'district' => '00', 'name' => t('Carabaya')),
      '210301' => array('department' => '21', 'province' => '03', 'district' => '01', 'name' => t('Macusani')),
      '210302' => array('department' => '21', 'province' => '03', 'district' => '02', 'name' => t('Ajoyani')),
      '210303' => array('department' => '21', 'province' => '03', 'district' => '03', 'name' => t('Ayapata')),
      '210304' => array('department' => '21', 'province' => '03', 'district' => '04', 'name' => t('Coasa')),
      '210305' => array('department' => '21', 'province' => '03', 'district' => '05', 'name' => t('Corani')),
      '210306' => array('department' => '21', 'province' => '03', 'district' => '06', 'name' => t('Crucero')),
      '210307' => array('department' => '21', 'province' => '03', 'district' => '07', 'name' => t('Ituata')),
      '210308' => array('department' => '21', 'province' => '03', 'district' => '08', 'name' => t('Ollachea')),
      '210309' => array('department' => '21', 'province' => '03', 'district' => '09', 'name' => t('San gaban')),
      '210310' => array('department' => '21', 'province' => '03', 'district' => '10', 'name' => t('Usicayos')),
      '210400' => array('department' => '21', 'province' => '04', 'district' => '00', 'name' => t('Chucuito')),
      '210401' => array('department' => '21', 'province' => '04', 'district' => '01', 'name' => t('Juli')),
      '210402' => array('department' => '21', 'province' => '04', 'district' => '02', 'name' => t('Desaguadero')),
      '210403' => array('department' => '21', 'province' => '04', 'district' => '03', 'name' => t('Huacullani')),
      '210404' => array('department' => '21', 'province' => '04', 'district' => '04', 'name' => t('Kelluyo')),
      '210405' => array('department' => '21', 'province' => '04', 'district' => '05', 'name' => t('Pisacoma')),
      '210406' => array('department' => '21', 'province' => '04', 'district' => '06', 'name' => t('Pomata')),
      '210407' => array('department' => '21', 'province' => '04', 'district' => '07', 'name' => t('Zepita')),
      '210500' => array('department' => '21', 'province' => '05', 'district' => '00', 'name' => t('El collao')),
      '210501' => array('department' => '21', 'province' => '05', 'district' => '01', 'name' => t('Ilave')),
      '210502' => array('department' => '21', 'province' => '05', 'district' => '02', 'name' => t('Capazo')),
      '210503' => array('department' => '21', 'province' => '05', 'district' => '03', 'name' => t('Pilcuyo')),
      '210504' => array('department' => '21', 'province' => '05', 'district' => '04', 'name' => t('Santa rosa')),
      '210505' => array('department' => '21', 'province' => '05', 'district' => '05', 'name' => t('Conduriri')),
      '210600' => array('department' => '21', 'province' => '06', 'district' => '00', 'name' => t('Huancane')),
      '210601' => array('department' => '21', 'province' => '06', 'district' => '01', 'name' => t('Huancane')),
      '210602' => array('department' => '21', 'province' => '06', 'district' => '02', 'name' => t('Cojata')),
      '210603' => array('department' => '21', 'province' => '06', 'district' => '03', 'name' => t('Huatasani')),
      '210604' => array('department' => '21', 'province' => '06', 'district' => '04', 'name' => t('Inchupalla')),
      '210605' => array('department' => '21', 'province' => '06', 'district' => '05', 'name' => t('Pusi')),
      '210606' => array('department' => '21', 'province' => '06', 'district' => '06', 'name' => t('Rosaspata')),
      '210607' => array('department' => '21', 'province' => '06', 'district' => '07', 'name' => t('Taraco')),
      '210608' => array('department' => '21', 'province' => '06', 'district' => '08', 'name' => t('Vilque chico')),
      '210700' => array('department' => '21', 'province' => '07', 'district' => '00', 'name' => t('Lampa')),
      '210701' => array('department' => '21', 'province' => '07', 'district' => '01', 'name' => t('Lampa')),
      '210702' => array('department' => '21', 'province' => '07', 'district' => '02', 'name' => t('Cabanilla')),
      '210703' => array('department' => '21', 'province' => '07', 'district' => '03', 'name' => t('Calapuja')),
      '210704' => array('department' => '21', 'province' => '07', 'district' => '04', 'name' => t('Nicasio')),
      '210705' => array('department' => '21', 'province' => '07', 'district' => '05', 'name' => t('Ocuviri')),
      '210706' => array('department' => '21', 'province' => '07', 'district' => '06', 'name' => t('Palca')),
      '210707' => array('department' => '21', 'province' => '07', 'district' => '07', 'name' => t('Paratia')),
      '210708' => array('department' => '21', 'province' => '07', 'district' => '08', 'name' => t('Pucara')),
      '210709' => array('department' => '21', 'province' => '07', 'district' => '09', 'name' => t('Santa lucia')),
      '210710' => array('department' => '21', 'province' => '07', 'district' => '10', 'name' => t('Vilavila')),
      '210800' => array('department' => '21', 'province' => '08', 'district' => '00', 'name' => t('Melgar')),
      '210801' => array('department' => '21', 'province' => '08', 'district' => '01', 'name' => t('Ayaviri')),
      '210802' => array('department' => '21', 'province' => '08', 'district' => '02', 'name' => t('Antauta')),
      '210803' => array('department' => '21', 'province' => '08', 'district' => '03', 'name' => t('Cupi')),
      '210804' => array('department' => '21', 'province' => '08', 'district' => '04', 'name' => t('Llalli')),
      '210805' => array('department' => '21', 'province' => '08', 'district' => '05', 'name' => t('Macari')),
      '210806' => array('department' => '21', 'province' => '08', 'district' => '06', 'name' => t('Nuñoa')),
      '210807' => array('department' => '21', 'province' => '08', 'district' => '07', 'name' => t('Orurillo')),
      '210808' => array('department' => '21', 'province' => '08', 'district' => '08', 'name' => t('Santa rosa')),
      '210809' => array('department' => '21', 'province' => '08', 'district' => '09', 'name' => t('Umachiri')),
      '210900' => array('department' => '21', 'province' => '09', 'district' => '00', 'name' => t('Moho')),
      '210901' => array('department' => '21', 'province' => '09', 'district' => '01', 'name' => t('Moho')),
      '210902' => array('department' => '21', 'province' => '09', 'district' => '02', 'name' => t('Conima')),
      '210903' => array('department' => '21', 'province' => '09', 'district' => '03', 'name' => t('Huayrapata')),
      '210904' => array('department' => '21', 'province' => '09', 'district' => '04', 'name' => t('Tilali')),
      '211000' => array('department' => '21', 'province' => '10', 'district' => '00', 'name' => t('San antonio de putina')),
      '211001' => array('department' => '21', 'province' => '10', 'district' => '01', 'name' => t('Putina')),
      '211002' => array('department' => '21', 'province' => '10', 'district' => '02', 'name' => t('Ananea')),
      '211003' => array('department' => '21', 'province' => '10', 'district' => '03', 'name' => t('Pedro vilca apaza')),
      '211004' => array('department' => '21', 'province' => '10', 'district' => '04', 'name' => t('Quilcapuncu')),
      '211005' => array('department' => '21', 'province' => '10', 'district' => '05', 'name' => t('Sina')),
      '211100' => array('department' => '21', 'province' => '11', 'district' => '00', 'name' => t('San roman')),
      '211101' => array('department' => '21', 'province' => '11', 'district' => '01', 'name' => t('Juliaca')),
      '211102' => array('department' => '21', 'province' => '11', 'district' => '02', 'name' => t('Cabana')),
      '211103' => array('department' => '21', 'province' => '11', 'district' => '03', 'name' => t('Cabanillas')),
      '211104' => array('department' => '21', 'province' => '11', 'district' => '04', 'name' => t('Caracoto')),
      '211200' => array('department' => '21', 'province' => '12', 'district' => '00', 'name' => t('Sandia')),
      '211201' => array('department' => '21', 'province' => '12', 'district' => '01', 'name' => t('Sandia')),
      '211202' => array('department' => '21', 'province' => '12', 'district' => '02', 'name' => t('Cuyocuyo')),
      '211203' => array('department' => '21', 'province' => '12', 'district' => '03', 'name' => t('Limbani')),
      '211204' => array('department' => '21', 'province' => '12', 'district' => '04', 'name' => t('Patambuco')),
      '211205' => array('department' => '21', 'province' => '12', 'district' => '05', 'name' => t('Phara')),
      '211206' => array('department' => '21', 'province' => '12', 'district' => '06', 'name' => t('Quiaca')),
      '211207' => array('department' => '21', 'province' => '12', 'district' => '07', 'name' => t('San juan del oro')),
      '211208' => array('department' => '21', 'province' => '12', 'district' => '08', 'name' => t('Yanahuaya')),
      '211209' => array('department' => '21', 'province' => '12', 'district' => '09', 'name' => t('Alto inambari')),
      '211210' => array('department' => '21', 'province' => '12', 'district' => '10', 'name' => t('San pedro de putina punco')),
      '211300' => array('department' => '21', 'province' => '13', 'district' => '00', 'name' => t('Yunguyo')),
      '211301' => array('department' => '21', 'province' => '13', 'district' => '01', 'name' => t('Yunguyo')),
      '211302' => array('department' => '21', 'province' => '13', 'district' => '02', 'name' => t('Anapia')),
      '211303' => array('department' => '21', 'province' => '13', 'district' => '03', 'name' => t('Copani')),
      '211304' => array('department' => '21', 'province' => '13', 'district' => '04', 'name' => t('Cuturapi')),
      '211305' => array('department' => '21', 'province' => '13', 'district' => '05', 'name' => t('Ollaraya')),
      '211306' => array('department' => '21', 'province' => '13', 'district' => '06', 'name' => t('Tinicachi')),
      '211307' => array('department' => '21', 'province' => '13', 'district' => '07', 'name' => t('Unicachi')),
      '220000' => array('department' => '22', 'province' => '00', 'district' => '00', 'name' => t('San martin')),
      '220100' => array('department' => '22', 'province' => '01', 'district' => '00', 'name' => t('Moyobamba')),
      '220101' => array('department' => '22', 'province' => '01', 'district' => '01', 'name' => t('Moyobamba')),
      '220102' => array('department' => '22', 'province' => '01', 'district' => '02', 'name' => t('Calzada')),
      '220103' => array('department' => '22', 'province' => '01', 'district' => '03', 'name' => t('Habana')),
      '220104' => array('department' => '22', 'province' => '01', 'district' => '04', 'name' => t('Jepelacio')),
      '220105' => array('department' => '22', 'province' => '01', 'district' => '05', 'name' => t('Soritor')),
      '220106' => array('department' => '22', 'province' => '01', 'district' => '06', 'name' => t('Yantalo')),
      '220200' => array('department' => '22', 'province' => '02', 'district' => '00', 'name' => t('Bellavista')),
      '220201' => array('department' => '22', 'province' => '02', 'district' => '01', 'name' => t('Bellavista')),
      '220202' => array('department' => '22', 'province' => '02', 'district' => '02', 'name' => t('Alto biavo')),
      '220203' => array('department' => '22', 'province' => '02', 'district' => '03', 'name' => t('Bajo biavo')),
      '220204' => array('department' => '22', 'province' => '02', 'district' => '04', 'name' => t('Huallaga')),
      '220205' => array('department' => '22', 'province' => '02', 'district' => '05', 'name' => t('San pablo')),
      '220206' => array('department' => '22', 'province' => '02', 'district' => '06', 'name' => t('San rafael')),
      '220300' => array('department' => '22', 'province' => '03', 'district' => '00', 'name' => t('El dorado')),
      '220301' => array('department' => '22', 'province' => '03', 'district' => '01', 'name' => t('San jose de sisa')),
      '220302' => array('department' => '22', 'province' => '03', 'district' => '02', 'name' => t('Agua blanca')),
      '220303' => array('department' => '22', 'province' => '03', 'district' => '03', 'name' => t('San martin')),
      '220304' => array('department' => '22', 'province' => '03', 'district' => '04', 'name' => t('Santa rosa')),
      '220305' => array('department' => '22', 'province' => '03', 'district' => '05', 'name' => t('Shatoja')),
      '220400' => array('department' => '22', 'province' => '04', 'district' => '00', 'name' => t('Huallaga')),
      '220401' => array('department' => '22', 'province' => '04', 'district' => '01', 'name' => t('Saposoa')),
      '220402' => array('department' => '22', 'province' => '04', 'district' => '02', 'name' => t('Alto saposoa')),
      '220403' => array('department' => '22', 'province' => '04', 'district' => '03', 'name' => t('El eslabon')),
      '220404' => array('department' => '22', 'province' => '04', 'district' => '04', 'name' => t('Piscoyacu')),
      '220405' => array('department' => '22', 'province' => '04', 'district' => '05', 'name' => t('Sacanche')),
      '220406' => array('department' => '22', 'province' => '04', 'district' => '06', 'name' => t('Tingo de saposoa')),
      '220500' => array('department' => '22', 'province' => '05', 'district' => '00', 'name' => t('Lamas')),
      '220501' => array('department' => '22', 'province' => '05', 'district' => '01', 'name' => t('Lamas')),
      '220502' => array('department' => '22', 'province' => '05', 'district' => '02', 'name' => t('Alonso de alvarado')),
      '220503' => array('department' => '22', 'province' => '05', 'district' => '03', 'name' => t('Barranquita')),
      '220504' => array('department' => '22', 'province' => '05', 'district' => '04', 'name' => t('Caynarachi')),
      '220505' => array('department' => '22', 'province' => '05', 'district' => '05', 'name' => t('Cuñumbuqui')),
      '220506' => array('department' => '22', 'province' => '05', 'district' => '06', 'name' => t('Pinto recodo')),
      '220507' => array('department' => '22', 'province' => '05', 'district' => '07', 'name' => t('Rumisapa')),
      '220508' => array('department' => '22', 'province' => '05', 'district' => '08', 'name' => t('San roque de cumbaza')),
      '220509' => array('department' => '22', 'province' => '05', 'district' => '09', 'name' => t('Shanao')),
      '220510' => array('department' => '22', 'province' => '05', 'district' => '10', 'name' => t('Tabalosos')),
      '220511' => array('department' => '22', 'province' => '05', 'district' => '11', 'name' => t('Zapatero')),
      '220600' => array('department' => '22', 'province' => '06', 'district' => '00', 'name' => t('Mariscal caceres')),
      '220601' => array('department' => '22', 'province' => '06', 'district' => '01', 'name' => t('Juanjui')),
      '220602' => array('department' => '22', 'province' => '06', 'district' => '02', 'name' => t('Campanilla')),
      '220603' => array('department' => '22', 'province' => '06', 'district' => '03', 'name' => t('Huicungo')),
      '220604' => array('department' => '22', 'province' => '06', 'district' => '04', 'name' => t('Pachiza')),
      '220605' => array('department' => '22', 'province' => '06', 'district' => '05', 'name' => t('Pajarillo')),
      '220700' => array('department' => '22', 'province' => '07', 'district' => '00', 'name' => t('Picota')),
      '220701' => array('department' => '22', 'province' => '07', 'district' => '01', 'name' => t('Picota')),
      '220702' => array('department' => '22', 'province' => '07', 'district' => '02', 'name' => t('Buenos aires')),
      '220703' => array('department' => '22', 'province' => '07', 'district' => '03', 'name' => t('Caspisapa')),
      '220704' => array('department' => '22', 'province' => '07', 'district' => '04', 'name' => t('Pilluana')),
      '220705' => array('department' => '22', 'province' => '07', 'district' => '05', 'name' => t('Pucacaca')),
      '220706' => array('department' => '22', 'province' => '07', 'district' => '06', 'name' => t('San cristobal')),
      '220707' => array('department' => '22', 'province' => '07', 'district' => '07', 'name' => t('San hilarion')),
      '220708' => array('department' => '22', 'province' => '07', 'district' => '08', 'name' => t('Shamboyacu')),
      '220709' => array('department' => '22', 'province' => '07', 'district' => '09', 'name' => t('Tingo de ponasa')),
      '220710' => array('department' => '22', 'province' => '07', 'district' => '10', 'name' => t('Tres unidos')),
      '220800' => array('department' => '22', 'province' => '08', 'district' => '00', 'name' => t('Rioja')),
      '220801' => array('department' => '22', 'province' => '08', 'district' => '01', 'name' => t('Rioja')),
      '220802' => array('department' => '22', 'province' => '08', 'district' => '02', 'name' => t('Awajun')),
      '220803' => array('department' => '22', 'province' => '08', 'district' => '03', 'name' => t('Elias soplin vargas')),
      '220804' => array('department' => '22', 'province' => '08', 'district' => '04', 'name' => t('Nueva cajamarca')),
      '220805' => array('department' => '22', 'province' => '08', 'district' => '05', 'name' => t('Pardo miguel')),
      '220806' => array('department' => '22', 'province' => '08', 'district' => '06', 'name' => t('Posic')),
      '220807' => array('department' => '22', 'province' => '08', 'district' => '07', 'name' => t('San fernando')),
      '220808' => array('department' => '22', 'province' => '08', 'district' => '08', 'name' => t('Yorongos')),
      '220809' => array('department' => '22', 'province' => '08', 'district' => '09', 'name' => t('Yuracyacu')),
      '220900' => array('department' => '22', 'province' => '09', 'district' => '00', 'name' => t('San martin')),
      '220901' => array('department' => '22', 'province' => '09', 'district' => '01', 'name' => t('Tarapoto')),
      '220902' => array('department' => '22', 'province' => '09', 'district' => '02', 'name' => t('Alberto leveau')),
      '220903' => array('department' => '22', 'province' => '09', 'district' => '03', 'name' => t('Cacatachi')),
      '220904' => array('department' => '22', 'province' => '09', 'district' => '04', 'name' => t('Chazuta')),
      '220905' => array('department' => '22', 'province' => '09', 'district' => '05', 'name' => t('Chipurana')),
      '220906' => array('department' => '22', 'province' => '09', 'district' => '06', 'name' => t('El porvenir')),
      '220907' => array('department' => '22', 'province' => '09', 'district' => '07', 'name' => t('Huimbayoc')),
      '220908' => array('department' => '22', 'province' => '09', 'district' => '08', 'name' => t('Juan guerra')),
      '220909' => array('department' => '22', 'province' => '09', 'district' => '09', 'name' => t('La banda de shilcayo')),
      '220910' => array('department' => '22', 'province' => '09', 'district' => '10', 'name' => t('Morales')),
      '220911' => array('department' => '22', 'province' => '09', 'district' => '11', 'name' => t('Papaplaya')),
      '220912' => array('department' => '22', 'province' => '09', 'district' => '12', 'name' => t('San antonio')),
      '220913' => array('department' => '22', 'province' => '09', 'district' => '13', 'name' => t('Sauce')),
      '220914' => array('department' => '22', 'province' => '09', 'district' => '14', 'name' => t('Shapaja')),
      '221000' => array('department' => '22', 'province' => '10', 'district' => '00', 'name' => t('Tocache')),
      '221001' => array('department' => '22', 'province' => '10', 'district' => '01', 'name' => t('Tocache')),
      '221002' => array('department' => '22', 'province' => '10', 'district' => '02', 'name' => t('Nuevo progreso')),
      '221003' => array('department' => '22', 'province' => '10', 'district' => '03', 'name' => t('Polvora')),
      '221004' => array('department' => '22', 'province' => '10', 'district' => '04', 'name' => t('Shunte')),
      '221005' => array('department' => '22', 'province' => '10', 'district' => '05', 'name' => t('Uchiza')),
      '230000' => array('department' => '23', 'province' => '00', 'district' => '00', 'name' => t('Tacna')),
      '230100' => array('department' => '23', 'province' => '01', 'district' => '00', 'name' => t('Tacna')),
      '230101' => array('department' => '23', 'province' => '01', 'district' => '01', 'name' => t('Tacna')),
      '230102' => array('department' => '23', 'province' => '01', 'district' => '02', 'name' => t('Alto de la alianza')),
      '230103' => array('department' => '23', 'province' => '01', 'district' => '03', 'name' => t('Calana')),
      '230104' => array('department' => '23', 'province' => '01', 'district' => '04', 'name' => t('Ciudad nueva')),
      '230105' => array('department' => '23', 'province' => '01', 'district' => '05', 'name' => t('Inclan')),
      '230106' => array('department' => '23', 'province' => '01', 'district' => '06', 'name' => t('Pachia')),
      '230107' => array('department' => '23', 'province' => '01', 'district' => '07', 'name' => t('Palca')),
      '230108' => array('department' => '23', 'province' => '01', 'district' => '08', 'name' => t('Pocollay')),
      '230109' => array('department' => '23', 'province' => '01', 'district' => '09', 'name' => t('Sama')),
      '230110' => array('department' => '23', 'province' => '01', 'district' => '10', 'name' => t('Coronel gregorio albarracin lanchipa')),
      '230200' => array('department' => '23', 'province' => '02', 'district' => '00', 'name' => t('Candarave')),
      '230201' => array('department' => '23', 'province' => '02', 'district' => '01', 'name' => t('Candarave')),
      '230202' => array('department' => '23', 'province' => '02', 'district' => '02', 'name' => t('Cairani')),
      '230203' => array('department' => '23', 'province' => '02', 'district' => '03', 'name' => t('Camilaca')),
      '230204' => array('department' => '23', 'province' => '02', 'district' => '04', 'name' => t('Curibaya')),
      '230205' => array('department' => '23', 'province' => '02', 'district' => '05', 'name' => t('Huanuara')),
      '230206' => array('department' => '23', 'province' => '02', 'district' => '06', 'name' => t('Quilahuani')),
      '230300' => array('department' => '23', 'province' => '03', 'district' => '00', 'name' => t('Jorge basadre')),
      '230301' => array('department' => '23', 'province' => '03', 'district' => '01', 'name' => t('Locumba')),
      '230302' => array('department' => '23', 'province' => '03', 'district' => '02', 'name' => t('Ilabaya')),
      '230303' => array('department' => '23', 'province' => '03', 'district' => '03', 'name' => t('Ite')),
      '230400' => array('department' => '23', 'province' => '04', 'district' => '00', 'name' => t('Tarata')),
      '230401' => array('department' => '23', 'province' => '04', 'district' => '01', 'name' => t('Tarata')),
      '230402' => array('department' => '23', 'province' => '04', 'district' => '02', 'name' => t('Heroes albarracin')),
      '230403' => array('department' => '23', 'province' => '04', 'district' => '03', 'name' => t('Estique')),
      '230404' => array('department' => '23', 'province' => '04', 'district' => '04', 'name' => t('Estique-pampa')),
      '230405' => array('department' => '23', 'province' => '04', 'district' => '05', 'name' => t('Sitajara')),
      '230406' => array('department' => '23', 'province' => '04', 'district' => '06', 'name' => t('Susapaya')),
      '230407' => array('department' => '23', 'province' => '04', 'district' => '07', 'name' => t('Tarucachi')),
      '230408' => array('department' => '23', 'province' => '04', 'district' => '08', 'name' => t('Ticaco')),
      '240000' => array('department' => '24', 'province' => '00', 'district' => '00', 'name' => t('Tumbes')),
      '240100' => array('department' => '24', 'province' => '01', 'district' => '00', 'name' => t('Tumbes')),
      '240101' => array('department' => '24', 'province' => '01', 'district' => '01', 'name' => t('Tumbes')),
      '240102' => array('department' => '24', 'province' => '01', 'district' => '02', 'name' => t('Corrales')),
      '240103' => array('department' => '24', 'province' => '01', 'district' => '03', 'name' => t('La cruz')),
      '240104' => array('department' => '24', 'province' => '01', 'district' => '04', 'name' => t('Pampas de hospital')),
      '240105' => array('department' => '24', 'province' => '01', 'district' => '05', 'name' => t('San jacinto')),
      '240106' => array('department' => '24', 'province' => '01', 'district' => '06', 'name' => t('San juan de la virgen')),
      '240200' => array('department' => '24', 'province' => '02', 'district' => '00', 'name' => t('Contralmirante villar')),
      '240201' => array('department' => '24', 'province' => '02', 'district' => '01', 'name' => t('Zorritos')),
      '240202' => array('department' => '24', 'province' => '02', 'district' => '02', 'name' => t('Casitas')),
      '240203' => array('department' => '24', 'province' => '02', 'district' => '03', 'name' => t('Canoas de punta sal')),
      '240300' => array('department' => '24', 'province' => '03', 'district' => '00', 'name' => t('Zarumilla')),
      '240301' => array('department' => '24', 'province' => '03', 'district' => '01', 'name' => t('Zarumilla')),
      '240302' => array('department' => '24', 'province' => '03', 'district' => '02', 'name' => t('Aguas verdes')),
      '240303' => array('department' => '24', 'province' => '03', 'district' => '03', 'name' => t('Matapalo')),
      '240304' => array('department' => '24', 'province' => '03', 'district' => '04', 'name' => t('Papayal')),
      '250000' => array('department' => '25', 'province' => '00', 'district' => '00', 'name' => t('Ucayali')),
      '250100' => array('department' => '25', 'province' => '01', 'district' => '00', 'name' => t('Coronel portillo')),
      '250101' => array('department' => '25', 'province' => '01', 'district' => '01', 'name' => t('Calleria')),
      '250102' => array('department' => '25', 'province' => '01', 'district' => '02', 'name' => t('Campoverde')),
      '250103' => array('department' => '25', 'province' => '01', 'district' => '03', 'name' => t('Iparia')),
      '250104' => array('department' => '25', 'province' => '01', 'district' => '04', 'name' => t('Masisea')),
      '250105' => array('department' => '25', 'province' => '01', 'district' => '05', 'name' => t('Yarinacocha')),
      '250106' => array('department' => '25', 'province' => '01', 'district' => '06', 'name' => t('Nueva requena')),
      '250107' => array('department' => '25', 'province' => '01', 'district' => '07', 'name' => t('Manantay')),
      '250200' => array('department' => '25', 'province' => '02', 'district' => '00', 'name' => t('Atalaya')),
      '250201' => array('department' => '25', 'province' => '02', 'district' => '01', 'name' => t('Raymondi')),
      '250202' => array('department' => '25', 'province' => '02', 'district' => '02', 'name' => t('Sepahua')),
      '250203' => array('department' => '25', 'province' => '02', 'district' => '03', 'name' => t('Tahuania')),
      '250204' => array('department' => '25', 'province' => '02', 'district' => '04', 'name' => t('Yurua')),
      '250300' => array('department' => '25', 'province' => '03', 'district' => '00', 'name' => t('Padre abad')),
      '250301' => array('department' => '25', 'province' => '03', 'district' => '01', 'name' => t('Padre abad')),
      '250302' => array('department' => '25', 'province' => '03', 'district' => '02', 'name' => t('Irazola')),
      '250303' => array('department' => '25', 'province' => '03', 'district' => '03', 'name' => t('Curimana')),
      '250400' => array('department' => '25', 'province' => '04', 'district' => '00', 'name' => t('Purus')),
      '250401' => array('department' => '25', 'province' => '04', 'district' => '01', 'name' => t('Purus')),
    );
    $map_ubigeo_iso31662 = array(
      '01' => 'AMA',
      '02' => 'ANC',
      '03' => 'APU',
      '04' => 'ARE',
      '05' => 'AYA',
      '06' => 'CAJ',
      '07' => 'CAL',
      '08' => 'CUS',
      '09' => 'HUV',
      '10' => 'HUC',
      '11' => 'ICA',
      '12' => 'JUN',
      '13' => 'LAL',
      '14' => 'LAM',
      '15' => 'LIM',
      '16' => 'LOR',
      '17' => 'MDD',
      '18' => 'MOQ',
      '19' => 'PAS',
      '20' => 'PIU',
      '21' => 'PUN',
      '22' => 'SAM',
      '23' => 'TAC',
      '24' => 'TUM',
      '25' => 'UCA',
    );
    foreach ($ubigeo as $code => $place) {
      $department_iso = $map_ubigeo_iso31662[$place['department']];
      if ($place['province'] == '00') {
        if ($place['district'] == '00') {
          // Department.
          $ubigeo_list['department'][$department_iso] = $place['name'];
          $flat_list['department'][$department_iso] = $place['name'];
        }
        else {
          // Should not happen.
        }
      }
      else {
        if ($place['district'] == '00') {
          // Province.
          $ubigeo_list['province'][$department_iso][$code] = $place['name'];
          $flat_list['province'][$code] = $place['name'];
        }
        else {
          // District.
          $ubigeo_list['district'][$department_iso][$place['province']][$code] = $place['name'];
          $flat_list['district'][$code] = $place['name'];
        }
      }
    }
  }
  switch ($type) {
    // @todo Validate required parameters.
    case 'districts':
      return $ubigeo_list['district'][$department][$province];
    case 'provinces':
      //$ubigeo_list['province'][$department]['none'] = t('--');
      return $ubigeo_list['province'][$department];
    case 'departments':
      return $ubigeo_list['department'];
    case 'item':
      $code = $department;
      if (substr($code, 2) == '0000') {
        $type = 'department';
      }
      elseif (substr($code, 4) == '00') {
        $type = 'province';
      }
      else {
        $type = 'district';
      }
      return $flat_list[$type][$department];
    case 'all':
    default:
      return $flat_list;
  }
}
